(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    296627,      11531]*)
(*NotebookOutlinePosition[    320646,      12405]*)
(*  CellTagsIndexPosition[    320602,      12401]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["OPTDesign Chapter 5 Example", "Title"],

Cell["\<\
This demo corresponds to the example in Chapter 5 of the book \
Classical Control Using Hinfinity Methods, by J. W. Helton and O. Merino,
NOTE: Depending upon the settings of the programs, some numbers  may differ \
from those in the book.\
\>", "Text"],

Cell[CellGroupData[{

Cell["5.1 Loading the software", "Section"],

Cell[CellGroupData[{

Cell["<<OPTDesign`", "Input"],

Cell[BoxData[
    \(" \n Anopt 4.0 (c) Copyright 1991-98 \n J.W.Helton and O.Merino.  All \
rights reserved."\)], "Print"],

Cell[BoxData[
    \("OPTDesign 2.0 (c) 1991-98 \n   J.W. Helton and O.Merino.  All rights \
reserved."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Setting up the problem", "Section"],

Cell[CellGroupData[{

Cell["\<\
     p[s_]= (1 - s/5)/(1+s/2)^2;\t\t

      wt  = 0.3;
  alphat  = 1.5;

 alphagpm = 2.0;

       wb = 2.0;
   alphab = 0.7;
              
       wr = 4.0;
   alphar = 2.5;
 
    k0[w_]= Which[ Abs[w] <= wb, 1.0,
                     True, 0.0];
 
   r0[w_] = Which[Abs[w] < wt,  alphat,
               Abs[w] < wb,  alphagpm,
               Abs[w] < wr,  alphab,
                     True ,  alphar*Abs[p[I w]]
                ];

     wpts = Grid[Ngrid ->128,GridSpread -> 1.0];

EnvelopePlot[Radius ->r0,Center -> k0,
\t\t\tFrequencyBand -> {0,wr+1} 
\t\t \t(* ,GridPoints -> wpts *) ];

EnvelopePlot3D[Radius ->r0,Center -> k0,
\t\t\tFrequencyBand -> {0,wr+1} 
\t\t \t(* ,GridPoints -> wpts *) ];

\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(alphab\)\" is similar \
to existing symbol \"\!\(alphat\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(alphar\)\" is similar \
to existing symbols \!\({alphab, alphat}\)."\)], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.161866 0.147151 [
[.2 .14937 -3 -9 ]
[.2 .14937 3 0 ]
[.4 .14937 -3 -9 ]
[.4 .14937 3 0 ]
[.6 .14937 -3 -9 ]
[.6 .14937 3 0 ]
[.8 .14937 -3 -9 ]
[.8 .14937 3 0 ]
[1 .14937 -3 -9 ]
[1 .14937 3 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16187 m
.2 .16812 L
s
[(1)] .2 .14937 0 1 Mshowa
.4 .16187 m
.4 .16812 L
s
[(2)] .4 .14937 0 1 Mshowa
.6 .16187 m
.6 .16812 L
s
[(3)] .6 .14937 0 1 Mshowa
.8 .16187 m
.8 .16812 L
s
[(4)] .8 .14937 0 1 Mshowa
1 .16187 m
1 .16812 L
s
[(5)] 1 .14937 0 1 Mshowa
.125 Mabswid
.04 .16187 m
.04 .16562 L
s
.08 .16187 m
.08 .16562 L
s
.12 .16187 m
.12 .16562 L
s
.16 .16187 m
.16 .16562 L
s
.24 .16187 m
.24 .16562 L
s
.28 .16187 m
.28 .16562 L
s
.32 .16187 m
.32 .16562 L
s
.36 .16187 m
.36 .16562 L
s
.44 .16187 m
.44 .16562 L
s
.48 .16187 m
.48 .16562 L
s
.52 .16187 m
.52 .16562 L
s
.56 .16187 m
.56 .16562 L
s
.64 .16187 m
.64 .16562 L
s
.68 .16187 m
.68 .16562 L
s
.72 .16187 m
.72 .16562 L
s
.76 .16187 m
.76 .16562 L
s
.84 .16187 m
.84 .16562 L
s
.88 .16187 m
.88 .16562 L
s
.92 .16187 m
.92 .16562 L
s
.96 .16187 m
.96 .16562 L
s
.25 Mabswid
0 .16187 m
1 .16187 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1 .08914 m
.89064 .07722 L
.79844 .06631 L
.72271 .06048 L
.65931 .05898 L
.60541 .05886 L
.55896 .05886 L
.51848 .05886 L
.48284 .0586 L
.45119 .05548 L
.42286 .04471 L
.39733 .02887 L
.37417 .01809 L
.35305 .01497 L
.33368 .01472 L
.31583 .01472 L
.29932 .01472 L
.28398 .01472 L
.26967 .01472 L
.25628 .01472 L
.2437 .01472 L
.23186 .01472 L
.22067 .01472 L
.21007 .01472 L
.2 .01472 L
.19042 .01472 L
.18127 .01472 L
.17252 .01472 L
.16414 .01472 L
.15608 .01472 L
.14833 .01472 L
.14086 .01472 L
.13364 .01472 L
.12665 .01472 L
.11988 .01472 L
.1133 .01472 L
.1069 .01472 L
.10067 .01472 L
.09459 .01472 L
.08865 .01472 L
.08284 .01472 L
.07715 .01472 L
.07156 .01514 L
.06607 .02034 L
.06067 .03831 L
.05535 .0647 L
.0501 .08266 L
.04491 .08786 L
.03978 .08829 L
.0347 .08829 L
Mistroke
.02967 .08829 L
.02467 .08829 L
.0197 .08829 L
.01475 .08829 L
.00983 .08829 L
.00491 .08829 L
0 .08829 L
Mfstroke
1 .2346 m
.89064 .24651 L
.79844 .25742 L
.72271 .26325 L
.65931 .26475 L
.60541 .26487 L
.55896 .26487 L
.51848 .26487 L
.48284 .26685 L
.45119 .29076 L
.42286 .37339 L
.39733 .4948 L
.37417 .57743 L
.35305 .60134 L
.33368 .60332 L
.31583 .60332 L
.29932 .60332 L
.28398 .60332 L
.26967 .60332 L
.25628 .60332 L
.2437 .60332 L
.23186 .60332 L
.22067 .60332 L
.21007 .60332 L
.2 .60332 L
.19042 .60332 L
.18127 .60332 L
.17252 .60332 L
.16414 .60332 L
.15608 .60332 L
.14833 .60332 L
.14086 .60332 L
.13364 .60332 L
.12665 .60332 L
.11988 .60332 L
.1133 .60332 L
.1069 .60332 L
.10067 .60332 L
.09459 .60332 L
.08865 .60332 L
.08284 .60332 L
.07715 .60332 L
.07156 .60289 L
.06607 .59769 L
.06067 .57973 L
.05535 .55333 L
.0501 .53537 L
.04491 .53017 L
.03978 .52974 L
.0347 .52974 L
Mistroke
.02967 .52974 L
.02467 .52974 L
.0197 .52974 L
.01475 .52974 L
.00983 .52974 L
.00491 .52974 L
0 .52974 L
Mfstroke
.5 g
.01 w
0 .52974 m
.01975 .52974 L
.04057 .52974 L
.04585 .52974 L
.0515 .52974 L
.05424 .52974 L
.05683 .52974 L
.05796 .52974 L
.05916 .52974 L
.06047 .60332 L
.06168 .60332 L
.08481 .60332 L
.12454 .60332 L
.16684 .60332 L
.20755 .60332 L
.25083 .60332 L
.29253 .60332 L
.33263 .60332 L
.35501 .60332 L
.37531 .60332 L
.38547 .60332 L
.39082 .60332 L
.39374 .60332 L
.39646 .60332 L
.39769 .60332 L
.39885 .60332 L
.40019 .26487 L
.40141 .26487 L
.40684 .26487 L
.41639 .26487 L
.45664 .26487 L
.49946 .26487 L
.54069 .26487 L
.58033 .26487 L
.62254 .26487 L
.66316 .26487 L
.70636 .26487 L
.74797 .26487 L
.76893 .26487 L
.78798 .26487 L
.79306 .26487 L
.79574 .26487 L
.7972 .26487 L
.79857 .26487 L
.79977 .26487 L
.80105 .25594 L
.80178 .25584 L
.80247 .25574 L
.80377 .25555 L
.80857 .25488 L
Mistroke
.83057 .2519 L
.87073 .24687 L
.91346 .24204 L
.9546 .23783 L
.99832 .23377 L
1 .23363 L
Mfstroke
0 .08829 m
.01975 .08829 L
.04057 .08829 L
.04585 .08829 L
.0515 .08829 L
.05424 .08829 L
.05683 .08829 L
.05796 .08829 L
.05916 .08829 L
.06047 .01472 L
.06168 .01472 L
.08481 .01472 L
.12454 .01472 L
.16684 .01472 L
.20755 .01472 L
.25083 .01472 L
.29253 .01472 L
.33263 .01472 L
.35501 .01472 L
.37531 .01472 L
.38547 .01472 L
.39082 .01472 L
.39374 .01472 L
.39646 .01472 L
.39769 .01472 L
.39885 .01472 L
.40019 .05886 L
.40141 .05886 L
.40684 .05886 L
.41639 .05886 L
.45664 .05886 L
.49946 .05886 L
.54069 .05886 L
.58033 .05886 L
.62254 .05886 L
.66316 .05886 L
.70636 .05886 L
.74797 .05886 L
.76893 .05886 L
.78798 .05886 L
.79306 .05886 L
.79574 .05886 L
.7972 .05886 L
.79857 .05886 L
.79977 .05886 L
.80105 .06779 L
.80178 .0679 L
.80247 .06799 L
.80377 .06818 L
.80857 .06885 L
Mistroke
.83057 .07183 L
.87073 .07686 L
.91346 .0817 L
.9546 .08591 L
.99832 .08996 L
1 .09011 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@000?l08@000?l0
8@0000l000<10000o`0?00003`000`40003o00l0000?00030@000?l03`0000L0104400030@000?l0
3`0000T000<100000`030@`0GF^U00002@000`40000300030@0000`0GF^U000000<00@400P440003
0@0000<000<100003002J`03004005800P42009[Y@0000T000<100000`000`40000<009[00<10000
E0020@9[Y@0000L00`4500030@0000`00V/00`40001F009[Y@0000T000<100000`000`40000<009[
F@02J`81X`0000l000<100003002JeT00V/200030@000:00000?00030@0000`00V]I009[0`020J00
000?00813@02JeT00V/50081WP0000l000<100003002JeT00V/700<1V`0000l000<100003002JeT0
0V/:0081V@0000l000<100003002JeT00V/<00H1T`0000l000<100003002JeT0KV/i00003`000`40
000<009[F@1_JcP0000?00030@0000`00V_100@116/00`4000020003J`0002l0000?00030@0000/0
00<1Jf/0a@0?Jb`0000?008130000`5[J`3701=[9P0000l000<100002P001040Jf_D015[6`0000l0
00<100002P001040Jf_I01M[400000l000<100002P001040Jf_T01Q[100000h04V__00i[0`0000h0
4V_j00=[0`0000l000<10000o`0?00003`000`40003o00l0000?0081o`0@00003`000`40003o00l0
000?00030@000?l03`0000l000<10000o`0?00003`000`40003o00l0000?00030@000?l03`0000l0
00<10000o`0?00003`000`40000a00@1<@040C<00P4e00030@0003400`4300003`020C@000<10000
<0000`40000c00040@000C@000<10000=0010@400@0000l000<10000<`000`40000a00030@0003D0
00<10000;`050CD00@410040000?00030@0003<000<10000<P000`40000b0081<P001040004c00<1
0`0000l000<10000<`000`40000c00030@0003<000<10000<0000`400@0c00030@0000<0000?0003
0@0003400`4b00040@000C8000@10001<`020C<000<100000`0000l000<10000<`000`40000a0081
=0020CD000<10000<@040@80000?00030@000?l03`0000l0o`4?0@<0000?00030@0000P000<10000
1`000`40000800030@0000P000<1000020000`40000700030@0000P000<1000020000`4000080003
0@0000L000<1000020000`40000800030@0000P000<100001`000`40000800030@0000P000<10000
20000`40000700030@0000P000<1000020000`40000800030@0000L000<1000020000`4000080003
0@0000P000<100000@0000l000<1000020000`40000700030@0000P000<1000020000`4000080003
0@0000L000<1000020000`40000800030@0000P000<100001`000`40000800030@0000P000<10000
20000`40000700030@0000P000<1000020000`40000800030@0000L000<1000020000`4000080003
0@0000P000<100001`000`40000800030@0000P000<1000020000`40000100003`000`40003o00l0
000?00030@000?l03`0000l000<10000o`0?00003`000`40003o00l0000?00030@000?l03`0000l0
0P7o0100000?00030@000?l03`0000l000<10000o`0?00003`000`40003o00l0000?00030@000?l0
3`0000l000<10000o`0?00003`000`40003o00l0000?00030@000?l03`0000l00P7o0100000?0003
0@000?l03`0000l000<10000o`0?00003`000`40003o00X000=[00000P0000l000<10000o@0>J`<0
000?00030@000?806F/300003`000`40003W01M[400000l000<10000hP0AJa/0000?0081e`000f/0
000300a[9P0000l000<10000e@0=Jb`0000?00030@000<h01@4:Jc40000?00030@000<@02P4500=[
>00000l000<10000I`1^JcT0000?00030@0006L0KV/i00003`000`40001W009[50020Hl0000?0003
0@0006L00V/C00030@0008l0000?0081J002Ja400P6B00003`000`40001W009[40000`40002B0000
3`000`40001W009[3P020ID0000?00030@0006L00V/=00030@0009D0000?00030@0006L00V/=0003
0@0009D0000?00030@0006L00V/<00030@0009H0000?00030@0006L00V/<00030@0009H0000700@1
10000`40001W009[30000`40002F00002@000`40000300<1I`02J`/000<10000U`0000T000<10000
0`000`40001W009[2`000`40002G00002@000`40000300030@0006L00V/:00030@0009P000090003
0@0000<000<10000I`02J`X000<10000V00000L00`4500030@0006L00V/:00030@0009P000090003
0@0000<000<10000I`02J`T000<10000V@0000l000<10000I`02J`T000<10000V@0000l000<10000
I`02J`T000<10000V@0000l00P5X009[20000`40002J00003`000`40001W009[20000`40002J0000
3`000`40001W009[20000`40002J00003`000`40001W009[1`000`40002K00003`000`40001W009[
1`000`40002K00003`000`40001W009[1P000`40002L00003`000`40001W009[1P000`40002L0000
3`000`40001W009[1P000`40002L00003`020FP00V/500030@0009d0000?00030@0006L00V/50003
0@0009d0000?00030@0006L00V/500030@0009d0000?00030@0006L00V/500030@0009d0000?0003
0@0006L00V/400030@0009h0000?00030@0006L00V/400030@0009h0000?00030@0006L00V/40003
0@0009h0000?00030@0006L00V/400030@0009h0000?0081J002J`@000<10000WP0000l000<10000
I`02J`@000<10000WP0000l000<10000I`02J`<000<10000W`0000l000<10000I`02J`<000<10000
W`0000l000<10000I`02J`<000<10000W`0000l000<10000I`02J`<000<10000W`0000l000<10000
I`02J`<000<10000W`0000l000<10000I`02J`8000<10000X00000l00P5X009[0P000`40002P0000
3`000`40001W009[0P000`40002P00003`000`40001W009[0P000`40002P00003`000`40001W009[
0P000`40002P00003`000`40001W009[0P000`40002P00003`000`40001W009[00<00@00XP0000L0
104400030@0006L00V/00`01002R00001`000`40000500030@0006L00V/00`01002R000020000`40
000400<1I`02J`0300400:80000900030@0000<000<10000I`02J`0300400:80000:00030@000080
00<10000I`02J`030@000:80000700040@000@@000<10000I`02J`030@000:80000800811@000`40
001W009[00<10000XP0000l000<10000I`02J`030@000:80000?00030@0006L00V/00`40002R0000
3`020FP00V/00`40002R00003`000`40001W009[Y@0000l000<10000I`02JjD0000?00030@0006L0
0V^U00003`000`40001W009[Y@0000l000<10000I`02JjD0000?00030@0006L00V^U00003`000`40
001W009[Y@0000l00P5W00030F][0:D0000?00030@0006H000<1Jf/0Y@0000l000<10000IP000`5[
J`2U00003`000`40001U00040@1[JjD0000>019[E`001040Jf^U00003P0BJeL000@106][Y@0000l0
00<100002P001040Jf]G00040@1[JjD0000?00030@0000X000@106][EP000`400002JjD0000?0081
30000`5[J`1F00030@00009[Y@0000l000<100002`000`5[J`1F00030@00009[Y@0000l000<10000
3002JeD000@100000V^U00003`000`40000<009[E@0010400002JjD0000?00030@0000`00V]E0004
0@00009[Y@0000l000<100003002Je@000<100000P02JjD0000?00030@0000`00V]D00030@000080
0V^U00003`000`40000<009[E0000`400002009[Y@0000l00P4=009[D`000`400003009[Y@0000l0
00<100003002Je<000<100000`02JjD0000?00030@0000`00V]B00030@0000@00V^U00003`000`40
000<009[DP000`400004009[Y@0000l000<100003002J`030@0004h000<100001@02JjD0000?0003
0@0000`00V/00`40001=00030@0000H00V^U00003`000`40000<009[00<00@00C0000`400007009[
Y@0000P00P4500030@0000`00V/00`01001<00030@0000L00V^U00001`001040004400<1301MJjD0
000:00030@00008000<10000301MJjD0000800811@000`40003o00l0000:00030@00008000<10000
o`0?00001`001040004400030@000?l03`0000P00P7o01L0003o0240003o0240003o0240003o0240
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.285873, -1.23796, 
  0.0186123, 0.0252969}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98709 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0161164 1.01612 -0.000359473 1.01612 [
[.21669 .99535 -3.18333 0 ]
[.21669 .99535 2.81667 9 ]
[.50187 .92136 -2.99327 0 ]
[.50187 .92136 3.00673 9 ]
[.81334 .84051 -2.77831 0 ]
[.81334 .84051 3.22169 9 ]
[.57837 .96533 -4.90342 0 ]
[.57837 .96533 5.09658 15 ]
[.00377 .85528 -3.33559 0 ]
[.00377 .85528 2.66441 9 ]
[.05477 .8929 -9.89388 0 ]
[.05477 .8929 8.10612 9 ]
[.10371 .92899 -3.26245 0 ]
[.10371 .92899 2.73755 9 ]
[.1507 .96365 -9.6867 0 ]
[.1507 .96365 8.3133 9 ]
[.19586 .99696 -3.19714 0 ]
[.19586 .99696 2.80286 9 ]
[.09784 .99201 -18.4886 0 ]
[.09784 .99201 15.5114 15 ]
[.94612 .21871 0 -6.03056 ]
[.94612 .21871 12 2.96944 ]
[.96063 .34082 0 -5.9512 ]
[.96063 .34082 6 3.0488 ]
[.97612 .47119 0 -5.86684 ]
[.97612 .47119 6 3.13316 ]
[.99268 .61067 0 -5.77697 ]
[.99268 .61067 6 3.22303 ]
[1.01044 .76026 0 -5.68105 ]
[1.01044 .76026 6 3.31895 ]
[1.03688 .45273 0 -9.77806 ]
[1.03688 .45273 34 5.22194 ]
[ 0 0 0 0 ]
[ 1 .98709 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20049 .98709 m
1 .77902 L
s
.21747 .98267 m
.21785 .97633 L
s
[(0)] .21669 .99535 .06111 -1 Mshowa
.50184 .90866 m
.50183 .90231 L
s
[(2)] .50187 .92136 -0.00224 -1 Mshowa
.81241 .82784 m
.81194 .82151 L
s
[(4)] .81334 .84051 -0.0739 -1 Mshowa
.125 Mabswid
.28629 .96476 m
.28646 .96095 L
s
.35659 .94646 m
.35671 .94266 L
s
.42843 .92777 m
.42848 .92396 L
s
.57689 .88913 m
.57682 .88532 L
s
.65363 .86916 m
.65349 .86535 L
s
.73212 .84874 m
.73191 .84493 L
s
.89457 .80646 m
.89421 .80267 L
s
.97867 .78457 m
.97824 .78079 L
s
gsave
.57837 .96533 -65.9034 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
0 .83882 m
.20049 .98709 L
s
.00518 .84266 m
.00589 .83634 L
s
[(0)] .00377 .85528 .11186 -1 Mshowa
.05603 .88026 m
.05666 .87394 L
s
[(0.5)] .05477 .8929 .09932 -1 Mshowa
.10481 .91634 m
.10537 .91001 L
s
[(1)] .10371 .92899 .08748 -1 Mshowa
.15167 .95098 m
.15215 .94465 L
s
[(1.5)] .1507 .96365 .0763 -1 Mshowa
.1967 .98429 m
.19711 .97795 L
s
[(2)] .19586 .99696 .06571 -1 Mshowa
.125 Mabswid
.01552 .8503 m
.01594 .84651 L
s
.02578 .85788 m
.02618 .8541 L
s
.03594 .8654 m
.03634 .86161 L
s
.04603 .87286 m
.04641 .86907 L
s
.06595 .88759 m
.06631 .8838 L
s
.07578 .89487 m
.07614 .89107 L
s
.08554 .90208 m
.08589 .89829 L
s
.09521 .90924 m
.09556 .90544 L
s
.11434 .92338 m
.11466 .91958 L
s
.12378 .93036 m
.12409 .92656 L
s
.13315 .93729 m
.13346 .93349 L
s
.14244 .94417 m
.14274 .94037 L
s
.16081 .95775 m
.1611 .95395 L
s
.16989 .96446 m
.17016 .96066 L
s
.1789 .97112 m
.17916 .96732 L
s
.18783 .97773 m
.18809 .97393 L
s
gsave
.09784 .99201 -79.4886 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Im) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 15.000000 moveto
(@) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 15.000000 moveto
(D) show
93.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.9327 .21103 m
1 .77902 L
s
.93409 .2228 m
.92808 .22484 L
s
[(-1)] .94612 .21871 -1 .34012 Mshowa
.94854 .34472 m
.9425 .34667 L
s
[(0)] .96063 .34082 -1 .32249 Mshowa
.96396 .47488 m
.95789 .47673 L
s
[(1)] .97612 .47119 -1 .30374 Mshowa
.98046 .61414 m
.97435 .61587 L
s
[(2)] .99268 .61067 -1 .28377 Mshowa
.99816 .76349 m
.99202 .7651 L
s
[(3)] 1.01044 .76026 -1 .26245 Mshowa
.125 Mabswid
.93691 .24656 m
.9333 .24778 L
s
.93976 .27063 m
.93615 .27183 L
s
.94265 .29501 m
.93903 .2962 L
s
.94558 .3197 m
.94195 .32088 L
s
.95154 .37007 m
.94791 .37123 L
s
.95459 .39575 m
.95095 .3969 L
s
.95767 .42178 m
.95403 .42291 L
s
.96079 .44815 m
.95715 .44927 L
s
.96717 .50197 m
.96352 .50307 L
s
.97043 .52944 m
.96677 .53052 L
s
.97373 .55728 m
.97007 .55835 L
s
.97707 .58551 m
.97341 .58657 L
s
.9839 .64317 m
.98023 .64419 L
s
.98739 .67261 m
.98372 .67362 L
s
.99093 .70247 m
.98725 .70347 L
s
.99452 .73276 m
.99084 .73374 L
s
gsave
1.03688 .45273 -61 -13.7781 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 15.000000 moveto
(@) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 15.000000 moveto
(D) show
93.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.06337 .27882 m
0 .83882 L
s
0 .83882 m
.20049 .98709 L
s
.20049 .98709 m
.23534 .44941 L
s
.23534 .44941 m
.06337 .27882 L
s
.80061 0 m
.9327 .21103 L
s
.9327 .21103 m
1 .77902 L
s
1 .77902 m
.85247 .5896 L
s
.85247 .5896 m
.80061 0 L
s
.06337 .27882 m
0 .83882 L
s
0 .83882 m
.85247 .5896 L
s
.85247 .5896 m
.80061 0 L
s
.80061 0 m
.06337 .27882 L
s
.23534 .44941 m
.9327 .21103 L
s
.9327 .21103 m
1 .77902 L
s
1 .77902 m
.20049 .98709 L
s
.20049 .98709 m
.23534 .44941 L
s
0 0 m
1 0 L
1 .98709 L
0 .98709 L
closepath
clip
newpath
.5 Mabswid
.28182 .40652 m .24819 .41815 L .26602 .46425 L p .734 .659 .853 r
F P
0 g
s
.26602 .46425 m .29966 .45288 L .28182 .40652 L p .734 .659 .853 r
F P
0 g
s
.1998 .48724 m .26602 .46425 L .24819 .41815 L p .934 .756 .761 r
F P
0 g
s
.29966 .45288 m .26602 .46425 L .28037 .51151 L p .724 .624 .82 r
F P
0 g
s
.26602 .46425 m .1998 .48724 L .21074 .52335 L p .929 .738 .745 r
F P
0 g
s
.21074 .52335 m .28037 .51151 L .26602 .46425 L p .929 .738 .745 r
F P
0 g
s
.28037 .51151 m .31411 .50038 L .29966 .45288 L p .724 .624 .82 r
F P
0 g
s
.31411 .50038 m .28037 .51151 L .29097 .559 L p .712 .587 .786 r
F P
0 g
s
.28037 .51151 m .21074 .52335 L .21867 .55963 L p .925 .72 .726 r
F P
0 g
s
.21867 .55963 m .29097 .559 L .28037 .51151 L p .925 .72 .726 r
F P
0 g
s
.2609 .36221 m .22723 .37413 L .24819 .41815 L p .744 .694 .884 r
F P
0 g
s
.24819 .41815 m .28182 .40652 L .2609 .36221 L p .744 .694 .884 r
F P
0 g
s
.18609 .45207 m .24819 .41815 L .22723 .37413 L p .941 .775 .775 r
F P
0 g
s
.24819 .41815 m .18609 .45207 L .1998 .48724 L p .934 .756 .761 r
F P
0 g
s
.29097 .559 m .32487 .54808 L .31411 .50038 L p .712 .587 .786 r
F P
0 g
s
.32487 .54808 m .29097 .559 L .29757 .60578 L p .697 .546 .747 r
F P
0 g
s
.29097 .559 m .21867 .55963 L .22339 .59529 L p .922 .703 .706 r
F P
0 g
s
.22339 .59529 m .29757 .60578 L .29097 .559 L p .922 .703 .706 r
F P
0 g
s
.31579 .39476 m .28182 .40652 L .29966 .45288 L p .734 .659 .853 r
F P
0 g
s
.29966 .45288 m .33366 .44139 L .31579 .39476 L p .734 .659 .853 r
F P
0 g
s
.33366 .44139 m .29966 .45288 L .31411 .50038 L p .724 .624 .82 r
F P
0 g
s
.31411 .50038 m .3482 .48913 L .33366 .44139 L p .724 .624 .82 r
F P
0 g
s
.3482 .48913 m .31411 .50038 L .32487 .54808 L p .712 .587 .786 r
F P
0 g
s
.2373 .32088 m .20351 .33309 L .22723 .37413 L p .753 .73 .915 r
F P
0 g
s
.22723 .37413 m .2609 .36221 L .2373 .32088 L p .753 .73 .915 r
F P
0 g
s
.16988 .41861 m .22723 .37413 L .20351 .33309 L p .95 .794 .788 r
F P
0 g
s
.22723 .37413 m .16988 .41861 L .18609 .45207 L p .941 .775 .775 r
F P
0 g
s
.29493 .35017 m .2609 .36221 L .28182 .40652 L p .744 .694 .884 r
F P
0 g
s
.28182 .40652 m .31579 .39476 L .29493 .35017 L p .744 .694 .884 r
F P
0 g
s
.32487 .54808 m .35912 .53705 L .3482 .48913 L p .712 .587 .786 r
F P
0 g
s
.35912 .53705 m .32487 .54808 L .33169 .59504 L p .697 .546 .747 r
F P
0 g
s
.29757 .60578 m .33169 .59504 L .32487 .54808 L p .697 .546 .747 r
F P
0 g
s
.33169 .59504 m .29757 .60578 L .29996 .65088 L p .68 .499 .701 r
F P
0 g
s
.29757 .60578 m .22339 .59529 L .22476 .62955 L p .922 .686 .683 r
F P
0 g
s
.22476 .62955 m .29996 .65088 L .29757 .60578 L p .922 .686 .683 r
F P
0 g
s
.35012 .38289 m .31579 .39476 L .33366 .44139 L p .734 .659 .853 r
F P
0 g
s
.33366 .44139 m .36802 .42978 L .35012 .38289 L p .734 .659 .853 r
F P
0 g
s
.36802 .42978 m .33366 .44139 L .3482 .48913 L p .724 .624 .82 r
F P
0 g
s
.3482 .48913 m .38265 .47777 L .36802 .42978 L p .724 .624 .82 r
F P
0 g
s
.38265 .47777 m .3482 .48913 L .35912 .53705 L p .712 .587 .786 r
F P
0 g
s
.27144 .30853 m .2373 .32088 L .2609 .36221 L p .753 .73 .915 r
F P
0 g
s
.2609 .36221 m .29493 .35017 L .27144 .30853 L p .753 .73 .915 r
F P
0 g
s
.32931 .338 m .29493 .35017 L .31579 .39476 L p .744 .694 .884 r
F P
0 g
s
.31579 .39476 m .35012 .38289 L .32931 .338 L p .744 .694 .884 r
F P
0 g
s
.18609 .45207 m .15253 .46362 L .16623 .49858 L p .732 .659 .854 r
F P
0 g
s
.16623 .49858 m .1998 .48724 L .18609 .45207 L p .732 .659 .854 r
F P
0 g
s
.1998 .48724 m .16623 .49858 L .17709 .53451 L p .721 .622 .821 r
F P
0 g
s
.21143 .28343 m .17746 .29596 L .20351 .33309 L p .761 .768 .946 r
F P
0 g
s
.20351 .33309 m .2373 .32088 L .21143 .28343 L p .761 .768 .946 r
F P
0 g
s
.15151 .3876 m .20351 .33309 L .17746 .29596 L p .96 .814 .799 r
F P
0 g
s
.20351 .33309 m .15151 .3876 L .16988 .41861 L p .95 .794 .788 r
F P
0 g
s
.17709 .53451 m .21074 .52335 L .1998 .48724 L p .721 .622 .821 r
F P
0 g
s
.21074 .52335 m .17709 .53451 L .1849 .57063 L p .709 .584 .785 r
F P
0 g
s
.35912 .53705 m .39374 .5259 L .38265 .47777 L p .712 .587 .786 r
F P
0 g
s
.39374 .5259 m .35912 .53705 L .36617 .58419 L p .697 .546 .747 r
F P
0 g
s
.33169 .59504 m .36617 .58419 L .35912 .53705 L p .697 .546 .747 r
F P
0 g
s
.36617 .58419 m .33169 .59504 L .33437 .6403 L p .68 .499 .701 r
F P
0 g
s
.29996 .65088 m .33437 .6403 L .33169 .59504 L p .68 .499 .701 r
F P
0 g
s
.16988 .41861 m .13629 .43037 L .15253 .46362 L p .742 .695 .886 r
F P
0 g
s
.15253 .46362 m .18609 .45207 L .16988 .41861 L p .742 .695 .886 r
F P
0 g
s
.38482 .37088 m .35012 .38289 L .36802 .42978 L p .734 .659 .853 r
F P
0 g
s
.36802 .42978 m .40273 .41805 L .38482 .37088 L p .734 .659 .853 r
F P
0 g
s
.40273 .41805 m .36802 .42978 L .38265 .47777 L p .724 .624 .82 r
F P
0 g
s
.1849 .57063 m .21867 .55963 L .21074 .52335 L p .709 .584 .785 r
F P
0 g
s
.21867 .55963 m .1849 .57063 L .18946 .60615 L p .694 .541 .744 r
F P
0 g
s
.38265 .47777 m .41746 .46628 L .40273 .41805 L p .724 .624 .82 r
F P
0 g
s
.41746 .46628 m .38265 .47777 L .39374 .5259 L p .712 .587 .786 r
F P
0 g
s
.30594 .29606 m .27144 .30853 L .29493 .35017 L p .753 .73 .915 r
F P
0 g
s
.29493 .35017 m .32931 .338 L .30594 .29606 L p .753 .73 .915 r
F P
0 g
s
.33437 .6403 m .29996 .65088 L .298 .69333 L p .657 .443 .645 r
F P
0 g
s
.29996 .65088 m .22476 .62955 L .22269 .6616 L p .922 .67 .657 r
F P
0 g
s
.22269 .6616 m .298 .69333 L .29996 .65088 L p .922 .67 .657 r
F P
0 g
s
.36405 .32571 m .32931 .338 L .35012 .38289 L p .744 .694 .884 r
F P
0 g
s
.35012 .38289 m .38482 .37088 L .36405 .32571 L p .744 .694 .884 r
F P
0 g
s
.15151 .3876 m .11784 .39958 L .13629 .43037 L p .751 .731 .918 r
F P
0 g
s
.13629 .43037 m .16988 .41861 L .15151 .3876 L p .751 .731 .918 r
F P
0 g
s
.24575 .27077 m .21143 .28343 L .2373 .32088 L p .761 .768 .946 r
F P
0 g
s
.2373 .32088 m .27144 .30853 L .24575 .27077 L p .761 .768 .946 r
F P
0 g
s
.39374 .5259 m .42871 .51463 L .41746 .46628 L p .712 .587 .786 r
F P
0 g
s
.42871 .51463 m .39374 .5259 L .40102 .57323 L p .697 .546 .747 r
F P
0 g
s
.36617 .58419 m .40102 .57323 L .39374 .5259 L p .697 .546 .747 r
F P
0 g
s
.40102 .57323 m .36617 .58419 L .36914 .6296 L p .68 .499 .701 r
F P
0 g
s
.33437 .6403 m .36914 .6296 L .36617 .58419 L p .68 .499 .701 r
F P
0 g
s
.18946 .60615 m .22339 .59529 L .21867 .55963 L p .694 .541 .744 r
F P
0 g
s
.22339 .59529 m .18946 .60615 L .19062 .64029 L p .675 .493 .697 r
F P
0 g
s
.41988 .35875 m .38482 .37088 L .40273 .41805 L p .734 .659 .853 r
F P
0 g
s
.40273 .41805 m .43781 .4062 L .41988 .35875 L p .734 .659 .853 r
F P
0 g
s
.43781 .4062 m .40273 .41805 L .41746 .46628 L p .724 .624 .82 r
F P
0 g
s
.41746 .46628 m .45264 .45467 L .43781 .4062 L p .724 .624 .82 r
F P
0 g
s
.45264 .45467 m .41746 .46628 L .42871 .51463 L p .712 .587 .786 r
F P
0 g
s
.34081 .28345 m .30594 .29606 L .32931 .338 L p .753 .73 .915 r
F P
0 g
s
.32931 .338 m .36405 .32571 L .34081 .28345 L p .753 .73 .915 r
F P
0 g
s
.36914 .6296 m .33437 .6403 L .33275 .68286 L p .657 .443 .645 r
F P
0 g
s
.298 .69333 m .33275 .68286 L .33437 .6403 L p .657 .443 .645 r
F P
0 g
s
.39917 .31328 m .36405 .32571 L .38482 .37088 L p .744 .694 .884 r
F P
0 g
s
.38482 .37088 m .41988 .35875 L .39917 .31328 L p .744 .694 .884 r
F P
0 g
s
.18378 .25078 m .14958 .26363 L .17746 .29596 L p .767 .81 .979 r
F P
0 g
s
.17746 .29596 m .21143 .28343 L .18378 .25078 L p .767 .81 .979 r
F P
0 g
s
.13135 .35977 m .17746 .29596 L .14958 .26363 L p .973 .835 .807 r
F P
0 g
s
.17746 .29596 m .13135 .35977 L .15151 .3876 L p .96 .814 .799 r
F P
0 g
s
.13135 .35977 m .09755 .37199 L .11784 .39958 L p .758 .77 .95 r
F P
0 g
s
.11784 .39958 m .15151 .3876 L .13135 .35977 L p .758 .77 .95 r
F P
0 g
s
.28044 .25798 m .24575 .27077 L .27144 .30853 L p .761 .768 .946 r
F P
0 g
s
.27144 .30853 m .30594 .29606 L .28044 .25798 L p .761 .768 .946 r
F P
0 g
s
.42871 .51463 m .46406 .50324 L .45264 .45467 L p .712 .587 .786 r
F P
0 g
s
.46406 .50324 m .42871 .51463 L .43623 .56214 L p .697 .546 .747 r
F P
0 g
s
.40102 .57323 m .43623 .56214 L .42871 .51463 L p .697 .546 .747 r
F P
0 g
s
.43623 .56214 m .40102 .57323 L .40429 .61878 L p .68 .499 .701 r
F P
0 g
s
.36914 .6296 m .40429 .61878 L .40102 .57323 L p .68 .499 .701 r
F P
0 g
s
.19062 .64029 m .22476 .62955 L .22339 .59529 L p .675 .493 .697 r
F P
0 g
s
.41988 .35875 m .43781 .4062 L p .39468 .28209 L .1 .1 .445 r
F P
0 g
s
.39997 .29579 m .39343 .27848 L p .39468 .28209 L .1 .1 .445 r
F P
0 g
s
.43781 .4062 m .39997 .29579 L p .39468 .28209 L .1 .1 .445 r
F P
0 g
s
.442 .30042 m .43658 .28274 L p .40637 .31238 L .72 .622 .821 r
F P
0 g
s
.39997 .29579 m .43781 .4062 L .45264 .45467 L p .857 .55 .1 r
F P
0 g
s
.40535 .31338 m .39997 .29579 L p .40121 .29953 L .857 .55 .1 r
F P
0 g
s
.45264 .45467 m .40535 .31338 L p .40121 .29953 L .857 .55 .1 r
F P
0 g
s
.39424 .28093 m .41988 .35875 L p .39468 .28209 L .1 .1 .445 r
F P
0 g
s
.39917 .31328 m .41988 .35875 L p .39098 .2764 L .1 .1 .648 r
F P
0 g
s
.38589 .26189 m .38838 .27151 L p .39098 .2764 L .1 .1 .648 r
F P
0 g
s
.38838 .27151 m .39917 .31328 L p .39098 .2764 L .1 .1 .648 r
F P
0 g
s
.44615 .31795 m .442 .30042 L p .41649 .32424 L .707 .582 .784 r
F P
0 g
s
.39343 .27848 m .38589 .26189 L p .39098 .2764 L .1 .1 .648 r
F P
0 g
s
.41988 .35875 m .3956 .28505 L p .39098 .2764 L .1 .1 .648 r
F P
0 g
s
.3956 .28505 m .39343 .27848 L p .39098 .2764 L .1 .1 .648 r
F P
0 g
s
.45264 .45467 m .46406 .50324 L p .40535 .31338 L .983 .687 .174 r
F P
0 g
s
.40944 .33083 m .40535 .31338 L p .40652 .31715 L .983 .687 .174 r
F P
0 g
s
.46406 .50324 m .40944 .33083 L p .40652 .31715 L .983 .687 .174 r
F P
0 g
s
.43623 .56214 m .47182 .55095 L .46406 .50324 L p .697 .546 .747 r
F P
0 g
s
.41213 .34771 m .40944 .33083 L p .4105 .33458 L 1 .768 .316 r
F P
0 g
s
.47182 .55095 m .41213 .34771 L p .4105 .33458 L 1 .768 .316 r
F P
0 g
s
.47182 .55095 m .43623 .56214 L .43981 .60786 L p .68 .499 .701 r
F P
0 g
s
.43981 .60786 m .47571 .59681 L .47182 .55095 L p .68 .499 .701 r
F P
0 g
s
.41335 .36359 m .41213 .34771 L p .41307 .3514 L 1 .811 .415 r
F P
0 g
s
.47571 .59681 m .41335 .36359 L p .41307 .3514 L 1 .811 .415 r
F P
0 g
s
.47571 .59681 m .43981 .60786 L .43926 .65077 L p .657 .443 .645 r
F P
0 g
s
.43926 .65077 m .47554 .63984 L .47571 .59681 L p .657 .443 .645 r
F P
0 g
s
.41306 .37808 m .41335 .36359 L p .41416 .3672 L 1 .833 .482 r
F P
0 g
s
.47554 .63984 m .41306 .37808 L p .41416 .3672 L 1 .833 .482 r
F P
0 g
s
.47554 .63984 m .43926 .65077 L .43449 .68988 L p .626 .372 .573 r
F P
0 g
s
.43449 .68988 m .47119 .67903 L .47554 .63984 L p .626 .372 .573 r
F P
0 g
s
.41124 .3908 m .41306 .37808 L p .41374 .3816 L 1 .843 .529 r
F P
0 g
s
.47119 .67903 m .41124 .3908 L p .41374 .3816 L 1 .843 .529 r
F P
0 g
s
.40429 .61878 m .43981 .60786 L .43623 .56214 L p .68 .499 .701 r
F P
0 g
s
.47119 .67903 m .43449 .68988 L .42542 .72416 L p .579 .276 .473 r
F P
0 g
s
.42542 .72416 m .4626 .71334 L .47119 .67903 L p .579 .276 .473 r
F P
0 g
s
.40792 .40138 m .41124 .3908 L p .41178 .39421 L 1 .847 .562 r
F P
0 g
s
.4626 .71334 m .40792 .40138 L p .41178 .39421 L 1 .847 .562 r
F P
0 g
s
.43981 .60786 m .40429 .61878 L .40338 .66158 L p .657 .443 .645 r
F P
0 g
s
.40338 .66158 m .43926 .65077 L .43981 .60786 L p .657 .443 .645 r
F P
0 g
s
.43926 .65077 m .40338 .66158 L .39818 .70061 L p .626 .372 .573 r
F P
0 g
s
.39818 .70061 m .43449 .68988 L .43926 .65077 L p .626 .372 .573 r
F P
0 g
s
.4626 .71334 m .42542 .72416 L .4121 .75259 L p .505 .139 .326 r
F P
0 g
s
.4121 .75259 m .44979 .74177 L .4626 .71334 L p .505 .139 .326 r
F P
0 g
s
.40317 .40953 m .40792 .40138 L p .40833 .4047 L 1 .847 .586 r
F P
0 g
s
.40429 .61878 m .36914 .6296 L .36788 .67228 L p .657 .443 .645 r
F P
0 g
s
.36788 .67228 m .40338 .66158 L .40429 .61878 L p .657 .443 .645 r
F P
0 g
s
.43449 .68988 m .39818 .70061 L .38865 .73485 L p .579 .276 .473 r
F P
0 g
s
.38865 .73485 m .42542 .72416 L .43449 .68988 L p .579 .276 .473 r
F P
0 g
s
.42542 .72416 m .38865 .73485 L .37482 .7633 L p .505 .139 .326 r
F P
0 g
s
.37482 .7633 m .4121 .75259 L .42542 .72416 L p .505 .139 .326 r
F P
0 g
s
.4121 .75259 m .37482 .7633 L .35684 .78496 L p .377 .1 .1 r
F P
0 g
s
.44979 .74177 m .4121 .75259 L .39464 .7742 L p .377 .1 .1 r
F P
0 g
s
.35684 .78496 m .39464 .7742 L .4121 .75259 L p .377 .1 .1 r
F P
0 g
s
.39464 .7742 m .43287 .76331 L .44979 .74177 L p .377 .1 .1 r
F P
0 g
s
.38981 .41758 m .39709 .415 L p .39722 .41809 L 1 .842 .617 r
F P
0 g
s
.43287 .76331 m .39464 .7742 L .3733 .78806 L p .154 .1 .1 r
F P
0 g
s
.3733 .78806 m .41208 .77707 L .43287 .76331 L p .154 .1 .1 r
F P
0 g
s
.41208 .77707 m .38981 .41758 L p .39722 .41809 L 1 .842 .617 r
F P
0 g
s
.38981 .41758 m .38152 .41716 L p .38195 .41704 L .58 .991 1 r
F P
0 g
s
.39709 .415 m .38981 .41758 L p .39122 .4171 L .1 .1 .1 r
F P
0 g
s
.44979 .74177 m .40361 .41268 L p .40907 .41073 L 1 .847 .586 r
F P
0 g
s
.40944 .33083 m .46406 .50324 L .47182 .55095 L p 1 .768 .316 r
F P
0 g
s
.41213 .34771 m .47182 .55095 L .47571 .59681 L p 1 .811 .415 r
F P
0 g
s
.41335 .36359 m .47571 .59681 L .47554 .63984 L p 1 .833 .482 r
F P
0 g
s
.41306 .37808 m .47554 .63984 L .47119 .67903 L p 1 .843 .529 r
F P
0 g
s
.41124 .3908 m .47119 .67903 L .4626 .71334 L p 1 .847 .562 r
F P
0 g
s
.4626 .71334 m .44979 .74177 L p .40833 .4047 L 1 .847 .586 r
F P
0 g
s
.40792 .40138 m .40848 .40456 L p .40833 .4047 L 1 .847 .586 r
F P
0 g
s
.40848 .40456 m .4626 .71334 L p .40833 .4047 L 1 .847 .586 r
F P
0 g
s
.40907 .41073 m .40317 .40953 L .40833 .4047 L 1 .847 .586 r
F
.40361 .41268 m .40317 .40953 L p .40907 .41073 L F P
0 g
s
.44979 .74177 m .43287 .76331 L p .40394 .41869 L 1 .845 .604 r
F P
0 g
s
.40317 .40953 m .40446 .41873 L p .40394 .41869 L 1 .845 .604 r
F P
0 g
s
.40446 .41873 m .44979 .74177 L p .40394 .41869 L 1 .845 .604 r
F P
0 g
s
.38195 .41704 m .38287 .4168 L .38981 .41758 L .58 .991 1 r
F
.39709 .415 m .40317 .40953 L p .40344 .41274 L 1 .845 .604 r
F P
0 g
s
.43287 .76331 m .39709 .415 L p .40344 .41274 L 1 .845 .604 r
F P
0 g
s
.39709 .415 m .43287 .76331 L .41208 .77707 L p 1 .842 .617 r
F P
0 g
s
.42775 .40473 m .43484 .40221 L p .39026 .41743 L .1 .1 .1 r
F P
0 g
s
.38981 .41758 m .39019 .41745 L p .39026 .41743 L .1 .1 .1 r
F P
0 g
s
.39019 .41745 m .42775 .40473 L p .39026 .41743 L .1 .1 .1 r
F P
0 g
s
.43484 .40221 m .44074 .39679 L p .39755 .41481 L .199 .1 .1 r
F P
0 g
s
.39709 .415 m .39749 .41486 L p .39755 .41481 L .199 .1 .1 r
F P
0 g
s
.39749 .41486 m .43484 .40221 L p .39755 .41481 L .199 .1 .1 r
F P
0 g
s
.43484 .40221 m .42605 .40519 L p .42637 .4051 L .1 .1 .1 r
F P
0 g
s
.42605 .40519 m .39749 .41486 L p .42637 .4051 L .1 .1 .1 r
F P
0 g
s
.39122 .4171 m .42637 .4051 L .39749 .41486 L .1 .1 .1 r
F
.39749 .41486 m .39709 .415 L p .39122 .4171 L F P
0 g
s
.40317 .40953 m .39709 .415 L p .39755 .41481 L .199 .1 .1 r
F P
0 g
s
.44074 .39679 m .40317 .40953 L p .39755 .41481 L .199 .1 .1 r
F P
0 g
s
.42775 .40473 m .39019 .41745 L p .38287 .4168 L .58 .991 1 r
F P
0 g
s
.39019 .41745 m .38981 .41758 L p .38287 .4168 L .58 .991 1 r
F P
0 g
s
.40792 .40138 m .40317 .40953 L p .40366 .40929 L .411 .1 .198 r
F P
0 g
s
.44531 .38866 m .40792 .40138 L p .40366 .40929 L .411 .1 .198 r
F P
0 g
s
.41124 .3908 m .40792 .40138 L p .40844 .40108 L .529 .202 .407 r
F P
0 g
s
.44845 .37808 m .41124 .3908 L p .40844 .40108 L .529 .202 .407 r
F P
0 g
s
.41306 .37808 m .41124 .3908 L p .4118 .39043 L .597 .329 .538 r
F P
0 g
s
.45012 .36536 m .41306 .37808 L p .4118 .39043 L .597 .329 .538 r
F P
0 g
s
.41335 .36359 m .41306 .37808 L p .41367 .37763 L .639 .418 .627 r
F P
0 g
s
.45027 .35083 m .41335 .36359 L p .41367 .37763 L .639 .418 .627 r
F P
0 g
s
.41213 .34771 m .41335 .36359 L p .41403 .36304 L .669 .484 .692 r
F P
0 g
s
.44894 .3349 m .41213 .34771 L p .41403 .36304 L .669 .484 .692 r
F P
0 g
s
.40944 .33083 m .41213 .34771 L p .4129 .34703 L .69 .537 .742 r
F P
0 g
s
.44615 .31795 m .40944 .33083 L p .4129 .34703 L .69 .537 .742 r
F P
0 g
s
.41032 .33001 m .41649 .32424 L .40535 .31338 L .707 .582 .784 r
F
.442 .30042 m .40985 .31179 L p .41649 .32424 L F P
0 g
s
.40985 .31179 m .40535 .31338 L p .41649 .32424 L .707 .582 .784 r
F P
0 g
s
.40944 .33083 m .41834 .32771 L p .41649 .32424 L .707 .582 .784 r
F P
0 g
s
.41834 .32771 m .44615 .31795 L p .41649 .32424 L .707 .582 .784 r
F P
0 g
s
.40535 .31338 m .40944 .33083 L p .41032 .33001 L .707 .582 .784 r
F P
0 g
s
.40535 .31338 m .40659 .31294 L p .40637 .31238 L .72 .622 .821 r
F P
0 g
s
.40659 .31294 m .442 .30042 L p .40637 .31238 L .72 .622 .821 r
F P
0 g
s
.39997 .29579 m .40535 .31338 L p .40637 .31238 L .72 .622 .821 r
F P
0 g
s
.43658 .28274 m .39997 .29579 L p .40637 .31238 L .72 .622 .821 r
F P
0 g
s
.39343 .27848 m .39424 .28093 L p .39468 .28209 L .1 .1 .445 r
F P
0 g
s
.22476 .62955 m .19062 .64029 L .18829 .67225 L p .651 .434 .639 r
F P
0 g
s
.33275 .68286 m .298 .69333 L .2916 .73212 L p .626 .372 .573 r
F P
0 g
s
.298 .69333 m .22269 .6616 L .21715 .69066 L p .925 .653 .628 r
F P
0 g
s
.21715 .69066 m .2916 .73212 L .298 .69333 L p .925 .653 .628 r
F P
0 g
s
.37605 .27071 m .34081 .28345 L .36405 .32571 L p .753 .73 .915 r
F P
0 g
s
.36405 .32571 m .39917 .31328 L .37605 .27071 L p .753 .73 .915 r
F P
0 g
s
.33275 .68286 m .36788 .67228 L .36914 .6296 L p .657 .443 .645 r
F P
0 g
s
.21836 .2378 m .18378 .25078 L .21143 .28343 L p .767 .81 .979 r
F P
0 g
s
.21143 .28343 m .24575 .27077 L .21836 .2378 L p .767 .81 .979 r
F P
0 g
s
.31551 .24505 m .28044 .25798 L .30594 .29606 L p .761 .768 .946 r
F P
0 g
s
.30594 .29606 m .34081 .28345 L .31551 .24505 L p .761 .768 .946 r
F P
0 g
s
.10982 .33582 m .07584 .34827 L .09755 .37199 L p .765 .813 .984 r
F P
0 g
s
.09755 .37199 m .13135 .35977 L .10982 .33582 L p .765 .813 .984 r
F P
0 g
s
.18829 .67225 m .22269 .6616 L .22476 .62955 L p .651 .434 .639 r
F P
0 g
s
.36788 .67228 m .33275 .68286 L .32674 .72173 L p .626 .372 .573 r
F P
0 g
s
.2916 .73212 m .32674 .72173 L .33275 .68286 L p .626 .372 .573 r
F P
0 g
s
.37753 .24642 m .37605 .27071 L .39917 .31328 L p .1 .248 .791 r
F P
0 g
s
.39917 .31328 m .38589 .26189 L .37753 .24642 L p .1 .248 .791 r
F P
0 g
s
.2533 .22468 m .21836 .2378 L .24575 .27077 L p .767 .81 .979 r
F P
0 g
s
.24575 .27077 m .28044 .25798 L .2533 .22468 L p .767 .81 .979 r
F P
0 g
s
.22269 .6616 m .18829 .67225 L .18246 .70126 L p .617 .358 .562 r
F P
0 g
s
.14958 .26363 m .10982 .33582 L .13135 .35977 L p .973 .835 .807 r
F P
0 g
s
.35095 .23198 m .31551 .24505 L .34081 .28345 L p .761 .768 .946 r
F P
0 g
s
.34081 .28345 m .37605 .27071 L .35095 .23198 L p .761 .768 .946 r
F P
0 g
s
.40338 .66158 m .36788 .67228 L .36227 .71123 L p .626 .372 .573 r
F P
0 g
s
.32674 .72173 m .36227 .71123 L .36788 .67228 L p .626 .372 .573 r
F P
0 g
s
.28863 .21142 m .2533 .22468 L .28044 .25798 L p .767 .81 .979 r
F P
0 g
s
.28044 .25798 m .31551 .24505 L .28863 .21142 L p .767 .81 .979 r
F P
0 g
s
.18246 .70126 m .21715 .69066 L .22269 .6616 L p .617 .358 .562 r
F P
0 g
s
.32674 .72173 m .2916 .73212 L .28073 .76625 L p .579 .276 .473 r
F P
0 g
s
.2916 .73212 m .21715 .69066 L .20817 .71597 L p .929 .636 .595 r
F P
0 g
s
.20817 .71597 m .28073 .76625 L .2916 .73212 L p .929 .636 .595 r
F P
0 g
s
.36855 .23247 m .35095 .23198 L .37605 .27071 L p .1 .369 .875 r
F P
0 g
s
.37605 .27071 m .37753 .24642 L .36855 .23247 L p .1 .369 .875 r
F P
0 g
s
.21715 .69066 m .18246 .70126 L .17317 .72653 L p .566 .256 .455 r
F P
0 g
s
.36227 .71123 m .39818 .70061 L .40338 .66158 L p .626 .372 .573 r
F P
0 g
s
.32434 .19801 m .28863 .21142 L .31551 .24505 L p .767 .81 .979 r
F P
0 g
s
.31551 .24505 m .35095 .23198 L .32434 .19801 L p .767 .81 .979 r
F P
0 g
s
.36227 .71123 m .32674 .72173 L .31631 .7559 L p .579 .276 .473 r
F P
0 g
s
.28073 .76625 m .31631 .7559 L .32674 .72173 L p .579 .276 .473 r
F P
0 g
s
.17317 .72653 m .20817 .71597 L .21715 .69066 L p .566 .256 .455 r
F P
0 g
s
.35917 .2204 m .32434 .19801 L .35095 .23198 L p .1 .42 .907 r
F P
0 g
s
.35095 .23198 m .36855 .23247 L .35917 .2204 L p .1 .42 .907 r
F P
0 g
s
.39818 .70061 m .36227 .71123 L .35228 .74543 L p .579 .276 .473 r
F P
0 g
s
.31631 .7559 m .35228 .74543 L .36227 .71123 L p .579 .276 .473 r
F P
0 g
s
.31631 .7559 m .28073 .76625 L .26547 .7947 L p .505 .139 .326 r
F P
0 g
s
.28073 .76625 m .20817 .71597 L .19586 .73677 L p .934 .619 .557 r
F P
0 g
s
.19586 .73677 m .26547 .7947 L .28073 .76625 L p .934 .619 .557 r
F P
0 g
s
.20817 .71597 m .17317 .72653 L .16052 .74734 L p .483 .106 .294 r
F P
0 g
s
.35228 .74543 m .38865 .73485 L .39818 .70061 L p .579 .276 .473 r
F P
0 g
s
.35228 .74543 m .31631 .7559 L .30152 .78435 L p .505 .139 .326 r
F P
0 g
s
.26547 .7947 m .30152 .78435 L .31631 .7559 L p .505 .139 .326 r
F P
0 g
s
.16052 .74734 m .19586 .73677 L .20817 .71597 L p .483 .106 .294 r
F P
0 g
s
.43004 .26533 m .39343 .27848 L .39997 .29579 L p .732 .659 .854 r
F P
0 g
s
.39997 .29579 m .43658 .28274 L .43004 .26533 L p .732 .659 .854 r
F P
0 g
s
.38865 .73485 m .35228 .74543 L .33797 .77388 L p .505 .139 .326 r
F P
0 g
s
.30152 .78435 m .33797 .77388 L .35228 .74543 L p .505 .139 .326 r
F P
0 g
s
.42252 .24862 m .38589 .26189 L .39343 .27848 L p .742 .695 .886 r
F P
0 g
s
.39343 .27848 m .43004 .26533 L .42252 .24862 L p .742 .695 .886 r
F P
0 g
s
.19586 .73677 m .16052 .74734 L .14473 .763 L p .337 .1 .1 r
F P
0 g
s
.41421 .23303 m .37753 .24642 L .38589 .26189 L p .751 .731 .917 r
F P
0 g
s
.38589 .26189 m .42252 .24862 L .41421 .23303 L p .751 .731 .917 r
F P
0 g
s
.41213 .34771 m .44894 .3349 L .44615 .31795 L p .69 .537 .742 r
F P
0 g
s
.30152 .78435 m .26547 .7947 L .24598 .81652 L p .377 .1 .1 r
F P
0 g
s
.26547 .7947 m .19586 .73677 L .18042 .75238 L p .941 .602 .513 r
F P
0 g
s
.18042 .75238 m .24598 .81652 L .26547 .7947 L p .941 .602 .513 r
F P
0 g
s
.4053 .21896 m .36855 .23247 L .37753 .24642 L p .759 .77 .949 r
F P
0 g
s
.37753 .24642 m .41421 .23303 L .4053 .21896 L p .759 .77 .949 r
F P
0 g
s
.46705 .25202 m .43004 .26533 L .43658 .28274 L p .732 .659 .854 r
F P
0 g
s
.43658 .28274 m .47361 .26954 L .46705 .25202 L p .732 .659 .854 r
F P
0 g
s
.47361 .26954 m .43658 .28274 L .442 .30042 L p .72 .622 .821 r
F P
0 g
s
.442 .30042 m .47906 .28732 L .47361 .26954 L p .72 .622 .821 r
F P
0 g
s
.47906 .28732 m .442 .30042 L .44615 .31795 L p .707 .582 .784 r
F P
0 g
s
.33797 .77388 m .37482 .7633 L .38865 .73485 L p .505 .139 .326 r
F P
0 g
s
.45955 .2352 m .42252 .24862 L .43004 .26533 L p .742 .695 .886 r
F P
0 g
s
.43004 .26533 m .46705 .25202 L .45955 .2352 L p .742 .695 .886 r
F P
0 g
s
.41335 .36359 m .45027 .35083 L .44894 .3349 L p .669 .484 .692 r
F P
0 g
s
.14473 .763 m .18042 .75238 L .19586 .73677 L p .337 .1 .1 r
F P
0 g
s
.44615 .31795 m .48328 .30493 L .47906 .28732 L p .707 .582 .784 r
F P
0 g
s
.48328 .30493 m .44615 .31795 L .44894 .3349 L p .69 .537 .742 r
F P
0 g
s
.45129 .21949 m .41421 .23303 L .42252 .24862 L p .751 .731 .917 r
F P
0 g
s
.42252 .24862 m .45955 .2352 L .45129 .21949 L p .751 .731 .917 r
F P
0 g
s
.39602 .20676 m .35917 .2204 L .36855 .23247 L p .766 .812 .982 r
F P
0 g
s
.36855 .23247 m .4053 .21896 L .39602 .20676 L p .766 .812 .982 r
F P
0 g
s
.44894 .3349 m .48615 .32194 L .48328 .30493 L p .69 .537 .742 r
F P
0 g
s
.48615 .32194 m .44894 .3349 L .45027 .35083 L p .669 .484 .692 r
F P
0 g
s
.41306 .37808 m .45012 .36536 L .45027 .35083 L p .639 .418 .627 r
F P
0 g
s
.33797 .77388 m .30152 .78435 L .28252 .80612 L p .377 .1 .1 r
F P
0 g
s
.24598 .81652 m .28252 .80612 L .30152 .78435 L p .377 .1 .1 r
F P
0 g
s
.44247 .20529 m .4053 .21896 L .41421 .23303 L p .759 .77 .949 r
F P
0 g
s
.41421 .23303 m .45129 .21949 L .44247 .20529 L p .759 .77 .949 r
F P
0 g
s
.50448 .23857 m .46705 .25202 L .47361 .26954 L p .732 .659 .854 r
F P
0 g
s
.47361 .26954 m .51104 .25619 L .50448 .23857 L p .732 .659 .854 r
F P
0 g
s
.51104 .25619 m .47361 .26954 L .47906 .28732 L p .72 .622 .821 r
F P
0 g
s
.47906 .28732 m .51653 .27407 L .51104 .25619 L p .72 .622 .821 r
F P
0 g
s
.51653 .27407 m .47906 .28732 L .48328 .30493 L p .707 .582 .784 r
F P
0 g
s
.497 .22163 m .45955 .2352 L .46705 .25202 L p .742 .695 .886 r
F P
0 g
s
.46705 .25202 m .50448 .23857 L .497 .22163 L p .742 .695 .886 r
F P
0 g
s
.45027 .35083 m .48761 .33793 L .48615 .32194 L p .669 .484 .692 r
F P
0 g
s
.48761 .33793 m .45027 .35083 L .45012 .36536 L p .639 .418 .627 r
F P
0 g
s
.48328 .30493 m .52081 .29177 L .51653 .27407 L p .707 .582 .784 r
F P
0 g
s
.52081 .29177 m .48328 .30493 L .48615 .32194 L p .69 .537 .742 r
F P
0 g
s
.18042 .75238 m .14473 .763 L .1261 .77289 L p .1 .1 .1 r
F P
0 g
s
.48879 .2058 m .45129 .21949 L .45955 .2352 L p .751 .731 .917 r
F P
0 g
s
.45955 .2352 m .497 .22163 L .48879 .2058 L p .751 .731 .917 r
F P
0 g
s
.43329 .19297 m .39602 .20676 L .4053 .21896 L p .766 .812 .982 r
F P
0 g
s
.4053 .21896 m .44247 .20529 L .43329 .19297 L p .766 .812 .982 r
F P
0 g
s
.48615 .32194 m .52379 .30885 L .52081 .29177 L p .69 .537 .742 r
F P
0 g
s
.52379 .30885 m .48615 .32194 L .48761 .33793 L p .669 .484 .692 r
F P
0 g
s
.41124 .3908 m .44845 .37808 L .45012 .36536 L p .597 .329 .538 r
F P
0 g
s
.45012 .36536 m .48759 .35249 L .48761 .33793 L p .639 .418 .627 r
F P
0 g
s
.48759 .35249 m .45012 .36536 L .44845 .37808 L p .597 .329 .538 r
F P
0 g
s
.37482 .7633 m .33797 .77388 L .31947 .7956 L p .377 .1 .1 r
F P
0 g
s
.28252 .80612 m .31947 .7956 L .33797 .77388 L p .377 .1 .1 r
F P
0 g
s
.48005 .19147 m .44247 .20529 L .45129 .21949 L p .759 .77 .949 r
F P
0 g
s
.45129 .21949 m .48879 .2058 L .48005 .19147 L p .759 .77 .949 r
F P
0 g
s
.54232 .22497 m .50448 .23857 L .51104 .25619 L p .732 .659 .854 r
F P
0 g
s
.51104 .25619 m .54889 .2427 L .54232 .22497 L p .732 .659 .854 r
F P
0 g
s
.54889 .2427 m .51104 .25619 L .51653 .27407 L p .72 .622 .821 r
F P
0 g
s
.51653 .27407 m .55442 .26068 L .54889 .2427 L p .72 .622 .821 r
F P
0 g
s
.55442 .26068 m .51653 .27407 L .52081 .29177 L p .707 .582 .784 r
F P
0 g
s
.53487 .20791 m .497 .22163 L .50448 .23857 L p .742 .695 .886 r
F P
0 g
s
.50448 .23857 m .54232 .22497 L .53487 .20791 L p .742 .695 .886 r
F P
0 g
s
.48761 .33793 m .52536 .32488 L .52379 .30885 L p .669 .484 .692 r
F P
0 g
s
.52536 .32488 m .48761 .33793 L .48759 .35249 L p .639 .418 .627 r
F P
0 g
s
.52081 .29177 m .55877 .27846 L .55442 .26068 L p .707 .582 .784 r
F P
0 g
s
.55877 .27846 m .52081 .29177 L .52379 .30885 L p .69 .537 .742 r
F P
0 g
s
.24598 .81652 m .18042 .75238 L .16214 .76219 L p .949 .585 .462 r
F P
0 g
s
.1261 .77289 m .16214 .76219 L p .17634 .75392 L .1 .1 .1 r
F P
0 g
s
.16214 .76219 m .1261 .77289 L .10504 .77654 L p .409 .9 .898 r
F P
0 g
s
.14142 .76572 m .16214 .76219 L p .15785 .76327 L .409 .9 .898 r
F P
0 g
s
.10504 .77654 m .14142 .76572 L p .15785 .76327 L .409 .9 .898 r
F P
0 g
s
.14142 .76572 m .10504 .77654 L .08204 .77359 L p .614 .987 1 r
F P
0 g
s
.11875 .76262 m .14142 .76572 L p .13695 .76631 L .614 .987 1 r
F P
0 g
s
.08204 .77359 m .11875 .76262 L p .13695 .76631 L .614 .987 1 r
F P
0 g
s
.09472 .75273 m .11875 .76262 L p .11416 .76271 L .703 .957 1 r
F P
0 g
s
.05772 .76388 m .09472 .75273 L p .11416 .76271 L .703 .957 1 r
F P
0 g
s
.03278 .74748 m .07004 .7361 L .09472 .75273 L p .734 .898 1 r
F P
0 g
s
.09472 .75273 m .07004 .7361 L p .07484 .7425 L .965 .517 .193 r
F P
0 g
s
.11875 .76262 m .08204 .77359 L .05772 .76388 L p .703 .957 1 r
F P
0 g
s
.09472 .75273 m .05772 .76388 L .03278 .74748 L p .734 .898 1 r
F P
0 g
s
.13403 .82146 m .09472 .75273 L p .07484 .7425 L .965 .517 .193 r
F P
0 g
s
.11875 .76262 m .09472 .75273 L p .10009 .75883 L .967 .532 .267 r
F P
0 g
s
.16592 .83376 m .11875 .76262 L p .10009 .75883 L .967 .532 .267 r
F P
0 g
s
.14142 .76572 m .11875 .76262 L p .12458 .76823 L .964 .55 .339 r
F P
0 g
s
.19569 .83674 m .14142 .76572 L p .12458 .76823 L .964 .55 .339 r
F P
0 g
s
.16214 .76219 m .14142 .76572 L p .14759 .77067 L .957 .567 .404 r
F P
0 g
s
.22258 .8308 m .16214 .76219 L p .14759 .77067 L .957 .567 .404 r
F P
0 g
s
.16214 .76219 m .18042 .75238 L p .17634 .75392 L .1 .1 .1 r
F P
0 g
s
.52672 .19195 m .48879 .2058 L .497 .22163 L p .751 .731 .917 r
F P
0 g
s
.497 .22163 m .53487 .20791 L .52672 .19195 L p .751 .731 .917 r
F P
0 g
s
.40792 .40138 m .44531 .38866 L .44845 .37808 L p .529 .202 .407 r
F P
0 g
s
.47098 .17902 m .43329 .19297 L .44247 .20529 L p .766 .812 .982 r
F P
0 g
s
.44247 .20529 m .48005 .19147 L .47098 .17902 L p .766 .812 .982 r
F P
0 g
s
.52379 .30885 m .56184 .2956 L .55877 .27846 L p .69 .537 .742 r
F P
0 g
s
.56184 .2956 m .52379 .30885 L .52536 .32488 L p .669 .484 .692 r
F P
0 g
s
.44845 .37808 m .48609 .36523 L .48759 .35249 L p .597 .329 .538 r
F P
0 g
s
.48609 .36523 m .44845 .37808 L .44531 .38866 L p .529 .202 .407 r
F P
0 g
s
.28252 .80612 m .24598 .81652 L .22258 .8308 L p .154 .1 .1 r
F P
0 g
s
.16214 .76219 m .22258 .8308 L .24598 .81652 L p .949 .585 .462 r
F P
0 g
s
.48759 .35249 m .52549 .33947 L .52536 .32488 L p .639 .418 .627 r
F P
0 g
s
.52549 .33947 m .48759 .35249 L .48609 .36523 L p .597 .329 .538 r
F P
0 g
s
.31947 .7956 m .35684 .78496 L .37482 .7633 L p .377 .1 .1 r
F P
0 g
s
.51805 .17749 m .48005 .19147 L .48879 .2058 L p .759 .77 .949 r
F P
0 g
s
.48879 .2058 m .52672 .19195 L .51805 .17749 L p .759 .77 .949 r
F P
0 g
s
.58059 .21121 m .54232 .22497 L .54889 .2427 L p .732 .659 .854 r
F P
0 g
s
.54889 .2427 m .58717 .22905 L .58059 .21121 L p .732 .659 .854 r
F P
0 g
s
.58717 .22905 m .54889 .2427 L .55442 .26068 L p .72 .622 .821 r
F P
0 g
s
.55442 .26068 m .59274 .24713 L .58717 .22905 L p .72 .622 .821 r
F P
0 g
s
.59274 .24713 m .55442 .26068 L .55877 .27846 L p .707 .582 .784 r
F P
0 g
s
.57317 .19403 m .53487 .20791 L .54232 .22497 L p .742 .695 .886 r
F P
0 g
s
.54232 .22497 m .58059 .21121 L .57317 .19403 L p .742 .695 .886 r
F P
0 g
s
.52536 .32488 m .56354 .31169 L .56184 .2956 L p .669 .484 .692 r
F P
0 g
s
.56354 .31169 m .52536 .32488 L .52549 .33947 L p .639 .418 .627 r
F P
0 g
s
.55877 .27846 m .59716 .26499 L .59274 .24713 L p .707 .582 .784 r
F P
0 g
s
.59716 .26499 m .55877 .27846 L .56184 .2956 L p .69 .537 .742 r
F P
0 g
s
.56507 .17794 m .52672 .19195 L .53487 .20791 L p .751 .731 .917 r
F P
0 g
s
.53487 .20791 m .57317 .19403 L .56507 .17794 L p .751 .731 .917 r
F P
0 g
s
.40317 .40953 m .44074 .39679 L .44531 .38866 L p .411 .1 .198 r
F P
0 g
s
.44531 .38866 m .48312 .3758 L .48609 .36523 L p .529 .202 .407 r
F P
0 g
s
.48312 .3758 m .44531 .38866 L .44074 .39679 L p .411 .1 .198 r
F P
0 g
s
.5091 .16491 m .47098 .17902 L .48005 .19147 L p .766 .812 .982 r
F P
0 g
s
.48005 .19147 m .51805 .17749 L .5091 .16491 L p .766 .812 .982 r
F P
0 g
s
.56184 .2956 m .60033 .28221 L .59716 .26499 L p .69 .537 .742 r
F P
0 g
s
.60033 .28221 m .56184 .2956 L .56354 .31169 L p .669 .484 .692 r
F P
0 g
s
.48609 .36523 m .52415 .35223 L .52549 .33947 L p .597 .329 .538 r
F P
0 g
s
.52415 .35223 m .48609 .36523 L .48312 .3758 L p .529 .202 .407 r
F P
0 g
s
.31947 .7956 m .28252 .80612 L .25961 .8203 L p .154 .1 .1 r
F P
0 g
s
.22258 .8308 m .25961 .8203 L .28252 .80612 L p .154 .1 .1 r
F P
0 g
s
.52549 .33947 m .56381 .32631 L .56354 .31169 L p .639 .418 .627 r
F P
0 g
s
.56381 .32631 m .52549 .33947 L .52415 .35223 L p .597 .329 .538 r
F P
0 g
s
.55649 .16335 m .51805 .17749 L .52672 .19195 L p .759 .77 .949 r
F P
0 g
s
.52672 .19195 m .56507 .17794 L .55649 .16335 L p .759 .77 .949 r
F P
0 g
s
.6193 .1973 m .58059 .21121 L .58717 .22905 L p .732 .659 .854 r
F P
0 g
s
.58717 .22905 m .62588 .21525 L .6193 .1973 L p .732 .659 .854 r
F P
0 g
s
.62588 .21525 m .58717 .22905 L .59274 .24713 L p .72 .622 .821 r
F P
0 g
s
.59274 .24713 m .63149 .23343 L .62588 .21525 L p .72 .622 .821 r
F P
0 g
s
.63149 .23343 m .59274 .24713 L .59716 .26499 L p .707 .582 .784 r
F P
0 g
s
.6119 .18 m .57317 .19403 L .58059 .21121 L p .742 .695 .886 r
F P
0 g
s
.58059 .21121 m .6193 .1973 L .6119 .18 L p .742 .695 .886 r
F P
0 g
s
.56354 .31169 m .60215 .29835 L .60033 .28221 L p .669 .484 .692 r
F P
0 g
s
.60215 .29835 m .56354 .31169 L .56381 .32631 L p .639 .418 .627 r
F P
0 g
s
.59716 .26499 m .63598 .25138 L .63149 .23343 L p .707 .582 .784 r
F P
0 g
s
.63598 .25138 m .59716 .26499 L .60033 .28221 L p .69 .537 .742 r
F P
0 g
s
.60386 .16378 m .56507 .17794 L .57317 .19403 L p .751 .731 .917 r
F P
0 g
s
.57317 .19403 m .6119 .18 L .60386 .16378 L p .751 .731 .917 r
F P
0 g
s
.44074 .39679 m .47873 .38391 L .48312 .3758 L p .411 .1 .198 r
F P
0 g
s
.47873 .38391 m .44074 .39679 L .43484 .40221 L p .199 .1 .1 r
F P
0 g
s
.48312 .3758 m .52135 .36279 L .52415 .35223 L p .529 .202 .407 r
F P
0 g
s
.52135 .36279 m .48312 .3758 L .47873 .38391 L p .411 .1 .198 r
F P
0 g
s
.54765 .15064 m .5091 .16491 L .51805 .17749 L p .766 .812 .982 r
F P
0 g
s
.51805 .17749 m .55649 .16335 L .54765 .15064 L p .766 .812 .982 r
F P
0 g
s
.60033 .28221 m .63925 .26866 L .63598 .25138 L p .69 .537 .742 r
F P
0 g
s
.63925 .26866 m .60033 .28221 L .60215 .29835 L p .669 .484 .692 r
F P
0 g
s
.52415 .35223 m .56264 .33908 L .56381 .32631 L p .597 .329 .538 r
F P
0 g
s
.56264 .33908 m .52415 .35223 L .52135 .36279 L p .529 .202 .407 r
F P
0 g
s
.35684 .78496 m .31947 .7956 L .29707 .80968 L p .154 .1 .1 r
F P
0 g
s
.25961 .8203 m .29707 .80968 L .31947 .7956 L p .154 .1 .1 r
F P
0 g
s
.56381 .32631 m .60258 .313 L .60215 .29835 L p .639 .418 .627 r
F P
0 g
s
.60258 .313 m .56381 .32631 L .56264 .33908 L p .597 .329 .538 r
F P
0 g
s
.59537 .14906 m .55649 .16335 L .56507 .17794 L p .759 .77 .949 r
F P
0 g
s
.56507 .17794 m .60386 .16378 L .59537 .14906 L p .759 .77 .949 r
F P
0 g
s
.65845 .18323 m .6193 .1973 L .62588 .21525 L p .732 .659 .854 r
F P
0 g
s
.62588 .21525 m .66504 .2013 L .65845 .18323 L p .732 .659 .854 r
F P
0 g
s
.66504 .2013 m .62588 .21525 L .63149 .23343 L p .72 .622 .821 r
F P
0 g
s
.63149 .23343 m .67068 .21957 L .66504 .2013 L p .72 .622 .821 r
F P
0 g
s
.67068 .21957 m .63149 .23343 L .63598 .25138 L p .707 .582 .784 r
F P
0 g
s
.65107 .1658 m .6119 .18 L .6193 .1973 L p .742 .695 .886 r
F P
0 g
s
.6193 .1973 m .65845 .18323 L .65107 .1658 L p .742 .695 .886 r
F P
0 g
s
.60215 .29835 m .6412 .28485 L .63925 .26866 L p .669 .484 .692 r
F P
0 g
s
.6412 .28485 m .60215 .29835 L .60258 .313 L p .639 .418 .627 r
F P
0 g
s
.63598 .25138 m .67525 .23761 L .67068 .21957 L p .707 .582 .784 r
F P
0 g
s
.67525 .23761 m .63598 .25138 L .63925 .26866 L p .69 .537 .742 r
F P
0 g
s
.64309 .14945 m .60386 .16378 L .6119 .18 L p .751 .731 .917 r
F P
0 g
s
.6119 .18 m .65107 .1658 L .64309 .14945 L p .751 .731 .917 r
F P
0 g
s
.47873 .38391 m .51716 .37087 L .52135 .36279 L p .411 .1 .198 r
F P
0 g
s
.51716 .37087 m .47873 .38391 L .47302 .38928 L p .199 .1 .1 r
F P
0 g
s
.43484 .40221 m .47302 .38928 L .47873 .38391 L p .199 .1 .1 r
F P
0 g
s
.52135 .36279 m .56003 .34964 L .56264 .33908 L p .529 .202 .407 r
F P
0 g
s
.56003 .34964 m .52135 .36279 L .51716 .37087 L p .411 .1 .198 r
F P
0 g
s
.58665 .13621 m .54765 .15064 L .55649 .16335 L p .766 .812 .982 r
F P
0 g
s
.55649 .16335 m .59537 .14906 L .58665 .13621 L p .766 .812 .982 r
F P
0 g
s
.47302 .38928 m .43484 .40221 L .42775 .40473 L p .1 .1 .1 r
F P
0 g
s
.39464 .7742 m .35684 .78496 L .33496 .79893 L p .154 .1 .1 r
F P
0 g
s
.33496 .79893 m .3733 .78806 L .39464 .7742 L p .154 .1 .1 r
F P
0 g
s
.38981 .41758 m .41208 .77707 L .38778 .78223 L p 1 .838 .627 r
F P
0 g
s
.38778 .78223 m .38152 .41716 L .38981 .41758 L p 1 .838 .627 r
F P
0 g
s
.63925 .26866 m .67862 .25496 L .67525 .23761 L p .69 .537 .742 r
F P
0 g
s
.67862 .25496 m .63925 .26866 L .6412 .28485 L p .669 .484 .692 r
F P
0 g
s
.56264 .33908 m .60157 .32578 L .60258 .313 L p .597 .329 .538 r
F P
0 g
s
.60157 .32578 m .56264 .33908 L .56003 .34964 L p .529 .202 .407 r
F P
0 g
s
.29707 .80968 m .33496 .79893 L .35684 .78496 L p .154 .1 .1 r
F P
0 g
s
.60258 .313 m .64178 .29953 L .6412 .28485 L p .639 .418 .627 r
F P
0 g
s
.64178 .29953 m .60258 .313 L .60157 .32578 L p .597 .329 .538 r
F P
0 g
s
.14142 .76572 m .19569 .83674 L .22258 .8308 L p .957 .567 .404 r
F P
0 g
s
.25961 .8203 m .22258 .8308 L .19569 .83674 L p .345 .855 .841 r
F P
0 g
s
.6347 .1346 m .59537 .14906 L .60386 .16378 L p .759 .77 .949 r
F P
0 g
s
.60386 .16378 m .64309 .14945 L .6347 .1346 L p .759 .77 .949 r
F P
0 g
s
.69426 .17252 m .65845 .18323 L .66504 .2013 L p .629 .6 .868 r
F P
0 g
s
.66504 .2013 m .69996 .18823 L .69426 .17252 L p .629 .6 .868 r
F P
0 g
s
.69996 .18823 m .66504 .2013 L .67068 .21957 L p .615 .558 .831 r
F P
0 g
s
.67068 .21957 m .70487 .2041 L .69996 .18823 L p .615 .558 .831 r
F P
0 g
s
.70487 .2041 m .67068 .21957 L .67525 .23761 L p .596 .512 .79 r
F P
0 g
s
.68791 .15737 m .65107 .1658 L .65845 .18323 L p .638 .638 .903 r
F P
0 g
s
.65845 .18323 m .69426 .17252 L .68791 .15737 L p .638 .638 .903 r
F P
0 g
s
.6412 .28485 m .68071 .2712 L .67862 .25496 L p .669 .484 .692 r
F P
0 g
s
.68071 .2712 m .6412 .28485 L .64178 .29953 L p .639 .418 .627 r
F P
0 g
s
.67525 .23761 m .70887 .21976 L .70487 .2041 L p .596 .512 .79 r
F P
0 g
s
.70887 .21976 m .67525 .23761 L .67862 .25496 L p .57 .457 .743 r
F P
0 g
s
.68106 .14315 m .64309 .14945 L .65107 .1658 L p .643 .676 .937 r
F P
0 g
s
.65107 .1658 m .68791 .15737 L .68106 .14315 L p .643 .676 .937 r
F P
0 g
s
.51716 .37087 m .55603 .35769 L .56003 .34964 L p .411 .1 .198 r
F P
0 g
s
.55603 .35769 m .51716 .37087 L .51165 .3762 L p .199 .1 .1 r
F P
0 g
s
.47302 .38928 m .51165 .3762 L .51716 .37087 L p .199 .1 .1 r
F P
0 g
s
.56003 .34964 m .59915 .33633 L .60157 .32578 L p .529 .202 .407 r
F P
0 g
s
.59915 .33633 m .56003 .34964 L .55603 .35769 L p .411 .1 .198 r
F P
0 g
s
.62609 .12161 m .58665 .13621 L .59537 .14906 L p .766 .812 .982 r
F P
0 g
s
.59537 .14906 m .6347 .1346 L .62609 .12161 L p .766 .812 .982 r
F P
0 g
s
.51165 .3762 m .47302 .38928 L .46613 .39174 L p .1 .1 .1 r
F P
0 g
s
.42775 .40473 m .46613 .39174 L .47302 .38928 L p .1 .1 .1 r
F P
0 g
s
.46613 .39174 m .42775 .40473 L .41964 .40423 L p .58 .991 1 r
F P
0 g
s
.38152 .41716 m .41964 .40423 L .42775 .40473 L p .58 .991 1 r
F P
0 g
s
.67862 .25496 m .71186 .23479 L .70887 .21976 L p .57 .457 .743 r
F P
0 g
s
.71186 .23479 m .67862 .25496 L .68071 .2712 L p .533 .388 .684 r
F P
0 g
s
.60157 .32578 m .64095 .31232 L .64178 .29953 L p .597 .329 .538 r
F P
0 g
s
.64095 .31232 m .60157 .32578 L .59915 .33633 L p .529 .202 .407 r
F P
0 g
s
.41964 .40423 m .38152 .41716 L .37243 .41369 L p .703 .988 1 r
F P
0 g
s
.38152 .41716 m .38778 .78223 L .36049 .77819 L p 1 .833 .634 r
F P
0 g
s
.36049 .77819 m .37243 .41369 L .38152 .41716 L p 1 .833 .634 r
F P
0 g
s
.64178 .29953 m .68144 .28591 L .68071 .2712 L p .639 .418 .627 r
F P
0 g
s
.68144 .28591 m .64178 .29953 L .64095 .31232 L p .597 .329 .538 r
F P
0 g
s
.29707 .80968 m .25961 .8203 L .23321 .8261 L p .345 .855 .841 r
F P
0 g
s
.19569 .83674 m .23321 .8261 L .25961 .8203 L p .345 .855 .841 r
F P
0 g
s
.6739 .13023 m .6347 .1346 L .64309 .14945 L p .642 .713 .973 r
F P
0 g
s
.64309 .14945 m .68106 .14315 L .6739 .13023 L p .642 .713 .973 r
F P
0 g
s
.68071 .2712 m .71376 .24884 L .71186 .23479 L p .533 .388 .684 r
F P
0 g
s
.71376 .24884 m .68071 .2712 L .68144 .28591 L p .479 .299 .606 r
F P
0 g
s
.55603 .35769 m .59535 .34435 L .59915 .33633 L p .411 .1 .198 r
F P
0 g
s
.59535 .34435 m .55603 .35769 L .55072 .36297 L p .199 .1 .1 r
F P
0 g
s
.51165 .3762 m .55072 .36297 L .55603 .35769 L p .199 .1 .1 r
F P
0 g
s
.59915 .33633 m .63872 .32287 L .64095 .31232 L p .529 .202 .407 r
F P
0 g
s
.63872 .32287 m .59915 .33633 L .59535 .34435 L p .411 .1 .198 r
F P
0 g
s
.66658 .11896 m .62609 .12161 L .6347 .1346 L p .634 .752 1 r
F P
0 g
s
.6347 .1346 m .6739 .13023 L .66658 .11896 L p .634 .752 1 r
F P
0 g
s
.55072 .36297 m .51165 .3762 L .50494 .37859 L p .1 .1 .1 r
F P
0 g
s
.46613 .39174 m .50494 .37859 L .51165 .3762 L p .1 .1 .1 r
F P
0 g
s
.50494 .37859 m .46613 .39174 L .4582 .39115 L p .58 .991 1 r
F P
0 g
s
.41964 .40423 m .4582 .39115 L .46613 .39174 L p .58 .991 1 r
F P
0 g
s
.64095 .31232 m .68079 .29872 L .68144 .28591 L p .597 .329 .538 r
F P
0 g
s
.68079 .29872 m .64095 .31232 L .63872 .32287 L p .529 .202 .407 r
F P
0 g
s
.4582 .39115 m .41964 .40423 L .41072 .40066 L p .703 .988 1 r
F P
0 g
s
.37243 .41369 m .41072 .40066 L .41964 .40423 L p .703 .988 1 r
F P
0 g
s
.41072 .40066 m .37243 .41369 L .36279 .40722 L p .746 .934 1 r
F P
0 g
s
.37243 .41369 m .36049 .77819 L .33088 .76459 L p 1 .828 .64 r
F P
0 g
s
.33088 .76459 m .36279 .40722 L .37243 .41369 L p 1 .828 .64 r
F P
0 g
s
.68144 .28591 m .71451 .26153 L .71376 .24884 L p .479 .299 .606 r
F P
0 g
s
.71451 .26153 m .68144 .28591 L .68079 .29872 L p .397 .173 .495 r
F P
0 g
s
.33496 .79893 m .29707 .80968 L .27118 .81532 L p .345 .855 .841 r
F P
0 g
s
.23321 .8261 m .27118 .81532 L .29707 .80968 L p .345 .855 .841 r
F P
0 g
s
.73291 .15959 m .69426 .17252 L .69996 .18823 L p .69 .635 .861 r
F P
0 g
s
.69996 .18823 m .73822 .17431 L .73291 .15959 L p .69 .635 .861 r
F P
0 g
s
.73822 .17431 m .69996 .18823 L .70487 .2041 L p .678 .596 .826 r
F P
0 g
s
.70487 .2041 m .74283 .18917 L .73822 .17431 L p .678 .596 .826 r
F P
0 g
s
.74283 .18917 m .70487 .2041 L .70887 .21976 L p .662 .554 .788 r
F P
0 g
s
.72702 .14539 m .68791 .15737 L .69426 .17252 L p .7 .673 .895 r
F P
0 g
s
.69426 .17252 m .73291 .15959 L .72702 .14539 L p .7 .673 .895 r
F P
0 g
s
.70887 .21976 m .74661 .20381 L .74283 .18917 L p .662 .554 .788 r
F P
0 g
s
.74661 .20381 m .70887 .21976 L .71186 .23479 L p .641 .504 .744 r
F P
0 g
s
.7207 .13206 m .68106 .14315 L .68791 .15737 L p .708 .71 .928 r
F P
0 g
s
.68791 .15737 m .72702 .14539 L .7207 .13206 L p .708 .71 .928 r
F P
0 g
s
.71186 .23479 m .74948 .21786 L .74661 .20381 L p .641 .504 .744 r
F P
0 g
s
.74948 .21786 m .71186 .23479 L .71376 .24884 L p .614 .445 .69 r
F P
0 g
s
.59535 .34435 m .63512 .33086 L .63872 .32287 L p .411 .1 .198 r
F P
0 g
s
.63512 .33086 m .59535 .34435 L .59024 .34958 L p .199 .1 .1 r
F P
0 g
s
.55072 .36297 m .59024 .34958 L .59535 .34435 L p .199 .1 .1 r
F P
0 g
s
.63872 .32287 m .67876 .30925 L .68079 .29872 L p .529 .202 .407 r
F P
0 g
s
.67876 .30925 m .63872 .32287 L .63512 .33086 L p .411 .1 .198 r
F P
0 g
s
.59024 .34958 m .55072 .36297 L .54421 .36529 L p .1 .1 .1 r
F P
0 g
s
.50494 .37859 m .54421 .36529 L .55072 .36297 L p .1 .1 .1 r
F P
0 g
s
.54421 .36529 m .50494 .37859 L .49721 .37792 L p .58 .991 1 r
F P
0 g
s
.4582 .39115 m .49721 .37792 L .50494 .37859 L p .58 .991 1 r
F P
0 g
s
.36279 .40722 m .40123 .39408 L .41072 .40066 L p .746 .934 1 r
F P
0 g
s
.40123 .39408 m .36279 .40722 L .35285 .39788 L p .757 .875 1 r
F P
0 g
s
.36279 .40722 m .33088 .76459 L .29977 .74136 L p 1 .823 .644 r
F P
0 g
s
.29977 .74136 m .35285 .39788 L .36279 .40722 L p 1 .823 .644 r
F P
0 g
s
.68079 .29872 m .71408 .27253 L .71451 .26153 L p .397 .173 .495 r
F P
0 g
s
.71408 .27253 m .68079 .29872 L .67876 .30925 L p .264 .1 .325 r
F P
0 g
s
.49721 .37792 m .4582 .39115 L .44946 .38749 L p .703 .988 1 r
F P
0 g
s
.41072 .40066 m .44946 .38749 L .4582 .39115 L p .703 .988 1 r
F P
0 g
s
.44946 .38749 m .41072 .40066 L .40123 .39408 L p .746 .934 1 r
F P
0 g
s
.71411 .11994 m .6739 .13023 L .68106 .14315 L p .713 .749 .962 r
F P
0 g
s
.68106 .14315 m .7207 .13206 L .71411 .11994 L p .713 .749 .962 r
F P
0 g
s
.11875 .76262 m .16592 .83376 L .19569 .83674 L p .964 .55 .339 r
F P
0 g
s
.23321 .8261 m .19569 .83674 L .16592 .83376 L p .577 .978 1 r
F P
0 g
s
.3733 .78806 m .33496 .79893 L .30959 .80442 L p .345 .855 .841 r
F P
0 g
s
.27118 .81532 m .30959 .80442 L .33496 .79893 L p .345 .855 .841 r
F P
0 g
s
.71376 .24884 m .75135 .23096 L .74948 .21786 L p .614 .445 .69 r
F P
0 g
s
.75135 .23096 m .71376 .24884 L .71451 .26153 L p .575 .369 .62 r
F P
0 g
s
.70741 .10936 m .66658 .11896 L .6739 .13023 L p .714 .79 .998 r
F P
0 g
s
.6739 .13023 m .71411 .11994 L .70741 .10936 L p .714 .79 .998 r
F P
0 g
s
.77237 .14628 m .73291 .15959 L .73822 .17431 L p .696 .638 .861 r
F P
0 g
s
.73822 .17431 m .77734 .16012 L .77237 .14628 L p .696 .638 .861 r
F P
0 g
s
.77734 .16012 m .73822 .17431 L .74283 .18917 L p .683 .599 .826 r
F P
0 g
s
.74283 .18917 m .78167 .17408 L .77734 .16012 L p .683 .599 .826 r
F P
0 g
s
.78167 .17408 m .74283 .18917 L .74661 .20381 L p .667 .557 .788 r
F P
0 g
s
.76689 .13291 m .72702 .14539 L .73291 .15959 L p .706 .675 .894 r
F P
0 g
s
.73291 .15959 m .77237 .14628 L .76689 .13291 L p .706 .675 .894 r
F P
0 g
s
.71451 .26153 m .75217 .24278 L .75135 .23096 L p .575 .369 .62 r
F P
0 g
s
.75217 .24278 m .71451 .26153 L .71408 .27253 L p .517 .265 .522 r
F P
0 g
s
.35285 .39788 m .39143 .38462 L .40123 .39408 L p .757 .875 1 r
F P
0 g
s
.74661 .20381 m .78526 .18782 L .78167 .17408 L p .667 .557 .788 r
F P
0 g
s
.78526 .18782 m .74661 .20381 L .74948 .21786 L p .647 .508 .744 r
F P
0 g
s
.63512 .33086 m .67536 .31721 L .67876 .30925 L p .411 .1 .198 r
F P
0 g
s
.67536 .31721 m .63512 .33086 L .63023 .33604 L p .199 .1 .1 r
F P
0 g
s
.59024 .34958 m .63023 .33604 L .63512 .33086 L p .199 .1 .1 r
F P
0 g
s
.67876 .30925 m .71247 .28154 L .71408 .27253 L p .264 .1 .325 r
F P
0 g
s
.71247 .28154 m .67876 .30925 L .67536 .31721 L p .1 .1 .1 r
F P
0 g
s
.63023 .33604 m .59024 .34958 L .58394 .35184 L p .1 .1 .1 r
F P
0 g
s
.54421 .36529 m .58394 .35184 L .59024 .34958 L p .1 .1 .1 r
F P
0 g
s
.58394 .35184 m .54421 .36529 L .53668 .36454 L p .58 .991 1 r
F P
0 g
s
.49721 .37792 m .53668 .36454 L .54421 .36529 L p .58 .991 1 r
F P
0 g
s
.40123 .39408 m .44013 .38079 L .44946 .38749 L p .746 .934 1 r
F P
0 g
s
.44013 .38079 m .40123 .39408 L .39143 .38462 L p .757 .875 1 r
F P
0 g
s
.76103 .12036 m .7207 .13206 L .72702 .14539 L p .713 .713 .927 r
F P
0 g
s
.72702 .14539 m .76689 .13291 L .76103 .12036 L p .713 .713 .927 r
F P
0 g
s
.53668 .36454 m .49721 .37792 L .48865 .37416 L p .703 .988 1 r
F P
0 g
s
.44946 .38749 m .48865 .37416 L .49721 .37792 L p .703 .988 1 r
F P
0 g
s
.48865 .37416 m .44946 .38749 L .44013 .38079 L p .746 .934 1 r
F P
0 g
s
.74948 .21786 m .78802 .201 L .78526 .18782 L p .647 .508 .744 r
F P
0 g
s
.78802 .201 m .74948 .21786 L .75135 .23096 L p .621 .45 .69 r
F P
0 g
s
.27118 .81532 m .23321 .8261 L .20391 .82291 L p .577 .978 1 r
F P
0 g
s
.16592 .83376 m .20391 .82291 L .23321 .8261 L p .577 .978 1 r
F P
0 g
s
.41208 .77707 m .3733 .78806 L .34845 .79339 L p .345 .855 .841 r
F P
0 g
s
.30959 .80442 m .34845 .79339 L .3733 .78806 L p .345 .855 .841 r
F P
0 g
s
.75495 .10895 m .71411 .11994 L .7207 .13206 L p .719 .751 .96 r
F P
0 g
s
.7207 .13206 m .76103 .12036 L .75495 .10895 L p .719 .751 .96 r
F P
0 g
s
.71408 .27253 m .75191 .253 L .75217 .24278 L p .517 .265 .522 r
F P
0 g
s
.75191 .253 m .71408 .27253 L .71247 .28154 L p .423 .112 .373 r
F P
0 g
s
.75135 .23096 m .78987 .21327 L .78802 .201 L p .621 .45 .69 r
F P
0 g
s
.78987 .21327 m .75135 .23096 L .75217 .24278 L p .583 .375 .621 r
F P
0 g
s
.39143 .38462 m .43047 .37121 L .44013 .38079 L p .757 .875 1 r
F P
0 g
s
.67536 .31721 m .7097 .2883 L .71247 .28154 L p .1 .1 .1 r
F P
0 g
s
.7097 .2883 m .67536 .31721 L .67068 .32234 L p .1 .1 .1 r
F P
0 g
s
.63023 .33604 m .67068 .32234 L .67536 .31721 L p .199 .1 .1 r
F P
0 g
s
.74879 .09897 m .70741 .10936 L .71411 .11994 L p .72 .793 .996 r
F P
0 g
s
.71411 .11994 m .75495 .10895 L .74879 .09897 L p .72 .793 .996 r
F P
0 g
s
.67068 .32234 m .63023 .33604 L .62414 .33822 L p .1 .1 .1 r
F P
0 g
s
.58394 .35184 m .62414 .33822 L .63023 .33604 L p .1 .1 .1 r
F P
0 g
s
.62414 .33822 m .58394 .35184 L .57661 .35099 L p .58 .991 1 r
F P
0 g
s
.53668 .36454 m .57661 .35099 L .58394 .35184 L p .58 .991 1 r
F P
0 g
s
.44013 .38079 m .47948 .36735 L .48865 .37416 L p .746 .934 1 r
F P
0 g
s
.47948 .36735 m .44013 .38079 L .43047 .37121 L p .757 .875 1 r
F P
0 g
s
.8126 .1326 m .77237 .14628 L .77734 .16012 L p .7 .641 .86 r
F P
0 g
s
.77734 .16012 m .81726 .14566 L .8126 .1326 L p .7 .641 .86 r
F P
0 g
s
.81726 .14566 m .77734 .16012 L .78167 .17408 L p .687 .602 .825 r
F P
0 g
s
.57661 .35099 m .53668 .36454 L .5283 .36067 L p .703 .988 1 r
F P
0 g
s
.48865 .37416 m .5283 .36067 L .53668 .36454 L p .703 .988 1 r
F P
0 g
s
.78167 .17408 m .82136 .15883 L .81726 .14566 L p .687 .602 .825 r
F P
0 g
s
.82136 .15883 m .78167 .17408 L .78526 .18782 L p .672 .56 .787 r
F P
0 g
s
.5283 .36067 m .48865 .37416 L .47948 .36735 L p .746 .934 1 r
F P
0 g
s
.80748 .11998 m .76689 .13291 L .77237 .14628 L p .71 .678 .893 r
F P
0 g
s
.77237 .14628 m .8126 .1326 L .80748 .11998 L p .71 .678 .893 r
F P
0 g
s
.75217 .24278 m .79075 .22432 L .78987 .21327 L p .583 .375 .621 r
F P
0 g
s
.79075 .22432 m .75217 .24278 L .75191 .253 L p .527 .272 .523 r
F P
0 g
s
.78526 .18782 m .82478 .17177 L .82136 .15883 L p .672 .56 .787 r
F P
0 g
s
.82478 .17177 m .78526 .18782 L .78802 .201 L p .652 .512 .743 r
F P
0 g
s
.30959 .80442 m .27118 .81532 L .24236 .81193 L p .577 .978 1 r
F P
0 g
s
.20391 .82291 m .24236 .81193 L .27118 .81532 L p .577 .978 1 r
F P
0 g
s
.34845 .79339 m .38778 .78223 L .41208 .77707 L p .345 .855 .841 r
F P
0 g
s
.71247 .28154 m .75056 .26134 L .75191 .253 L p .423 .112 .373 r
F P
0 g
s
.75056 .26134 m .71247 .28154 L .7097 .2883 L p .261 .1 .134 r
F P
0 g
s
.80204 .10812 m .76103 .12036 L .76689 .13291 L p .718 .715 .926 r
F P
0 g
s
.76689 .13291 m .80748 .11998 L .80204 .10812 L p .718 .715 .926 r
F P
0 g
s
.78802 .201 m .82744 .18417 L .82478 .17177 L p .652 .512 .743 r
F P
0 g
s
.82744 .18417 m .78802 .201 L .78987 .21327 L p .626 .454 .69 r
F P
0 g
s
.09472 .75273 m .13403 .82146 L .16592 .83376 L p .967 .532 .267 r
F P
0 g
s
.79641 .09733 m .75495 .10895 L .76103 .12036 L p .723 .754 .959 r
F P
0 g
s
.76103 .12036 m .80204 .10812 L .79641 .09733 L p .723 .754 .959 r
F P
0 g
s
.75191 .253 m .79064 .23385 L .79075 .22432 L p .527 .272 .523 r
F P
0 g
s
.79064 .23385 m .75191 .253 L .75056 .26134 L p .436 .123 .377 r
F P
0 g
s
.43047 .37121 m .46997 .35764 L .47948 .36735 L p .757 .875 1 r
F P
0 g
s
.78987 .21327 m .82926 .19571 L .82744 .18417 L p .626 .454 .69 r
F P
0 g
s
.82926 .19571 m .78987 .21327 L .79075 .22432 L p .59 .38 .621 r
F P
0 g
s
.70583 .29258 m .7097 .2883 L p .70078 .29608 L .1 .1 .1 r
F P
0 g
s
.74815 .26756 m .7097 .2883 L .70583 .29258 L p .1 .1 .1 r
F P
0 g
s
.70583 .29258 m .70095 .29425 L p .71094 .28905 L .53 .958 .83 r
F P
0 g
s
.74472 .27147 m .74815 .26756 L p .7165 .28628 L .1 .1 .1 r
F P
0 g
s
.70583 .29258 m .74472 .27147 L p .7165 .28628 L .1 .1 .1 r
F P
0 g
s
.78744 .24736 m .74815 .26756 L .74472 .27147 L p .1 .1 .1 r
F P
0 g
s
.7844 .25093 m .78744 .24736 L p .75475 .26581 L .1 .1 .1 r
F P
0 g
s
.74472 .27147 m .7844 .25093 L p .75475 .26581 L .1 .1 .1 r
F P
0 g
s
.82753 .22757 m .78744 .24736 L .7844 .25093 L p .1 .1 .1 r
F P
0 g
s
.7844 .25093 m .82485 .23085 L .82753 .22757 L p .1 .1 .1 r
F P
0 g
s
.7844 .25093 m .7805 .25219 L p .81441 .23587 L .49 .935 .821 r
F P
0 g
s
.82485 .23085 m .7844 .25093 L p .81441 .23587 L .49 .935 .821 r
F P
0 g
s
.74472 .27147 m .74035 .27291 L p .77327 .25648 L .508 .946 .825 r
F P
0 g
s
.7844 .25093 m .74472 .27147 L p .77327 .25648 L .508 .946 .825 r
F P
0 g
s
.74472 .27147 m .70583 .29258 L p .71094 .28905 L .53 .958 .83 r
F P
0 g
s
.67068 .32234 m .70583 .29258 L p .70078 .29608 L .1 .1 .1 r
F P
0 g
s
.62414 .33822 m .66482 .32445 L .67068 .32234 L p .1 .1 .1 r
F P
0 g
s
.70583 .29258 m .67068 .32234 L .66482 .32445 L p .738 1 .858 r
F P
0 g
s
.66482 .32445 m .62414 .33822 L .61701 .33729 L p .58 .991 1 r
F P
0 g
s
.57661 .35099 m .61701 .33729 L .62414 .33822 L p .58 .991 1 r
F P
0 g
s
.47948 .36735 m .5193 .35375 L .5283 .36067 L p .746 .934 1 r
F P
0 g
s
.5193 .35375 m .47948 .36735 L .46997 .35764 L p .757 .875 1 r
F P
0 g
s
.61701 .33729 m .57661 .35099 L .56842 .34702 L p .703 .988 1 r
F P
0 g
s
.5283 .36067 m .56842 .34702 L .57661 .35099 L p .703 .988 1 r
F P
0 g
s
.56842 .34702 m .5283 .36067 L .5193 .35375 L p .746 .934 1 r
F P
0 g
s
.20391 .82291 m .16592 .83376 L .13403 .82146 L p .685 .962 1 r
F P
0 g
s
.7097 .2883 m .74815 .26756 L .75056 .26134 L p .261 .1 .134 r
F P
0 g
s
.79073 .08788 m .74879 .09897 L .75495 .10895 L p .726 .796 .995 r
F P
0 g
s
.75495 .10895 m .79641 .09733 L .79073 .08788 L p .726 .796 .995 r
F P
0 g
s
.34845 .79339 m .30959 .80442 L .28126 .80082 L p .577 .978 1 r
F P
0 g
s
.24236 .81193 m .28126 .80082 L .30959 .80442 L p .577 .978 1 r
F P
0 g
s
.79075 .22432 m .83021 .20607 L .82926 .19571 L p .59 .38 .621 r
F P
0 g
s
.83021 .20607 m .79075 .22432 L .79064 .23385 L p .535 .279 .525 r
F P
0 g
s
.75056 .26134 m .78953 .24161 L .79064 .23385 L p .436 .123 .377 r
F P
0 g
s
.78953 .24161 m .75056 .26134 L .74815 .26756 L p .279 .1 .14 r
F P
0 g
s
.46997 .35764 m .50993 .34391 L .5193 .35375 L p .757 .875 1 r
F P
0 g
s
.79064 .23385 m .83024 .215 L .83021 .20607 L p .535 .279 .525 r
F P
0 g
s
.83024 .215 m .79064 .23385 L .78953 .24161 L p .447 .131 .38 r
F P
0 g
s
.66482 .32445 m .70095 .29425 L .70583 .29258 L p .738 1 .858 r
F P
0 g
s
.70095 .29425 m .66482 .32445 L .6579 .32342 L p .862 1 1 r
F P
0 g
s
.61701 .33729 m .6579 .32342 L .66482 .32445 L p .58 .991 1 r
F P
0 g
s
.5193 .35375 m .5596 .33998 L .56842 .34702 L p .746 .934 1 r
F P
0 g
s
.5596 .33998 m .5193 .35375 L .50993 .34391 L p .757 .875 1 r
F P
0 g
s
.6579 .32342 m .61701 .33729 L .60902 .33321 L p .703 .988 1 r
F P
0 g
s
.56842 .34702 m .60902 .33321 L .61701 .33729 L p .703 .988 1 r
F P
0 g
s
.60902 .33321 m .56842 .34702 L .5596 .33998 L p .746 .934 1 r
F P
0 g
s
.24236 .81193 m .20391 .82291 L .17245 .81036 L p .685 .962 1 r
F P
0 g
s
.13403 .82146 m .17245 .81036 L .20391 .82291 L p .685 .962 1 r
F P
0 g
s
.38778 .78223 m .34845 .79339 L .32064 .78957 L p .577 .978 1 r
F P
0 g
s
.28126 .80082 m .32064 .78957 L .34845 .79339 L p .577 .978 1 r
F P
0 g
s
.74815 .26756 m .78744 .24736 L .78953 .24161 L p .279 .1 .14 r
F P
0 g
s
.07004 .7361 m .10092 .79979 L .13403 .82146 L p .965 .517 .193 r
F P
0 g
s
.78953 .24161 m .82934 .22224 L .83024 .215 L p .447 .131 .38 r
F P
0 g
s
.82934 .22224 m .78953 .24161 L .78744 .24736 L p .294 .1 .145 r
F P
0 g
s
.50993 .34391 m .55038 .33002 L .5596 .33998 L p .757 .875 1 r
F P
0 g
s
.70095 .29425 m .74035 .27291 L .74472 .27147 L p .53 .958 .83 r
F P
0 g
s
.74035 .27291 m .70095 .29425 L .69517 .2932 L p .731 1 1 r
F P
0 g
s
.6579 .32342 m .69517 .2932 L .70095 .29425 L p .862 1 1 r
F P
0 g
s
.5596 .33998 m .60038 .32605 L .60902 .33321 L p .746 .934 1 r
F P
0 g
s
.60038 .32605 m .5596 .33998 L .55038 .33002 L p .757 .875 1 r
F P
0 g
s
.69517 .2932 m .6579 .32342 L .65011 .31924 L p .89 1 1 r
F P
0 g
s
.60902 .33321 m .65011 .31924 L .6579 .32342 L p .703 .988 1 r
F P
0 g
s
.65011 .31924 m .60902 .33321 L .60038 .32605 L p .746 .934 1 r
F P
0 g
s
.28126 .80082 m .24236 .81193 L .21134 .79913 L p .685 .962 1 r
F P
0 g
s
.17245 .81036 m .21134 .79913 L .24236 .81193 L p .685 .962 1 r
F P
0 g
s
.32064 .78957 m .36049 .77819 L .38778 .78223 L p .577 .978 1 r
F P
0 g
s
.78744 .24736 m .82753 .22757 L .82934 .22224 L p .294 .1 .145 r
F P
0 g
s
.17245 .81036 m .13403 .82146 L .10092 .79979 L p .725 .904 1 r
F P
0 g
s
.69517 .2932 m .73516 .27183 L .74035 .27291 L p .731 1 1 r
F P
0 g
s
.73516 .27183 m .69517 .2932 L .68864 .28943 L p .801 1 1 r
F P
0 g
s
.65011 .31924 m .68864 .28943 L .69517 .2932 L p .89 1 1 r
F P
0 g
s
.55038 .33002 m .59132 .31595 L .60038 .32605 L p .757 .875 1 r
F P
0 g
s
.74035 .27291 m .7805 .25219 L .7844 .25093 L p .508 .946 .825 r
F P
0 g
s
.7805 .25219 m .74035 .27291 L .73516 .27183 L p .716 1 1 r
F P
0 g
s
.60038 .32605 m .64165 .31195 L .65011 .31924 L p .746 .934 1 r
F P
0 g
s
.64165 .31195 m .60038 .32605 L .59132 .31595 L p .757 .875 1 r
F P
0 g
s
.68864 .28943 m .65011 .31924 L .64165 .31195 L p .885 .968 1 r
F P
0 g
s
.32064 .78957 m .28126 .80082 L .2507 .78775 L p .685 .962 1 r
F P
0 g
s
.21134 .79913 m .2507 .78775 L .28126 .80082 L p .685 .962 1 r
F P
0 g
s
.68864 .28943 m .72926 .2682 L .73516 .27183 L p .801 1 1 r
F P
0 g
s
.72926 .2682 m .68864 .28943 L .68153 .283 L p .817 .954 1 r
F P
0 g
s
.64165 .31195 m .68153 .283 L .68864 .28943 L p .885 .968 1 r
F P
0 g
s
.73516 .27183 m .77581 .25107 L .7805 .25219 L p .716 1 1 r
F P
0 g
s
.77581 .25107 m .73516 .27183 L .72926 .2682 L p .791 1 1 r
F P
0 g
s
.21134 .79913 m .17245 .81036 L .13972 .78839 L p .725 .904 1 r
F P
0 g
s
.10092 .79979 m .13972 .78839 L .17245 .81036 L p .725 .904 1 r
F P
0 g
s
.59132 .31595 m .63275 .30172 L .64165 .31195 L p .757 .875 1 r
F P
0 g
s
.7805 .25219 m .82135 .23195 L .82485 .23085 L p .49 .935 .821 r
F P
0 g
s
.82135 .23195 m .7805 .25219 L .77581 .25107 L p .703 1 1 r
F P
0 g
s
.68153 .283 m .64165 .31195 L .63275 .30172 L p .872 .909 .983 r
F P
0 g
s
.36049 .77819 m .32064 .78957 L .29054 .77624 L p .685 .962 1 r
F P
0 g
s
.2507 .78775 m .29054 .77624 L .32064 .78957 L p .685 .962 1 r
F P
0 g
s
.68153 .283 m .72281 .2621 L .72926 .2682 L p .817 .954 1 r
F P
0 g
s
.72281 .2621 m .68153 .283 L .67405 .27405 L p .815 .893 1 r
F P
0 g
s
.63275 .30172 m .67405 .27405 L .68153 .283 L p .872 .909 .983 r
F P
0 g
s
.72926 .2682 m .77047 .24758 L .77581 .25107 L p .791 1 1 r
F P
0 g
s
.77047 .24758 m .72926 .2682 L .72281 .2621 L p .81 .952 1 r
F P
0 g
s
.77581 .25107 m .81712 .23081 L .82135 .23195 L p .703 1 1 r
F P
0 g
s
.81712 .23081 m .77581 .25107 L .77047 .24758 L p .783 1 1 r
F P
0 g
s
.2507 .78775 m .21134 .79913 L .17899 .77685 L p .725 .904 1 r
F P
0 g
s
.13972 .78839 m .17899 .77685 L .21134 .79913 L p .725 .904 1 r
F P
0 g
s
.29054 .77624 m .33088 .76459 L .36049 .77819 L p .685 .962 1 r
F P
0 g
s
.67405 .27405 m .716 .25367 L .72281 .2621 L p .815 .893 1 r
F P
0 g
s
.72281 .2621 m .76461 .24177 L .77047 .24758 L p .81 .952 1 r
F P
0 g
s
.76461 .24177 m .72281 .2621 L .716 .25367 L p .808 .891 1 r
F P
0 g
s
.77047 .24758 m .81227 .22743 L .81712 .23081 L p .783 1 1 r
F P
0 g
s
.81227 .22743 m .77047 .24758 L .76461 .24177 L p .803 .95 1 r
F P
0 g
s
.29054 .77624 m .2507 .78775 L .21875 .76517 L p .725 .904 1 r
F P
0 g
s
.17899 .77685 m .21875 .76517 L .2507 .78775 L p .725 .904 1 r
F P
0 g
s
.716 .25367 m .75839 .23379 L .76461 .24177 L p .808 .891 1 r
F P
0 g
s
.76461 .24177 m .80693 .22189 L .81227 .22743 L p .803 .95 1 r
F P
0 g
s
.80693 .22189 m .76461 .24177 L .75839 .23379 L p .803 .89 1 r
F P
0 g
s
.75839 .23379 m .80123 .2143 L .80693 .22189 L p .803 .89 1 r
F P
0 g
s
.33088 .76459 m .29054 .77624 L .25901 .75334 L p .725 .904 1 r
F P
0 g
s
.21875 .76517 m .25901 .75334 L .29054 .77624 L p .725 .904 1 r
F P
0 g
s
.25901 .75334 m .29977 .74136 L .33088 .76459 L p .725 .904 1 r
F P
0 g
s
.25 Mabswid
.80061 0 m
.9327 .21103 L
s
.9327 .21103 m
1 .77902 L
s
1 .77902 m
.85247 .5896 L
s
.85247 .5896 m
.80061 0 L
s
.06337 .27882 m
0 .83882 L
s
0 .83882 m
.85247 .5896 L
s
.85247 .5896 m
.80061 0 L
s
.80061 0 m
.06337 .27882 L
s
0 .83882 m
.20049 .98709 L
s
.00518 .84266 m
.00589 .83634 L
s
[(0)] .00377 .85528 .11186 -1 Mshowa
.05603 .88026 m
.05666 .87394 L
s
[(0.5)] .05477 .8929 .09932 -1 Mshowa
.10481 .91634 m
.10537 .91001 L
s
[(1)] .10371 .92899 .08748 -1 Mshowa
.15167 .95098 m
.15215 .94465 L
s
[(1.5)] .1507 .96365 .0763 -1 Mshowa
.1967 .98429 m
.19711 .97795 L
s
[(2)] .19586 .99696 .06571 -1 Mshowa
.125 Mabswid
.01552 .8503 m
.01594 .84651 L
s
.02578 .85788 m
.02618 .8541 L
s
.03594 .8654 m
.03634 .86161 L
s
.04603 .87286 m
.04641 .86907 L
s
.06595 .88759 m
.06631 .8838 L
s
.07578 .89487 m
.07614 .89107 L
s
.08554 .90208 m
.08589 .89829 L
s
.09521 .90924 m
.09556 .90544 L
s
.11434 .92338 m
.11466 .91958 L
s
.12378 .93036 m
.12409 .92656 L
s
.13315 .93729 m
.13346 .93349 L
s
.14244 .94417 m
.14274 .94037 L
s
.16081 .95775 m
.1611 .95395 L
s
.16989 .96446 m
.17016 .96066 L
s
.1789 .97112 m
.17916 .96732 L
s
.18783 .97773 m
.18809 .97393 L
s
gsave
.09784 .99201 -79.4886 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Im) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 15.000000 moveto
(@) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 15.000000 moveto
(D) show
93.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.9327 .21103 m
1 .77902 L
s
.93409 .2228 m
.92808 .22484 L
s
[(-1)] .94612 .21871 -1 .34012 Mshowa
.94854 .34472 m
.9425 .34667 L
s
[(0)] .96063 .34082 -1 .32249 Mshowa
.96396 .47488 m
.95789 .47673 L
s
[(1)] .97612 .47119 -1 .30374 Mshowa
.98046 .61414 m
.97435 .61587 L
s
[(2)] .99268 .61067 -1 .28377 Mshowa
.99816 .76349 m
.99202 .7651 L
s
[(3)] 1.01044 .76026 -1 .26245 Mshowa
.125 Mabswid
.93691 .24656 m
.9333 .24778 L
s
.93976 .27063 m
.93615 .27183 L
s
.94265 .29501 m
.93903 .2962 L
s
.94558 .3197 m
.94195 .32088 L
s
.95154 .37007 m
.94791 .37123 L
s
.95459 .39575 m
.95095 .3969 L
s
.95767 .42178 m
.95403 .42291 L
s
.96079 .44815 m
.95715 .44927 L
s
.96717 .50197 m
.96352 .50307 L
s
.97043 .52944 m
.96677 .53052 L
s
.97373 .55728 m
.97007 .55835 L
s
.97707 .58551 m
.97341 .58657 L
s
.9839 .64317 m
.98023 .64419 L
s
.98739 .67261 m
.98372 .67362 L
s
.99093 .70247 m
.98725 .70347 L
s
.99452 .73276 m
.99084 .73374 L
s
gsave
1.03688 .45273 -61 -13.7781 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 15.000000 moveto
(@) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 15.000000 moveto
(D) show
93.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{227.812, 224.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003S0000h0P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVN<0003S0000h`000><0003S0000h`000><0
003S0000h`000><0003S0000h`000><0002D0081C@0009800P400`010@1<0000S`030@<00P5<0000
S0030@H000<10040B`0008X00P4900030@0104/0002700<12`001040005:0000Q0030@l000@10001
B@0008800P4B00040@000DT0001o00<150001@40000104P0001l00<15`000`40000200030@0004D0
001j00816P000`40000200030@0004D0001g00<170000`40000300030@0004@0001d00<17`000`40
000300030@0004@0001b00818P000`40000400030@0004<0001_00<190000`40000500030@000480
001/00<19`000`40000500030@000480001Z00819@030@8000<100001P000`4000110000I`030B<0
1043R`030@0100P000<10000@@0006D00P4S00<100J;T8^@Ri020@8000<100001P000`4000100000
HP030B401042R`030H^;00@10X/00`400@0900030@0003l0001O00<180040@05T8^@Ri001045R`81
00<00@0020000`40000o0000G@020Al01043R`030H/100<10h/00`6;0@030@04RX/10@X000<10000
?P0005X00`4G00X100J@Ri2;T8/30@F;1045R`<12`000`40000m0000E`030AP00P42R`080H]bRg:;
LP42R`@10X/00`6;0@030@05RX^:0HX010400h^50@0;00030@0003d0001E00816@020@0908/0R`5b
Rg:;00D11H/30@J;0`45R`8130000`40000l0000DP030AP00`45R`H100J;LX]b0H/40@06R`6;RX^:
0`401XD1QH^5R`8100=/0@002`000`40000l0000C`030AT00P4018/00@040@09Ri01Rg:;LX]b00<1
1X/0106;0@45R`070H/10H^5R`020@`000<10000>`0004d00P4J00810h/30@N;00<1R`400`4026`1
RX^:RhZ;0`401X^5RhF;Q@<100E/Rfb;K0020@d000<10000>P0004X00`4I00<100>;08/00P402I2;
0H^@Ri2;T0030@08Rg:;LX]b0H/40@:;00<1Rh/0104018F;0H/50@03R`4000/000<10000>P0004L0
0`4H00@10X/0106;0@44R`030H^;00@100R;RP5/Rfb;K0<100I/Rfb;K8/30@05Rfb;K8/00`4018]/
Rf`30@d000<10000>@0004D00P4H00<100D0R`2;00030@06T8^@Ri2;0`46R`030H]b00<100=]0H/0
0h/30@06R`6;QH^50P401X/1RhF;Q@@13@000`40000i0000@P030AP00P400h/1R`03R`810X/00`6;
R`02R`8100R:0HZ;RX^:R`@100M/Rfb;K05/008100N;K8]/R`6;008100I/Rfb;0H/20@04K8D10@h0
00<10000>00003l00`4I008100J;08/00@020@07Ri2;T06@R`020@B;00<1R`400`42R`060Ff;KH]]
0`401XF;QH^5R`<100F;QH^5R`030@04RhF;Q@813`000`40000g0000?@020AT00`45R`<11X/30@05
RX^:RhX00`402HF;QH^5RhD1K0030@07K8/1Rfb;K0020@05R`6;K8/00`401HD1QFb500<100>50@00
3@000`40000g0000>P030AT00P40102;0H/40@05T8/1Ri0010400h/1R`03R`810X/00`6;R`04R`<1
00Q/Rfb;K065R`8100F5RhD1Q@020@06RhF;Q@650P42Q@<13`000`40000f0000>0020AX00P43R`<1
1X/30@08RhZ;RX^:0HX20@07RhF;Q@65R`040@08Q@5/Rfb;K8/30@04Rfb;K0<100E/QFb5K0030@03
K8E/008100>50@003`000`40000e0000=@030@D00P4B00<100<0R`000P401h^@0I2;T8/00P400h/1
R`05R`<11X/30@08RhZ;RX^:0F`40@05R`6;QH/00P401XD1QH^5R`8100A/Q@650P4016`10@4@0003
0@0003D0000b00<11P020@:;00<100002`040@:;00@1R`4118/00`6;R`020@06RX^:R`6;10401hF;
0H^5RhD00P4028/1RhF;QH^50`401fb6K8I/0F`00P401XE/QF`1K08100>5K8D00`401XEV0@650A40
00<10000=00003000P47008100B;08/00`4800<100F;08/0R`030@06Ri2;T8^@0`45R`<11X/00`6;
R`020@08RX^:R`6;RX/20@07Q@5/Rfb;K0030@05QH^5RhD00`400fb5K0020@03Q@65008100AV0@41
4@000`40000800@1:00002d00`4600<11h/00`4m0@0500810X/00`6;0@030@:;00<1Rh/010401X/1
RhZ;RP8100V;Q@65RhF;QH/00`4028^5RhF;Q@650P401XZ5RXD1K0<100A/Q@65104016b50HD20@03
IXD100<100EV0@5V0@0A00812`000`40000W0000:P030@H00`403P2;0H/0R`2;08/00E@10P020@03
08/000<100J@Ri2;T8/30@J;00@1R`4118/00`6;R`040@08R`6;RX^:RhX30@05QH^5RhD00`401Fb6
K8I/008100F5K8E/Q@030@03QF`100<100@0T05V0`4>00<100<00@002P000`40000W0000:0020@H0
0`46R`030H^;00J;00@1?@410h/20@:;00<1Rh/00X/20@08RP6:RhZ;RX/30@06RhF;QH^50`4028F;
QH^5R`6;10401XD1QHZ5RP8100J50Fb5K8D30@04QFb5K08100>50HD0104018^@Ri050@/00`430081
0`040@@000<100009`0002D00`46008101L0R`6;08/0R`2;0H/0R`2;08/1?E@100020@07Ri2;T06@
R`020@B;00<1R`400`42R`030H^;00:;0P4028X1RX^:RhZ;0`4028^5RhF;Q@650P403H^5RhD1K8H1
QFb50HD00P400fb5K0040@030901008100>@00400`4800<11`000`40000900030@0002L0000R00<1
1`020@F;00<1Rh/018/00`6;R`05R`D11X/30@05RX^:RhX00`402HF;QH^5R`6;Q@020@08RhF;Q@65
RhD20@08RP6:QHZ5RXD30@J50`4016aWK6L20@05QFJ50F`00P4018^@0@42T0<100>@M`401P030@/0
00<100001P030BT0000P00811`030@0B08/0R`2;08/1R`2;08/00@2;10401i2;0CMD0I001042R`04
0H^;R`810X/00`6;R`04R`<100R:RhZ;RX/1R`8100J5RhF;0H/40@08Q@65RhF;QH/20@04K8E/Q@<1
00>5K0400`401P2@0@40T0<100F@0@400@0300<13P000`40000800030@0002L0000M00<11P030@:;
00<1Rh/01X/00`6;R`04R`<11X/00`4m=`020@08RhZ;RX^:0HX20@07RhF;Q@65R`040@08Q@65RhF;
QH/30@05RXF:QHX00`46Q@030HD100<100R50FaWK05/IPD100F;T041T0060@@000@100414@000`40
000b00006P030@H00`404P2;08/0R`6;08/0R`2;0040R`<100b;T06@Ri2;T8^@0E@20@J;0P46R`<1
00R;RX^:RhX1RP@100J;0H^5RhD20@08R`6;QH^5RhD30@06QHZ5RXF:0`400hEWQ@030@0709010@2@
00040@D00`4B0081=00001P00P4600<10X/00`6;R`05R`030H^;00F;0`45R`030H^;00F;00H1=`41
RhX40@06R`6;QH^50P4028/1RhF;QH^50`4028F:QHZ5RP6:0P44Q@040HF5Q@8100M/0Fb5K8E/00<1
00=VK6H010400i010@02T0H10`030@03004001<000<10000<P0001D00`46008101<0R`2;08/1R`2;
08/00@2;08/00081016;T06@Ri2;T8/1Ri2;T8^@R`020@03C`4100J;00`1R`41RX^:R`6;RX/20@08
Q@65RhF;QH/30@08RhF;QH^50HD20@05RXF:0HX01042Q@030HEW008100H0T00109060@800`440003
0@00018000<10000<P0001800`4800030J4100N;00<1Rh/018/00`6;R`020@B;00<1Rh/01H/00`6;
R`04R`8100Pg0HF;QH^5R`<100R;QH^5RhD1Q@8100J:QHZ50HD40@03Q@6500F50`4016b5K8D30@06
QF^5JhE[0`4018^@0@42T0H100@00@411`000`40000B00030@000380000@00812`004@40X@6;08/0
R`0108/0R`2;00<101F;T8^@Ri2;0H^@Ri2;T8/1Ri2;T8/00P4014l10H/40@08R`6;RX^:RhX30@05
QH^5RhD00`4028F;QH^5R`6;10401HD1QHZ5008100>50HD01HD20@0509010@000P400i000@050@X0
00<100004P020C<0000>008130001P6UXJFQ0@J;00<1Rh/00`42R`030H^;00F;00<1Rh/01H/00`6;
R`030@04RX/1=`8100R5RhF;QH/1R`@100J50HF:QHX20@03Q@6500F50`401hE/QFb50HD00P401V^5
JhD1Q@@100F;0@41T0020@:@1@4=00030@0001<000<10000<@0000h00P4<000<0J40X@0108/0R`2;
0`405H^@Ri2;0H^@Ri2;T8^@0I2;T8^@R`030@F;00T1=`41RhZ;RX/00`4028^5RhF;Q@650P4028^5
RhD1QH^50P401hX1RXF:QHX00`45Q@D100D0T00100020@03T00100<140000`40000C00030@000340
000>00030@0100X000P1XJFQYJ6U0@:;0`42R`030H^;00B;00<1Rh/01H/00`6;R`040@09RX/1RhZ;
RX^:00<100>5R`400P4028X1RXF:QHZ50`46Q@090HD10Fb5K05/00@100J50HE[QF/20@06Q@41R`2;
0P4010010I040A8000<100004`000`40000a00003P001040004900080@2Q0:40X@020@0DRi2;T8/1
Ri2;T8^@R`6;T8^@Ri030@J;00<1Rh/018/20@0:<`41RhF;QH/1R`@100R50HF;QH^5R`<100B:QHZ5
0`46Q@060HD10F^50P401900T04200030@0000<15@000`40000A0081<`0000h000D100000@07000;
0JFQYJ6UXJD1X@401X/00`6;R`05R`040H^;R`8101V;RP6:RhZ;RX^:0HZ;RX^:R`4c0HZ5RXF:00<1
1XD00`650@030@05Q@65K8D00P4026/1JhE[QF^50`403XEV0@40R`2;0I000@2@0`4F00030@000180
00<10000<@0000d000<100000`000`400003000L0@2Q0:40X@2Q0J41Ri2;T8^@R`6;T8^@Ri01T081
18/00`6;R`05R`030H^;00B;0`400hF;0@020@08R`6;QH^5RhD30@07QHZ5RXD1Q@020@B500<1Q@40
0`400hD1Q@020@04Ri01008100L00@400@0101P000<100004P000`40000a00003@000`4000040003
0@00008000T1XJFQYJ6UX@400j400`6;R`05R`030H^;00>;0P405X^:RhZ;RX/1RhZ;RX^:R`6;RX^:
RhX20@03RP4100B500<1Q@400`401f`1K8E/QF`00`401F^5JhE[00<100EVQFJ5IP020@0;T8^@Ri01
0901T0000`4I00030@00018000<10000<@0000d000<100001@006`40006Q0:40X@2Q0J40X@01T8^@
Ri2;T06@R`030@:;00<1Rh/01H/00`6;R`04R`030H^;00>;10401H^5RhF;00<100N:QHZ5RP6:00@1
00>50HD00XD30@05J`5[QF/00`400h^@R`030@:@0P400`010@020AX000<100004P000`40000a0000
3@000`400006000:0@01YJ6UXJFQ0@JQ00<1Rh/018/30@0GRX^:RhX1RX^:RhZ;RP6:RhZ;RX^:0HX0
0`400hF;0@04Q@8100N50HE/QFb500<100N5JhE[Q@65008100AVQFJ5104018^@0I020@05Ri2;T8/0
0`400i01000K00030@0001800P4b00003@000`400007000B0@2Q0:40X@010:40X@2Q0H^@1042R`03
0H^;00B;00<1Rh/01H/00`6;R`03R`<11H/50@07QHZ50HF:Q@020@03Q@6500B50`401HE[QF^50081
00F;T8^@R`020@:@1P400i1g0@0M00030@0001<000@100000P4]00003@000`40000700080J6UXJFQ
Y@48X@8101R;RX^:RhX1RX^:RhZ;0H^:RhZ;RX/1RhX30@09QH/1RhF;QH^5008100N5K8E/Q@650081
00I[QF^50HD30@04QFH1IP@100>@R`400`400i2;T0020@04M`41M`<17`000`40000C00040@000@80
00<10000:P0000d000<100001@020@0BX@2Q0:400@2Q0:40X@2Q0J411h/00`6;R`04R`030H^;00B;
0`45R`030H^;00B;00H1RXF:QHX30@F50`4018E[QF/40@03T8^@00810i030@:@1@4R00030@0001<0
00@100010P000`40000Z00003@000`40000200<10X/01P6QYJ6U0@RQ01D1XJ41RhZ;RX^:R`6;RX^:
RhX1RX/010404XD1QH^5RhF;Q@65RhF;QH]/Q@<100B5J`5[104018D1QFH30@03Ri2;00<100B;T06@
0P400gL10@030BH000<100004`001040004200030@0002X0000<00040@00008101P0R`2;08/1X@2Q
0J40X@2Q0:41X@2Q0047R`030H^;00>;0`46R`030H^;00B;00<1Rh/018/20@B50`401F^5JhE[00<1
00B;T06@0P45T0@100>@0@40:@000`40000B00810P001040004/000030000`40000200030H^;00F;
00<1X@401j400`6QX@04X@0;0H^:RhZ;RP6:RhX00P406h/1RhF;QH^5R`6;QH^5RhF;0H^5RhF;JhE[
Q@020@06IP5VQFJ50P401H^@Ri2;008100>@R`401@42M`81:`000`40000C00040@000@8000<10000
:P0000`000<100000`001`6;08/0R`000P404:40X@2Q0:400@2Q0:40X@47R`<118/00`6;R`05R`03
0H^;00B;00<1Rh/00h/2Q@8100F5JhD1Q@030@03T8/100<10i020@:@1@4_00030@00018000@10000
0P4]000030000`40000400030H^;00<10X/00`6QX@04X@030J6Q00JQ00H1RX^:RhX20@0HRhF;QH^5
0HF;QH^5RhD1QH^5RhF;Q@651@400fJ5IP040@03T8^@008100B;T8^@0P400gN@M`040C8000<10000
4`000`40000_000030000`400005008101J@Ri2;T8/1X@2Q0040X@2Q0:40X@010X/30@:;00<1Rh/0
18/00`6;R`04R`030H^;00B;0`401HZ;RXE[00<100B;T8^@0P42T0030I2@008100>@0@400`4e0003
0@0001800P4a000030000`40000600030H^;00B;00D1XJ6Q0@0;X@8101J5RhF;Q@65RhF;QH/1RhF;
QH^5R`6;10401XD1QH^5R`8100F;T06@R`020@05T8^@Ri000`42M`81>0000`40000C00030@0002l0
000<00030@0000L001@1Ri2;T8^@0@010:40X@2Q0:40X@8100<00H/01H/00`6;R`04R`030H^;00>;
0`4028^:RhZ;RP6:0P401I2;T8^@00810Y050@03T7N@0081>P000`40000C00030@0002l0000<0003
0@0000L000<1Rh/018/20@ZQ01H1RZ6:0HF;QH^5R`6;QH^5RhD1QH^50P4028/1RhF;QH^50`400h^@
0@030@03Ri2;008100B@0@5g0`4m00030@0001<000<10000;`0000`000<1000020000`6@R`030@:;
01010:40X@2Q0:41X@2Q0:411X/00`6;R`04R`<100J:RhZ;0H/40@03Ri2;00810i030@:@1@500003
0@0001<000<10000;`0000/000<100002P020@06RX^:RhX11Z420@0CRZ6:XHZQ0H^5RhF;Q@65RhF;
Q@020@06RhF;QH^50P40192;T8/20@04T8/1R`8100>@0@40105300030@0001<000<10000;`0000/0
00<100002`000`6;R`04R`0@0J40X@010:40X@2Q0:400@J;00<1R`400P4028X1RX^:RhZ;0P4018^@
0@44T0L1A`000`40000C00030@0002l0000;00030@0000/000P1RX^:RhZ;0@>Q0141XHZQRZ6:XHZQ
RP65RhF;Q@030@0=QH^5RhD1QH^5RhD1X0020@03T04100T1B0000`40000D00030@0002h0000;0003
0@0000`000<1Rh/018/30@0>0:40X@2Q0:40X@2Q0H/30@0@RP6:RhZ;RX/1RhZ;RX/1Y@<10Y040@05
Y@41X040B0000`40000D00030@0001`00P4800811P0000/000<1000030001P6;RX^:R`8100f:XHZQ
RZ6:XHZQRZ6:00<101>5RhF;Q@65RhF;QH/1RhF;0J6P008100>U0@400P400j2T0@050DL000<10000
50000`40000L00030@0000P000<10000100000/000<100003@000`6;0@020@:;00/1X@2Q0:40X@2Q
00020@0FX@6:RhZ;RX/1RhZ;RX^:0HZ;RP6PY@8100>P0J000P400jFP0@050DP000<100004P020@l0
0`4200030@0000<11000104000040@<000<10000100000/000<100003@020@0>RhF;QH/1XHZQRZ6:
XHX20@0HXHZQRP65RhF;QH/1RhF;QH/1RhF;0J6P0P400jD1Y@020@03X:@100D1B0000`40000C0003
0@0000h000@100010P000`40000500050@0000400P001@40000100H0000;00030@0000h000<1Rh/0
18/01P40X@2Q00811Z40406;RX^:RhX1RX^:RhZ;0H/20@07X:D10J01X0020@04Y@41X08100>T0@40
A`000`40000C00030@0000h00`4300<11@000`40000200030@0000<000<10000100000/000<10000
3P002`6;QH^5RhD1RZ6:008101FQRZ6:XHZQRZ41RhF;QH/1RhF;QH/00`402hX1X@6U0JD1Y@6U00<1
00>T0@400`5700030@0001<000<100003P001040004200040@000@@000<100000`000`4000020003
0@0000@0000:00030@00010000<1Rh/018/30@^Q00T1RX^:RhZ;0H/00`403X/1RhD1X06P0J01X06P
0`400j010@030DL000<100004`000`40000>00040@000@<00P4500040@0000@10`000`4000040000
2P000`40000@00060HF;QH^50P404j6:XHZQRZ6:XHZQRZ41RhF;QH/00`401HZ5RXF:008100ZPX@6U
0JD1Y@6U0P400j010@020@03X04104H000<100004`020@h0104;008120020@H0000:00030@000140
00<1R`400P400hZ;0@0=X@030H/1008100R;0H^5RhF;Q@8100ZUX06P0J01X06P0P400jD10@020@03
X04104H000<1000050000`4000040BT0000:00030@0001400P404XF;QH^50HZQRZ6:XHZQRZ6:X@<1
00^:QHZ5RP6:QHZ5RP020@0:X:41Y@6U0JD1Y@8100>P0J001@5600030@0001@000<100000P000`40
000X00002P000`40000A00090HZ;RX^:RhX100RQ0`406J41RhF;QH^50HF;QH^5R`6UX06P0J01X:D0
1@401JD10@6T0081A@000`40000D00030@00008000<10000:00000X000<100004P003@65RhF;QH/1
XHZQRZ400`407:6:XHZQ0HZ5RXF:0HZ5RXF:Q@6PX@6U0JD1YJ020@04Y@41X0<100>O0@40A@000`40
000D00030@00008000<10000:00000X000<100004P002P6;RX^:RhZ;0J430@RQ01L1QH^5RhF;0H^5
RhF;0JFP0J01X06PY@020@04X041Y@<100>T0@40A@000`40000C008110000`40000X00002P000`40
000C00060H^5RhF;0`408Z6:XHZQRZ6:XHZQ0HZ5RXF:Q@65RXF:0J6PX@6U0JD1YJ020@05Y@6T0J@0
1@5500030@0001@000<100000`4Z00002@000`40000D00040HZ;RP8100>;0J403:40606;QH^5R`6;
QH^50J2UX06P0J01X:D1Y@8100>50J000`400j010@1500030@0001<000<100000P000`40000X0000
2@000`40000E00<101Z5RXF:0J6:XHZQRZ6:XHZQRP65RXF:QHX1RP<100bQX:41Y@6U0JFP0J020@03
Y06T00<100>P0@40A@000`40000D00030@0002`0000900030@0001D000P1RhF;QH^50@bQ00H1RhF;
QH/30@0?RhD1X:D1YJ01X06PY@6U008100>P0J000`400j010@1500030@0001<00P4^00002@000`40
000E000G0HF:QHZ5RP6QRZ6:XHZQRZ6:XHZQ0HX00`400hD1Q@02Q@0=0J6P0J01X:D1YJ01X0040@03
Y06T008100>O0@00A0000`40000D00030@0002`0000900030@0001H000L1QH^5RhD100ZQ1@406h^5
RhD1QH^50J2U0JD1YJ01X:D1Y@6U0JD1Y@030@03Y04004@000<1000050000`40000/00002@000`40
000F000;0HZ5RXF:Q@6:XHX01P401:6:X@46Q@0F0HF50J6P0J01X:D1YJ01X06P0J01X0<100>O0@40
A0000`40000D00030@0002`0000900030@0001H000H1QH^5RhD50@VQ01d1QH^5RhF;0H/1YJ2U0JD1
YJ01X:D1Y@6U0JD1Y@030@03Y:0104@000<1000050000`40000/00002@000`40000G00030HD10081
01250HZQRZ6:XHZQRZ6:XHX11HD05P650J2QX06P0J2U0JFP0J01X06P0J020@04Y06P0D@000<10000
4`020Bh0000900030@0001L00P401HF;QH/100fQ01h1RhF;QH/1R`6UX:D1Y@6UX06PY@6U0JD1Y@6U
0J@20@03X04004<000<1000050000`40000/000020000`40000H00030HF500>500l1RZ6:XHZQRZ6:
XHZQRP401XD20@0>X:6P0J01X:D1YJ01K:D20@04X06PY0<100>P0@40@`000`40000E00030@0002/0
000800030@0001P000P1RhF;QH^50@bQ00L1RhF;QH^5008101BUX:D1Y@6UX06PY@6UX06P0J01X0<1
00>PY040@`000`40000E00030@0002/0000800030@0001P000<1QHD018D03`6QRZ6:XHZQRZ6:XHZQ
0@04Q@<101BPXJ01X06PY@6UX06PY@6U0J@1Y08100BP0Il1@`000`40000E00030@0002/000080003
0@0001T000L1QH^5RhD100fQ00<1Q@400P406HD1X:FPY@6U0JFP0J2UX06P0J01X06P0J000P400j@1
001300030@0001@000<10000:`0000P000<100006@000`65Q@02QA4101a/QFb50J6PX@6UX06PY@6U
X:D1Y@6U0J@1Y06T0P400il1001300030@0001<00P4]000020000`40000I00030HD1008100>50J40
3:407@65RXF:Q@6PYJ01X:D1YJ01X:FP0J01X06P0J2U00<100>T0@00@`000`40000D00030@0002/0
000800030@0001T00P40;fb5K8D1XHFQQJ65XHFQQJ65X@65K8E/Q@6QX:41YJ01X:D1YJ2U0JD1Y@6T
0JBP008100>T0@40A0000`40000D00030@0002/0000800030@0001T000P1QHZ5RXF:0@bQ01P1QHZ5
RXD1X:FP0J2U0JFP0J2UX06P0J020@03Y@6U008100>P0@40A0000`40000D00030@0002/000070003
0@0001X003<1QFb5K8E/0HFQQJ65XHFQQJ65XHD1K8E/Q@6QX:41YJ01X:D1YJ2U0JD1YJ01X06P0J00
0`5400030@0001D000<10000:P0000L000<100006`001`6:QHZ5RP403J407P6:QHX1YJ2UX06PY@6U
X06PYJ01X:D1Y@6U0JD1Y0<1@`020AH00P4/00001`000`40000K00050Fb5K8D01@409j65XHFQQJ65
XHD1K8E/0J2QX:41YJ01X:D1YJ2U0JFP0J01X06PY0020@03X04003h0104200030@0001@000<10000
:P0000L000<100006`000`6:0@020@03Q@6Q00:Q1`43X@030HX1008101RUX:FP0J2U0JFP0J2UX06P
Y@6U0JD1YJ020@03Y04003/00`4700030@0001<000<10000104V00001`000`40000K008100n5JhE[
0HBQQ:64XHBQQ:401@407HE[0J2QX:41YJ01X:FP0J2U0JFP0J01X06PY06T0081>@030@X000<10000
4`001040004Y00001`000`40000K00030HF500>500<1XJ402j407`65QHD1YJ2UX06PY@6UX:D1YJ01
X:D1Y@6UX06P0J000P4e00@13P000`40000B00050@000040:00000L000<100006`00;05[QF^5J`64
XHBQQ:64XHBQQ:640F^5J`6PXJ01X:FP0J2UX06PY@6UX06P0P401:@1Y:030C800`4C00030@000100
0P4400030@0002D0000700030@0001/000<1QHD00hD00`6QX@0;X@0N0HF50J2UX:D1YJ2U0JFPY@6U
X06PY@6UX06P0J2U0`4^00@15`000`40000@00030@0000<000<10000900000L000<100006`00=@5[
QF^5J`64XHBQQ:64XHBQQ:640F^50J6PXJ01X:FP0J2UX06PY@6UX06PY@6T0JBP0J0102/00`4L0003
0@00010000<100400P000`40000T00001P000`40000L00030HF500:5104;X@0Q0HF50J2UX:D1YJ2U
0JFPY@6UX06PY@6UX06P0J2U0J@102P00`4O00030@00010000<100000P4W00001P000`40000L0003
0F/1008100AV0HBQ1@409j64XHBQQ05[Q@6QX:6P0J2UX06PYJ01X:D1YJ01X:D1Y:01X06P0@0T00@1
8`000`40000?00030@0002T0000600030@0001`00P401HB5Q8D100NQ1042X@0O0HF50J2UX:D1YJ2U
0JFPY@6UX06PYJ01X06PY@6UX0020B400`4X00030@0000d00P4[00001P000`40000L000B0FJ5IXEV
0HBQQ:64XHBQQ:641P406j6PXJ01X:FP0J2UX06PYJ01X:D1Y@6TX06PY0020Ad0104/00030@0000d0
00<10000:@0000H000<1000070001`65Q8F4Q@403J407`65Q06PYJ2U0JFPY@6UX:D1YJ2U0JFP0J2U
0JD1YJ000P4J00<1<@000`40000<00030@0002T0000600030@0001`000D1IXEVQ@030@0[XHBQQ:64
XHBQQ:640FH1X:6PXJ01X:FP0J2UX06PYJ01X:D1YJ01X06PY0020AL00`4d00030@0000`000<10000
:@0000H000<1000070000`650@020@03Q@6Q00812Z407`650JFPYJ2U0JFPY@6UX:D1YJ2U0JFP0J2U
0JD1YJ000P4C00@1>0000`40000;00030@0002T0000600030@0001`00P4028AVQ6H1Q:640P40:J64
XHBQQ:640FH1X:6PXJ01X:FP0J2UX06PYJ01X:D1YJ01X:@1Y:0101000`4m00030@0000X00P4Z0000
1@000`40000M000<0HEVQFJ50J6PXJ2Q0`45X@0Q0HD1YJ2UX06PYJ2U0JFPY@6UX:D1YJ01X:D1YJ01
X:D100d00`5100030@0000T00P4Z00001@000`40000M000?0FJ4IX@1XHBQQ:64XHBQ008102B4XH@1
IP6PXJ2Q0JFPYJ01X:FP0J2UX06PY@6UX06PY06TX04900@1A@000`40000900030@0002P000050003
0@0001d00141QFJ5IP6PXJ2QX:6PXJ2QX0020@0RX@650JFPYJ01X:FPY@6UX:D1YJ2U0JFP0J2U0JFP
0J2U0@H00`5900030@0000T000<10000:00000D000<1000070001@64IXAV00<100b4XHBQQ:64XHBQ
Q:430@0NXJ2QX:41YJ2U0JFPYJ01X:FP0J2UX06PY@6T0J@10`040Dd000<1000020000`40000X0000
1@000`40000L00030FH1008100=V0I/00P402j6PXJ2QX:6PXJ2Q008101fPYJ2UX06PYJ01X:FPY@6U
X:D1YJ2U0JFP0J01X0040E8000<100001`000`40000X00001@000`40000L008100QUIVD1Q:64X@81
00V4XHBQQ:64XH@00P406j6PXJ2Q0JFPY@6UX:FP0J2UX06PYJ01X:D1Y0030EH000<100001@020BX0
000500030@0001`000`1IWmVO`6QVj6KXI/20@07XJ2QX:6PX@020@0FX:FPYJ01X:FP0J2UX:D1YJ2U
0JFPY@D100>U0@00E`000`40000500030@0002P0000500030@0001/000@1IFIU0P402J64XHBQQ:64
X@020@0KQ:64X@640J6PXJ2Q0JFPY@6UX:FP0J2UX06P00<100JPY@6TX05H00030@0000H000<10000
9`0000D000<100006`040@0=H0410I^QVj6KXI^QV`020@0EXJ01IP6PYJ2UX06PYJ01X:FPY@6U00@1
00VPY@6UX06PY@40F@000`40000500030@0002L0000400030@0001/00P43H00?0HBPQ064XHBQQ:64
XHBQ00@100jPXJ2QX:41YJ2U0JFPY@<100ZUX06PYJ01X:FP0P5K00030@0000@000<100009`0000@0
00<100006`005P5PIF1U0J6KXI/1Vj6KXI^QVj6KXI/20@0:YJ2UX:FP0J2UX0@100fU0JFPY@6UX:D1
YJ2U0081G0000`40000300030@0002L0000400030@0000L00P4A00040F1PH08100JPQ:24X8@20@09
XHBQQ:64XHBQ008100NPXJ2QX06P00@1016UX:FP0J2UX:D1YJ01X:FP0@1N00040@000081:@0000@0
00<100000`040@:@0P4?00D1016P0J6KXI^QVj41XI^QVj6KX@030@04YJ2UX0<101FPYJ01X:FPY@6U
X:FP0J2UX06PY@40GP000`40000200030@0002L0000400040@00008100R;T8^@Ri01VP8130020@96
00`1X8BP0J24X8BPQ:020@03Q:4100<100>;T0400`405j01X:FPY@6UX:FP0J2UX:D1YJ2U0JD10600
00D100000@030081900000@000<100000P020@J@00<1VYX00P4900030FE6008100FPVj2KX0020@05
Vj6KXI/01043T0<10Y006@6PY@6UX:FP0J2UX:D1YJ2UX06PYJ01X040H@001040004200040@000B<0
000400030@0000@00P400i2;0@030@03VYT100811P050@08V`6PQ:24X8@50@03Ri2;00@100J@Ri2;
T8/30@0BX:FPY@6UX:FP0J2UX:D1YJ2U0P5S00040@000@@000<100008@0000@000<100001P020@>@
00H1VYX1WiX30@03004100<100RKX9^P0J2KX0<119060@N@0`404jFPYJ01X:FPY@6UX:FP0J2UX040
I@030@800P4T000010000`400008008100J@0IZIVP42VP0=0IX10I^JViX1VY^JV`030@04T8/1R`<1
00V;T8^@Ri01T8/010400i1gT0020@0>X:D1YJ2UX06PYJ2U0JD20FH000<1004010000`40000Q0000
0`000`40000;00<10YX03`6JW`6PVZ0109ZPVP6KX0020@:@1@48T0<12I030@09X:FPY@6UX:FP0081
J@020@05004000408`0000<000<100003@001@6I0IT100:J00P1VYZJ0@2JV`<100n@0@41T8^@Ri01
T8^@Ri000P400gN@M`020@08T7N@Mi1gT7L40@05YJ01X:D00`5W00030@0000810P020B@000030003
0@0000h000X1VYX1WiZO0J2J104019010@49T0030I2@00811i020@:@104017N@Mi060FP0104Z0000
0`000`40000>00050IZIVP400YX30@03R`41008100b@Ri01T8^@Ri2;T8/30@0;Mi1gT7N@Mi1gT7L0
0`44M`D1J0040Bh0000300030@0000l000<1VP400`4019010@48T0810Y040@>@0`43T0@100B@Mi1g
1P5W00@1<P0000<000<100003`020@03T8/1008100b;T8/1Ri2;T8^@Ri030@0:T7N@Mi1gT7N@M`@1
17L50F@000<10000104f00000`000`40000?00@11i020@:@1043T0<10i040@04Mi1gT0H1IP040CX0
000300030@0000`00`4300090I2;T8^@Ri2;00<100YgT7N@Mi1gT7N@1044M`D1IP040Ch000020003
0@0000T0104700810Y040@>@0`43T0@100B@Mi1g1P5U00@1@P00008000<100001P030@d00P402Y1g
T7N@Mi1gT7L40@Ag1@5S00030@0000<1AP00008000<100000`030A800`43T0@100AgT7N@1@5V00@1
B@00008000<100400`4H00@117L40FH0105=00000P020B0010400`01001S00@1D@0000<00`4S0003
0@0005`000<100400`5E00001@000`40000Q00030@0005X0105I00001P020B0000<10000E`040A80
00<10000B00000L00`4N00030@0005@00`4F00030@0004P0000900030@0001`000<10000C`050AH0
1@5900000P020@H00P400`01000I00030@0004`0104J00040@000DX000001@01000100H00`4J0003
0@0004P0104O00030@0104X000001@01000100L00`4I00030@00044000<10000104T0081BP000005
004000402@020AP000<10000@0040BT000<10000B0000005004000402`000`40000E00030@0003`0
105h000000D00@000@0<00815@000`40000h00@1O0000080104400030@0000801P4C00030@0003<0
00<100400P6000000`001040004;00040@010A8000<10000<@040H<0000300040@000@/000@10001
4P000`40000]00@1Q`0000<000@1000120030@@00P4@00030@0002T0106;00000`00104000480003
0@0000H00P4>00030@0002D0106?00000`001040004800030@0000L000<1004030000`40000Q00@1
T`0000@00P4900@11`020@`000<100007@040A00106300004`040@D000<1004020000`40000J00@1
50000`40002400005@000`400005008120000`40000G00@160000`40002300005@000`40000600<1
1P000`40000C00@17@000`40002200005@000`40000800811@000`40000=00030@0100<18P000`40
002100005@000`400009008110000`40000;00@18`001040006300004`030@d000D100000@0900@1
:0020H@0000E00@10`000`40000200L10P000`4000040K80000G00030@0000X010400`010@020KH0
000G00030@0000X000<100400P6j00005`000`40000700<1AP000`400@1f00005`000`4000070003
0@0004H000<10040MP0001D00`4900030@0004D000D100400@1e00004`020@8000<100000`020@80
10440081?P001@400@0107D0000C00030@0000P000<100000`050@8000<10000>`0010400@020G@0
000400D100D00@0100020@<000@10000104300030@0000<000D100000@0200030@000;D000060009
0@0000400@0100@000D100000@0200050@0000401P001040004200030@000;D0000600090@000040
0@0100@000<100000P000`40000300030@0000D000<100400P000`40002e00001P002@4000010040
0@0400030@0000<000<100000P000`40000600810P000`40002e00001P00104000020@03004000@0
00@10000104300030@0000<000D1000100020KP0000400D12P020@P00P460081_0000><0003S0000
h`000><0003S0000h`000><0003S0000h`000><0003S0000h`000><0003S0000h`000><0003S0000
h`000001\
\>"],
  ImageRangeCache->{{{0, 226.812}, {223.812, 0}} -> {0.0016671, -0.0717526, 
  0.00536599, 0.00536599}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3 Optimization with OPTDesign ", "Section"],

Cell[CellGroupData[{

Cell["\<\
OPTDesign[p,Radius->r0,Center->k0 (* GridPoints -> wpts *)];
\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[BoxData[
    \("\nParameterization for internal stability:"\)], "Print"],

Cell[BoxData[
    \("  T = A + B * T1, where T1 is RHP stable and"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("A[s]="\[InvisibleSpace]\(\( - 5.`\) + s
            \)\/\((\(2.`\[InvisibleSpace]\) + s)\)\^2\),
      SequenceForm[ "A[s]=", 
        Times[ 
          Plus[ -5.0, s], 
          Power[ 
            Plus[ 2.0, s], -2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("B[s]="\[InvisibleSpace]\(\( - 5.`\) + s
            \)\/\((\(2.`\[InvisibleSpace]\) + s)\)\^2\),
      SequenceForm[ "B[s]=", 
        Times[ 
          Plus[ -5.0, s], 
          Power[ 
            Plus[ 2.0, s], -2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("  "\)], "Print"],

Cell[BoxData[
    \("Processing performance function..."\)], "Print"],

Cell[BoxData[
    \("Sampling Radius and Center ..."\)], "Print"],

Cell[BoxData[
    \("Smoothing Radius and Center ..."\)], "Print"],

Cell[BoxData[
    \("Optimization routine Anopt now number-crunching ..."\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("It :    Current Value    :  Step   : Optimality Tests  :  Error  : Sm. \
: Grid"\)], "Print"],

Cell[BoxData[
    \("   :     gammastar       :         :   flat   grAlign  :   ned   :     \
:"\)], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
------"\)], "Print"],

Cell[BoxData[
    \(" 0 : 2.2485924730083E+00 :   N/A   : 8.9E-01 : 1. E+00 :   N/A   : NON \
: 128"\)], "Print"],

Cell[BoxData[
    \(" 1 : 1.5972070924256E-01 : 1.8E+00 : 3.6E-03 : 0  E+00 : 1.3E-02 : NON \
: 128"\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("Summary"\)], "Print"],

Cell[BoxData[
    \("-------"\)], "Print"],

Cell[BoxData[
    \("gammastar = 1.597207092425607E-01"\)], "Print"],

Cell[BoxData[
    \("flat      = 3.5616725651E-03"\)], "Print"],

Cell[BoxData[
    \("grAlign   = 0           E+00"\)], "Print"],

Cell[BoxData[
    \("ned      = 1.32E-02"\)], "Print"],

Cell[BoxData[
    \("Calculating output functions ..."\)], "Print"],

Cell[BoxData[
    \("Resetting options ..."\)], "Print"],

Cell[BoxData[
    \("Done! "\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4 Producing a rational compensator", "Section"],

Cell[CellGroupData[{

Cell["Trat[s_] = RationalModel[s,DegreeOfDenominator -> 3]", "Input"],

Cell[BoxData[
    InterpretationBox[\("Error = "\[InvisibleSpace]0.171724347370698549`\),
      SequenceForm[ "Error = ", 0.17172434737069855],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\(-5.`\) + s\)\/\((\(2.`\[InvisibleSpace]\) + s)\)\^2 + 
      \(\((\(1.96197999152904856`\[InvisibleSpace]\) + 
              0.805659853329509267`\ s)\)\ 
          \((\(-5.`\) + s)\)\)\/\(\((
            \(-1.58062453779134663`\) - 0.41937546220865336`\ s)\)\ 
          \((\(2.`\[InvisibleSpace]\) + s)\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplifying the compensator", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
comp1[s_] =   1/p[s]  Trat[s]/(1-Trat[s]) ; 
PlotZP[comp1[s],s,Frame -> True];\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.569044 0.0783556 0.5 0.454545 [
[.09891 -0.0125 -6 -9 ]
[.09891 -0.0125 6 0 ]
[.25562 -0.0125 -6 -9 ]
[.25562 -0.0125 6 0 ]
[.41233 -0.0125 -6 -9 ]
[.41233 -0.0125 6 0 ]
[.56904 -0.0125 -3 -9 ]
[.56904 -0.0125 3 0 ]
[.72576 -0.0125 -3 -9 ]
[.72576 -0.0125 3 0 ]
[.88247 -0.0125 -3 -9 ]
[.88247 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04545 -12 -4.5 ]
[-0.0125 .04545 0 4.5 ]
[-0.0125 .27273 -24 -4.5 ]
[-0.0125 .27273 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .72727 -18 -4.5 ]
[-0.0125 .72727 0 4.5 ]
[-0.0125 .95455 -6 -4.5 ]
[-0.0125 .95455 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09891 0 m
.09891 .00625 L
s
[(-6)] .09891 -0.0125 0 1 Mshowa
.25562 0 m
.25562 .00625 L
s
[(-4)] .25562 -0.0125 0 1 Mshowa
.41233 0 m
.41233 .00625 L
s
[(-2)] .41233 -0.0125 0 1 Mshowa
.56904 0 m
.56904 .00625 L
s
[(0)] .56904 -0.0125 0 1 Mshowa
.72576 0 m
.72576 .00625 L
s
[(2)] .72576 -0.0125 0 1 Mshowa
.88247 0 m
.88247 .00625 L
s
[(4)] .88247 -0.0125 0 1 Mshowa
.125 Mabswid
.13809 0 m
.13809 .00375 L
s
.17727 0 m
.17727 .00375 L
s
.21644 0 m
.21644 .00375 L
s
.2948 0 m
.2948 .00375 L
s
.33398 0 m
.33398 .00375 L
s
.37316 0 m
.37316 .00375 L
s
.45151 0 m
.45151 .00375 L
s
.49069 0 m
.49069 .00375 L
s
.52987 0 m
.52987 .00375 L
s
.60822 0 m
.60822 .00375 L
s
.6474 0 m
.6474 .00375 L
s
.68658 0 m
.68658 .00375 L
s
.76493 0 m
.76493 .00375 L
s
.80411 0 m
.80411 .00375 L
s
.84329 0 m
.84329 .00375 L
s
.05973 0 m
.05973 .00375 L
s
.02056 0 m
.02056 .00375 L
s
.92164 0 m
.92164 .00375 L
s
.96082 0 m
.96082 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04545 m
.00625 .04545 L
s
[(-1)] -0.0125 .04545 1 0 Mshowa
0 .27273 m
.00625 .27273 L
s
[(-0.5)] -0.0125 .27273 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .72727 m
.00625 .72727 L
s
[(0.5)] -0.0125 .72727 1 0 Mshowa
0 .95455 m
.00625 .95455 L
s
[(1)] -0.0125 .95455 1 0 Mshowa
.125 Mabswid
0 .09091 m
.00375 .09091 L
s
0 .13636 m
.00375 .13636 L
s
0 .18182 m
.00375 .18182 L
s
0 .22727 m
.00375 .22727 L
s
0 .31818 m
.00375 .31818 L
s
0 .36364 m
.00375 .36364 L
s
0 .40909 m
.00375 .40909 L
s
0 .45455 m
.00375 .45455 L
s
0 .54545 m
.00375 .54545 L
s
0 .59091 m
.00375 .59091 L
s
0 .63636 m
.00375 .63636 L
s
0 .68182 m
.00375 .68182 L
s
0 .77273 m
.00375 .77273 L
s
0 .81818 m
.00375 .81818 L
s
0 .86364 m
.00375 .86364 L
s
0 .90909 m
.00375 .90909 L
s
.25 Mabswid
0 0 m
0 1 L
s
.09891 .99375 m
.09891 1 L
s
.25562 .99375 m
.25562 1 L
s
.41233 .99375 m
.41233 1 L
s
.56904 .99375 m
.56904 1 L
s
.72576 .99375 m
.72576 1 L
s
.88247 .99375 m
.88247 1 L
s
.125 Mabswid
.13809 .99625 m
.13809 1 L
s
.17727 .99625 m
.17727 1 L
s
.21644 .99625 m
.21644 1 L
s
.2948 .99625 m
.2948 1 L
s
.33398 .99625 m
.33398 1 L
s
.37316 .99625 m
.37316 1 L
s
.45151 .99625 m
.45151 1 L
s
.49069 .99625 m
.49069 1 L
s
.52987 .99625 m
.52987 1 L
s
.60822 .99625 m
.60822 1 L
s
.6474 .99625 m
.6474 1 L
s
.68658 .99625 m
.68658 1 L
s
.76493 .99625 m
.76493 1 L
s
.80411 .99625 m
.80411 1 L
s
.84329 .99625 m
.84329 1 L
s
.05973 .99625 m
.05973 1 L
s
.02056 .99625 m
.02056 1 L
s
.92164 .99625 m
.92164 1 L
s
.96082 .99625 m
.96082 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .04545 m
1 .04545 L
s
.99375 .27273 m
1 .27273 L
s
.99375 .5 m
1 .5 L
s
.99375 .72727 m
1 .72727 L
s
.99375 .95455 m
1 .95455 L
s
.125 Mabswid
.99625 .09091 m
1 .09091 L
s
.99625 .13636 m
1 .13636 L
s
.99625 .18182 m
1 .18182 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .31818 m
1 .31818 L
s
.99625 .36364 m
1 .36364 L
s
.99625 .40909 m
1 .40909 L
s
.99625 .45455 m
1 .45455 L
s
.99625 .54545 m
1 .54545 L
s
.99625 .59091 m
1 .59091 L
s
.99625 .63636 m
1 .63636 L
s
.99625 .68182 m
1 .68182 L
s
.99625 .77273 m
1 .77273 L
s
.99625 .81818 m
1 .81818 L
s
.99625 .86364 m
1 .86364 L
s
.99625 .90909 m
1 .90909 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.56904 0 m
.56904 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
newpath
matrix currentmatrix
0.010658 0.0618278 scale
38.6873 8.08697 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.010658 0.0618278 scale
38.6873 8.08697 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.010658 0.0618278 scale
46.1333 8.08697 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.010658 0.0618278 scale
90.15 8.08697 1 0 365.73 arc
setmatrix s
.03355 .48182 m
.06991 .51818 L
s
.03355 .51818 m
.06991 .48182 L
s
.46906 .15883 m
.50542 .19519 L
s
.46906 .19519 m
.50542 .15883 L
s
.46906 .80481 m
.50542 .84117 L
s
.46906 .84117 m
.50542 .80481 L
s
.94264 .48182 m
.979 .51818 L
s
.94264 .51818 m
.979 .48182 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@000?l08@000?l08@000?l08@000?l08@000?l08@0003H00P4X00030@0002@0
104R00819P040BL000<100007@0003D000@100019`000`40000T00030@00028000@100019@000`40
000X00030@0001d0000e00040@000B@01@4V00030@00024000@100019P000`40000T00D17P0002l0
104200<180040@050040004080040@@000<1000080001040004W00030@0002<000@100017`0003D0
00<100009P000`400@0Y00030@0001l000@10001:0000`40000S00030@0101l0000e00030@0002L0
0P4V00040@000B4000@100019@001040004V00817`0003H00`4W00030@0002D00P4S00819`020BP0
00<100007@000?l08@0001/0o`450@40000K00030@00008000<100001`000`40000700030@0000P0
00<100001`000`40000700030@0000L000<100001`000`40000700030@0000P000<100001`000`40
000700030@0000L000<100001`000`40000700030@0000P000<100001`000`40000700030@0000L0
00<100001`000`40000800030@0000L000<100001`000`40000700030@0000L000<100001`010@40
000K00030@0001H000<100009P000`40000V00030@0002D000<100009P000`40000V00030@0001/0
0@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40
002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d0
0@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40
002@00030@0006d00@4100004`040@@000<10000T0000`40001]00410@0001D000<100000`020I40
00<10000K0020@40000E00030@0000<000<10000T0000`40001]00410@0000d0104400030@0000<0
00<10000T0000`40001]00410@0001D000<100000`000`40002@00030@0006d00@4100004`030@D0
00<10000T0000`40001]00410@0001D000<100000`000`40002@00030@0006d00@4100006`000`40
002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d0
0@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40
002@00030@0006d00@4100006`020I4000<10000K0020@40000K00030@00090000<10000K@010@40
000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@000900
00<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40
000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@000900
00<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40
000K0081T@000`40001/00810@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40
001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/0
00<10000T0000`40001]00410@0001/000<10000M`000`40000600030@0000d000<10000K@010@40
000K00030@0007P000<1000010000`40000>00030@0006d00@4100006`000`40001i00030@000080
00<100003`000`40001]00410@0001/000<10000NP001040004B00030@0006d00@4100006`000`40
001k00814`000`40001]00410@0001/000<10000N`020A<000<10000K@010@40000K0081N`001040
004B00030@0006`00P4100006`000`40001i00030@00008000<100003`000`40001]00410@0001/0
00<10000N0000`40000400030@0000h000<10000K@010@40000K00030@0007L000<100001P000`40
000=00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d0
0@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40
002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d0
0@4100006`020I4000<10000K0020@40000K00030@00090000<10000K@010@40000K00030@000900
00<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40
000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@000900
00<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40
000K00030@00090000<10000K@010@400008008110000`40000200<11@000`40002@00030@0006d0
0@4100001`001040004;00030@0000800P6A00030@0006`00P4100001`001040004;00030@000080
00<10000T0000`40001]00410@000003004100810P001040004800<11@000`40002@00030@0006d0
0@4100001`001040004800030@0000D000<10000T0000`40001]00410@0000L000@1000120000`40
000500030@00090000<10000K@010@40000800812@040@@000<10000T0000`40001]00410@0001/0
00<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40
001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/0
00<10000T0000`40001]00410@0001/00P6A00030@0006`00P4100006`000`40002@00030@0006d0
0@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40
002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d0
0@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40
002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d0
0@4100006`020I4000<10000K0020@40000K00030@00090000<10000K@010@40000K00030@000900
00<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40
000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@000900
00<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40
000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K0081T@000`40
001/00810@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/0
00<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40
001]00410@0001/000<10000T0000`40001]00410@0001/000<10000J0000`40000B00030@000100
00<10000H`000`40000700410@0001/000<10000I`000`400@0B00030@01014000<10000HP000`40
0@0800410@0001/000<10000IP001040004A00040@000A4000<10000HP000`400@0800410@0001/0
00<10000IP001@400001010000@100014@000`40001R00040@000@L00@4100006`020FL000D10000
0@0@00040@000A4000<10000H@001@40000100H00P4100006`000`40001V00050@00004040001@40
0001010000<10000H@001@40000100L00@4100006`000`40001V00050@0000403`000`4000020003
0@0000h000<10000H@001@40000100L00@4100006`000`40001V00050@0000403`000`4000020003
0@0000h000<10000H@000`40000200030@0000@00@4100006`000`40001U00030@00008000<10000
3@000`40000200030@0000h000<10000H@000`40000200030@0000@00@4100006`000`40001U0003
0@00008000<100003@000`40000200030@0000h000<10000H@000`40000200030@0000@00@410000
6`000`40001U00030@00008000<100003@000`40000200030@0000h000<10000H@000`4000020003
0@0000@00@4100006`000`40000500030@0000L000<10000D`000`40000200030@0000d000<10000
0P000`40000>00030@0005h000@1000110000`400@0400410@0001/000<100001P000`4000050003
0@0005@000<100000`000`40000<00030@00008000<100003P000`40001O00030@0100@00P450041
0@0001/000<100001`000`40000300030@0005D000<100000`000`40000<00030@00008000<10000
3P000`40001P008110000`40000400410@0001/000<1000020001@40000105P000<100000`000`40
000<00030@00008000<100003P000`40001P00810`020@H00@41000050020@D000<100002@000`40
0@1I00030@0000<000<1000030000`40000200030@0000h000<10000H0001`400@0100401P010@40
000C00040@000@@0o`450@40000C00040@000@@000<100002@000`400@1I00030@0000<000<10000
30000`40000200030@0000h000<10000H0001`400@0100401P010@40000C00040@000@@000<10000
20001@40000105P000<100000`000`40000<00030@00008000<100003P000`40001P00810`020@H0
0@4100004`001040004400030@0000L000<100000`000`40001E00030@0000<000<1000030000`40
000200030@0000h000<10000H0000`40000300030@0000@00@4100004`001040004400030@0000H0
00<100001@000`40001D00030@0000<000<1000030000`40000200030@0000h000<10000G`000`40
0@0400811@010@40000D00811@000`40000500030@0000L000<10000D`000`40000200030@0000d0
00<100000P000`40000>00030@0005h000@1000110000`400@0400410@0001/000<10000I@000`40
000200030@0000d000<100000P000`40000>00030@00064000<100000P000`40000400410@0001/0
00<10000I@000`40000200030@0000d000<100000P000`40000>00030@00064000<100000P000`40
000400410@0001/000<10000I@000`40000200030@0000d000<100000P000`40000>00030@000640
00D100000@0700410@0001/000<10000I@000`40000200030@0000d000<100000P000`40000>0003
0@00064000D100000@0700410@0001/000<10000IP001@40000100l000<100000P000`40000>0003
0@00064000D100000@0700410@0001/000<10000IP001@40000100l000D100000@0A00030@000640
00D100000@0700410@0001/00P5W00050@00004040001040004A00030@00068000@100011P020@40
000K00030@0006H000D100000@0@00040@000A4000<10000HP001040004700410@0001/000<10000
I`000`400@0A00040@000A4000<10000HP001040004700410@0001/000<10000I`000`400@0A0003
0@01018000<10000HP000`400@0800410@0001/000<10000J0000`40000A00030@00014000<10000
H`000`40000700410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]0041
0@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000
T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]0041
0@0001/00P6A00030@0006`00P4100006`000`40002@00030@0006d00@4100006`000`40002@0003
0@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@410000
6`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@0003
0@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@410000
6`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`020I4000<10000
K0020@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K0003
0@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000
K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K0003
0@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000
K@010@40000K0081T@000`40001/00810@0001/000<10000T0000`40001]00410@0001/000<10000
T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]0041
0@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000
T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]0041
0@0001/000<10000T0000`40001]00410@0000P00P4400030@0000800`4500030@00090000<10000
K@010@40000700040@000@/000<100000P020I4000<10000K0020@40000700040@000@/000<10000
0P000`40002@00030@0006d00@4100001`001040004800<11@000`40002@00030@0006d00@410000
1`001040004800030@0000D000<10000T0000`40001]00410@0000L000@1000120000`4000050003
0@00090000<10000K@010@40000800812@040@@000<10000T0000`40001]00410@0001/000<10000
T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]0041
0@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000
T0000`40001]00410@0001/00P6A00030@0006`00P4100006`000`40002@00030@0006d00@410000
6`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@0003
0@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@410000
6`000`40002@00030@0006d00@4100006`000`40001g00030@0000H000<100003@000`40001]0041
0@0001/000<10000N0000`40000400030@0000h000<10000K@010@40000K00030@0007T000<10000
0P000`40000?00030@0006d00@4100006`000`40001j00040@000A8000<10000K@010@40000K0081
O0020A<000<10000K0020@40000K00030@0007`000<100004@000`40001]00410@0001/000<10000
N`020A<000<10000K@010@40000K00030@0007X000@100014P000`40001]00410@0001/000<10000
N@000`40000200030@0000l000<10000K@010@40000K00030@0007P000<1000010000`40000>0003
0@0006d00@4100006`000`40001g00030@0000H000<100003@000`40001]00410@0001/000<10000
T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]0041
0@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/00P6A0003
0@0006`00P4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@410000
6`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@0003
0@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@410000
6`000`40002@00030@0006d00@4100006`000`40002@00030@0006d00@4100006`000`40002@0003
0@0006d00@4100006`020I4000<10000K0020@40000K00030@00090000<10000K@010@40000K0003
0@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000
K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K0003
0@00090000<10000K@010@40000K00030@00090000<10000K@010@40000K00030@00090000<10000
K@010@40000K00030@00090000<10000K@010@40000C00@110000`40002@00030@0006d00@410000
5@000`4000030081T@000`40001/00810@0001D000<100000`000`40002@00030@0006d00@410000
5@000`40000300030@00090000<10000K@010@40000E00030@0000<000<10000T0000`40001]0041
0@0001<00`4500030@00090000<10000K@010@40000E00030@0000<000<10000T0000`40001]0041
0@0001/000<10000T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<10000
T0000`40001]00410@0001/000<10000T0000`40001]00410@0001/000<100005P000`40000V0003
0@0002H000<100009@000`40000V00030@0002H000<100006`010@40000K00030@00008000<10000
1`000`40000700030@0000P000<100001`000`40000700030@0000L000<100001`000`4000070003
0@0000P000<100001`000`40000700030@0000L000<100001`000`40000700030@0000P000<10000
1`000`40000700030@0000L000<100001`000`40000800030@0000L000<100001`000`4000070003
0@0000L000<100001`010@40000K0?l11@410000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000
o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-8.60167, -1.26786, 0.0491564, 
  0.0084737}}]
}, Open  ]],

Cell["\<\
The pole-zero pair at s = 5 must be cancelled.  We do this \
with\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
comp2[s_] = CancelZP[comp1[s],s-5,s,Tolerance -> 0.001]

PlotZP[comp2[s],s,Frame -> True];\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[BoxData[
    \(\(\(-7.62710907475398869`\) - 15.3527968971711459`\ s - 
        9.63246509110562598`\ s\^2 - 
        1.93142195560427953`\ s\^3\)\/\(\(-17.662883529907476`\) - 
        25.7997339925336888`\ s - 14.5776431109872639`\ s\^2 - 
        1.67750184883461361`\ s\^3\)\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.868458 0.119584 0.5 0.454545 [
[.15095 -0.0125 -6 -9 ]
[.15095 -0.0125 6 0 ]
[.39012 -0.0125 -6 -9 ]
[.39012 -0.0125 6 0 ]
[.62929 -0.0125 -6 -9 ]
[.62929 -0.0125 6 0 ]
[.86846 -0.0125 -3 -9 ]
[.86846 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04545 -12 -4.5 ]
[-0.0125 .04545 0 4.5 ]
[-0.0125 .27273 -24 -4.5 ]
[-0.0125 .27273 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .72727 -18 -4.5 ]
[-0.0125 .72727 0 4.5 ]
[-0.0125 .95455 -6 -4.5 ]
[-0.0125 .95455 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15095 0 m
.15095 .00625 L
s
[(-6)] .15095 -0.0125 0 1 Mshowa
.39012 0 m
.39012 .00625 L
s
[(-4)] .39012 -0.0125 0 1 Mshowa
.62929 0 m
.62929 .00625 L
s
[(-2)] .62929 -0.0125 0 1 Mshowa
.86846 0 m
.86846 .00625 L
s
[(0)] .86846 -0.0125 0 1 Mshowa
.125 Mabswid
.21075 0 m
.21075 .00375 L
s
.27054 0 m
.27054 .00375 L
s
.33033 0 m
.33033 .00375 L
s
.44991 0 m
.44991 .00375 L
s
.50971 0 m
.50971 .00375 L
s
.5695 0 m
.5695 .00375 L
s
.68908 0 m
.68908 .00375 L
s
.74887 0 m
.74887 .00375 L
s
.80867 0 m
.80867 .00375 L
s
.09116 0 m
.09116 .00375 L
s
.03137 0 m
.03137 .00375 L
s
.92825 0 m
.92825 .00375 L
s
.98804 0 m
.98804 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04545 m
.00625 .04545 L
s
[(-1)] -0.0125 .04545 1 0 Mshowa
0 .27273 m
.00625 .27273 L
s
[(-0.5)] -0.0125 .27273 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .72727 m
.00625 .72727 L
s
[(0.5)] -0.0125 .72727 1 0 Mshowa
0 .95455 m
.00625 .95455 L
s
[(1)] -0.0125 .95455 1 0 Mshowa
.125 Mabswid
0 .09091 m
.00375 .09091 L
s
0 .13636 m
.00375 .13636 L
s
0 .18182 m
.00375 .18182 L
s
0 .22727 m
.00375 .22727 L
s
0 .31818 m
.00375 .31818 L
s
0 .36364 m
.00375 .36364 L
s
0 .40909 m
.00375 .40909 L
s
0 .45455 m
.00375 .45455 L
s
0 .54545 m
.00375 .54545 L
s
0 .59091 m
.00375 .59091 L
s
0 .63636 m
.00375 .63636 L
s
0 .68182 m
.00375 .68182 L
s
0 .77273 m
.00375 .77273 L
s
0 .81818 m
.00375 .81818 L
s
0 .86364 m
.00375 .86364 L
s
0 .90909 m
.00375 .90909 L
s
.25 Mabswid
0 0 m
0 1 L
s
.15095 .99375 m
.15095 1 L
s
.39012 .99375 m
.39012 1 L
s
.62929 .99375 m
.62929 1 L
s
.86846 .99375 m
.86846 1 L
s
.125 Mabswid
.21075 .99625 m
.21075 1 L
s
.27054 .99625 m
.27054 1 L
s
.33033 .99625 m
.33033 1 L
s
.44991 .99625 m
.44991 1 L
s
.50971 .99625 m
.50971 1 L
s
.5695 .99625 m
.5695 1 L
s
.68908 .99625 m
.68908 1 L
s
.74887 .99625 m
.74887 1 L
s
.80867 .99625 m
.80867 1 L
s
.09116 .99625 m
.09116 1 L
s
.03137 .99625 m
.03137 1 L
s
.92825 .99625 m
.92825 1 L
s
.98804 .99625 m
.98804 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .04545 m
1 .04545 L
s
.99375 .27273 m
1 .27273 L
s
.99375 .5 m
1 .5 L
s
.99375 .72727 m
1 .72727 L
s
.99375 .95455 m
1 .95455 L
s
.125 Mabswid
.99625 .09091 m
1 .09091 L
s
.99625 .13636 m
1 .13636 L
s
.99625 .18182 m
1 .18182 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .31818 m
1 .31818 L
s
.99625 .36364 m
1 .36364 L
s
.99625 .40909 m
1 .40909 L
s
.99625 .45455 m
1 .45455 L
s
.99625 .54545 m
1 .54545 L
s
.99625 .59091 m
1 .59091 L
s
.99625 .63636 m
1 .63636 L
s
.99625 .68182 m
1 .68182 L
s
.99625 .77273 m
1 .77273 L
s
.99625 .81818 m
1 .81818 L
s
.99625 .86364 m
1 .86364 L
s
.99625 .90909 m
1 .90909 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.86846 0 m
.86846 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
newpath
matrix currentmatrix
0.0114826 0.043646 scale
54.8039 11.4558 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0114826 0.043646 scale
54.8039 11.4558 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0114826 0.043646 scale
65.3511 11.4558 1 0 365.73 arc
setmatrix s
.06077 .48182 m
.09713 .51818 L
s
.06077 .51818 m
.09713 .48182 L
s
.72543 .15883 m
.7618 .19519 L
s
.72543 .19519 m
.7618 .15883 L
s
.72543 .80481 m
.7618 .84117 L
s
.72543 .84117 m
.7618 .80481 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@000?l08@000?l08@000?l08@000?l08@000?l08@0004@00P4m00030@0003T0
104h00818`0004<000@10001?0000`40000i00030@0003P000@100018P0004<000@10001>@050C/0
00<10000=`001040004R0000?@040@800`4e00@100D00@000@0e00@110000`40000f00040@000B80
001300030@0003/000<10040?P000`40000e00040@000B80001300030@0003`00P4k00040@000CL0
00@100018P0004@00`4l00030@0003X00P4i00818`000?l08@0001/0o`450@40000K00030@0000D0
00<1000030000`40000=00030@0000`000<100003@000`40000=00030@0000`000<100003@000`40
000<00030@0000d000<1000030000`40000=00030@0000`000<100003@000`40000<00030@0000d0
00<1000030001040004100006`000`40000T00030@0003/000<10000>`000`40000k00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100004`040@@000<10000gP000`40000O00410@0001D000<100000`020Ml0
00<100007P020@40000E00030@0000<000<10000gP000`40000O00410@0000d0104400030@0000<0
00<10000gP000`40000O00410@0001D000<100000`000`40003N00030@0001l00@4100004`030@D0
00<10000gP000`40000O00410@0001D000<100000`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`020Ml000<100007P020@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K0081g`000`40000N00810@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000^@000`40000700030@0001P000<100007`010@40
000K00030@000;X000<100001@000`40000I00030@0001l00@4100006`000`40002k00030@0000<0
00<100006P000`40000O00410@0001/000<10000_0001@40000101d000<100007`010@40000K0003
0@000;d00`4N00030@0001l00@4100006`000`40002m00030@0101h000<100007`010@40000K0081
_@001@40000101d000<100007P020@40000K00030@000;/000<100000`000`40000J00030@0001l0
0@4100006`000`40002j00030@0000D000<100006@000`40000O00410@0001/000<10000^@000`40
000700030@0001P000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K0081g`000`40000N00810@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0000P00P4400030@0000800`4500030@000=h0
00<100007`010@40000700040@000@/000<100000P020Ml000<100007P020@40000700040@000@/0
00<100000P000`40003N00030@0001l00@41000000<00@400P4200040@000@P00`4500030@000=h0
00<100007`010@40000700040@000@P000<100001@000`40003N00030@0001l00@4100001`001040
004800030@0000D000<10000gP000`40000O00410@0000P00P4900@110000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`020Ml000<100007P020@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K0081g`000`40000N00810@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
0P7O00030@0001h00P4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`020Ml000<100007P020@40000K00030@000:0000<100007@000`40
000K00030@0001l00@4100006`000`40002O00030@0101d000<1004070000`40000O00410@0001/0
00<10000W`000`400@0M00030@0101`000<100007`010@40000K00030@0009h000D100000@0K0005
0@0000406`000`40000O00410@0001/000<10000WP001@40000101X000<100000P000`40000I0003
0@0001l00@4100006`000`40002N00030@00008000<100005`000`40000200030@0001T000<10000
7`010@40000K00030@0000d000<100001P000`40002400030@0000<000<100005`000`4000020003
0@0001T000<100007`010@40000K00030@0000h000<1000010000`40002500030@0000<000<10000
5`000`40000200030@0001T000<100007`010@40000K00030@0000l000<100000P000`4000260003
0@0000<000<100005`000`40000200030@0001T000<100007`010@40000K00030@00010000@10001
R@000`40000300030@0001L000<100000`000`40000H00030@0001l00@41000050020@D000<10000
4@020HX000<100000`000`40000G00030@0000<000<1000060000`40000O00410@0001<000@10001
103o0@D10@0001<000@1000110000`40000A0081RP000`40000300030@0001L000<100000`000`40
000H00030@0001l00@4100004`001040004400030@00010000@10001R@000`40000300030@0001L0
00<100000P000`40000I00030@0001l00@4100004`001040004400030@0000l000<100000P000`40
002600030@0000<000<100005`000`40000200030@0001T000<100007`010@40000C00040@000@@0
00<100003P000`40000400030@0008D000<100000`000`40000G00030@00008000<100006@000`40
000O00410@0001@00P4500030@0000d000<100001P000`40002500030@00008000<100005`000`40
000200030@0001T000<100007`010@40000K00030@0009h000<100000P000`40000G00030@000080
00<100006@000`40000O00410@0001/000<10000WP000`40000200030@0001L000<100000P000`40
000I00030@0001l00@4100006`000`40002N00050@0000406P000`40000200030@0001T000<10000
7`010@40000K00030@0009l000@100016`001@40000101/000<100007`010@40000K00030@0009l0
00<1004070001040004L00030@0001l00@4100006`000`40002P00817@030A`000<100007`010@40
000K0081g`000`40000N00810@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/00P7O00030@0001h0
0P4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`020Ml000<100007P020@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K0081g`000`40
000N00810@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0000P00P4400030@0000800`4500030@000=h000<100007`010@40000700040@000@/0
00<100000P020Ml000<100007P020@40000700040@000@/000<100000P000`40003N00030@0001l0
0@4100001`001040004800<11@000`40003N00030@0001l00@4100001`001040004800030@0000D0
00<10000gP000`40000O00410@0000L000@1000120000`40000500030@000=h000<100007`010@40
000800812@040@@000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
0P7O00030@0001h00P4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40002i00030@0000L000<1000060000`40000O00410@0001/000<10000^P000`40
000500030@0001T000<100007`010@40000K00030@000;/000<100000`000`40000J00030@0001l0
0@4100006`000`40002l00050@0000407@000`40000O00410@0001/00P6n00030@0101h000<10000
7P020@40000K00030@000;h000<100007@000`40000O00410@0001/000<10000_@000`400@0N0003
0@0001l00@4100006`000`40002l00050@0000407@000`40000O00410@0001/000<10000^`000`40
000300030@0001X000<100007`010@40000K00030@000;X000<100001@000`40000I00030@0001l0
0@4100006`000`40002i00030@0000L000<1000060000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/00P7O00030@0001h0
0P4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40
003N00030@0001l00@4100006`000`40003N00030@0001l00@4100006`000`40003N00030@0001l0
0@4100006`020Ml000<100007P020@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h0
00<100007`010@40000K00030@000=h000<100007`010@40000K00030@000=h000<100007`010@40
000K00030@000=h000<100007`010@40000C00@110000`40003N00030@0001l00@4100005@000`40
00030081g`000`40000N00810@0001D000<100000`000`40003N00030@0001l00@4100005@000`40
000300030@000=h000<100007`010@40000E00030@0000<000<10000gP000`40000O00410@0001<0
0`4500030@000=h000<100007`010@40000E00030@0000<000<10000gP000`40000O00410@0001/0
00<10000gP000`40000O00410@0001/000<10000gP000`40000O00410@0001/000<10000gP000`40
000O00410@0001/000<10000gP000`40000O00410@0001/000<1000090000`40000k00030@0003/0
00<10000>`000`40000O00410@0001/000<100001@000`40000<00030@0000d000<1000030000`40
000=00030@0000d000<1000030000`40000=00030@0000`000<100003@000`40000<00030@0000d0
00<1000030000`40000=00030@0000`000<100003@000`40000<00040@000@40000K0?l11@410000
o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-8.13991, -1.26786, 0.032209, 
  0.0084737}}]
}, Open  ]],

Cell["Now we calculate the resulting closed loop function", "Text"],

Cell[CellGroupData[{

Cell["\<\
Trat2[s_] = Together[p[s] comp2[s]/(1 + p[s] comp2[s])]

PlotZP[Trat2[s],s,Frame -> True];\
\>", "Input"],

Cell[BoxData[
    \(\(4\ \((\(-5\) + s)\)\ 
        \((\(7.62710907475398869`\[InvisibleSpace]\) + 
            15.3527968971711459`\ s + 9.63246509110562598`\ s\^2 + 
            1.93142195560427953`\ s\^3)\)\)\/\(\(-505.79985209322924`\) - 
        1145.79985209323043`\ s - 1027.10007395338442`\ s\^2 - 
        454.200147906769124`\ s\^3 - 98.712564709211481`\ s\^4 - 
        8.3875092441730672`\ s\^5\)\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.429809 0.103671 0.5 0.454545 [
[.01513 -0.0125 -6 -9 ]
[.01513 -0.0125 6 0 ]
[.22247 -0.0125 -6 -9 ]
[.22247 -0.0125 6 0 ]
[.42981 -0.0125 -3 -9 ]
[.42981 -0.0125 3 0 ]
[.63715 -0.0125 -3 -9 ]
[.63715 -0.0125 3 0 ]
[.84449 -0.0125 -3 -9 ]
[.84449 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04545 -12 -4.5 ]
[-0.0125 .04545 0 4.5 ]
[-0.0125 .27273 -24 -4.5 ]
[-0.0125 .27273 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .72727 -18 -4.5 ]
[-0.0125 .72727 0 4.5 ]
[-0.0125 .95455 -6 -4.5 ]
[-0.0125 .95455 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01513 0 m
.01513 .00625 L
s
[(-4)] .01513 -0.0125 0 1 Mshowa
.22247 0 m
.22247 .00625 L
s
[(-2)] .22247 -0.0125 0 1 Mshowa
.42981 0 m
.42981 .00625 L
s
[(0)] .42981 -0.0125 0 1 Mshowa
.63715 0 m
.63715 .00625 L
s
[(2)] .63715 -0.0125 0 1 Mshowa
.84449 0 m
.84449 .00625 L
s
[(4)] .84449 -0.0125 0 1 Mshowa
.125 Mabswid
.06696 0 m
.06696 .00375 L
s
.1188 0 m
.1188 .00375 L
s
.17063 0 m
.17063 .00375 L
s
.2743 0 m
.2743 .00375 L
s
.32614 0 m
.32614 .00375 L
s
.37797 0 m
.37797 .00375 L
s
.48164 0 m
.48164 .00375 L
s
.53348 0 m
.53348 .00375 L
s
.58532 0 m
.58532 .00375 L
s
.68899 0 m
.68899 .00375 L
s
.74082 0 m
.74082 .00375 L
s
.79266 0 m
.79266 .00375 L
s
.89633 0 m
.89633 .00375 L
s
.94816 0 m
.94816 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04545 m
.00625 .04545 L
s
[(-1)] -0.0125 .04545 1 0 Mshowa
0 .27273 m
.00625 .27273 L
s
[(-0.5)] -0.0125 .27273 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .72727 m
.00625 .72727 L
s
[(0.5)] -0.0125 .72727 1 0 Mshowa
0 .95455 m
.00625 .95455 L
s
[(1)] -0.0125 .95455 1 0 Mshowa
.125 Mabswid
0 .09091 m
.00375 .09091 L
s
0 .13636 m
.00375 .13636 L
s
0 .18182 m
.00375 .18182 L
s
0 .22727 m
.00375 .22727 L
s
0 .31818 m
.00375 .31818 L
s
0 .36364 m
.00375 .36364 L
s
0 .40909 m
.00375 .40909 L
s
0 .45455 m
.00375 .45455 L
s
0 .54545 m
.00375 .54545 L
s
0 .59091 m
.00375 .59091 L
s
0 .63636 m
.00375 .63636 L
s
0 .68182 m
.00375 .68182 L
s
0 .77273 m
.00375 .77273 L
s
0 .81818 m
.00375 .81818 L
s
0 .86364 m
.00375 .86364 L
s
0 .90909 m
.00375 .90909 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01513 .99375 m
.01513 1 L
s
.22247 .99375 m
.22247 1 L
s
.42981 .99375 m
.42981 1 L
s
.63715 .99375 m
.63715 1 L
s
.84449 .99375 m
.84449 1 L
s
.125 Mabswid
.06696 .99625 m
.06696 1 L
s
.1188 .99625 m
.1188 1 L
s
.17063 .99625 m
.17063 1 L
s
.2743 .99625 m
.2743 1 L
s
.32614 .99625 m
.32614 1 L
s
.37797 .99625 m
.37797 1 L
s
.48164 .99625 m
.48164 1 L
s
.53348 .99625 m
.53348 1 L
s
.58532 .99625 m
.58532 1 L
s
.68899 .99625 m
.68899 1 L
s
.74082 .99625 m
.74082 1 L
s
.79266 .99625 m
.79266 1 L
s
.89633 .99625 m
.89633 1 L
s
.94816 .99625 m
.94816 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .04545 m
1 .04545 L
s
.99375 .27273 m
1 .27273 L
s
.99375 .5 m
1 .5 L
s
.99375 .72727 m
1 .72727 L
s
.99375 .95455 m
1 .95455 L
s
.125 Mabswid
.99625 .09091 m
1 .09091 L
s
.99625 .13636 m
1 .13636 L
s
.99625 .18182 m
1 .18182 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .31818 m
1 .31818 L
s
.99625 .36364 m
1 .36364 L
s
.99625 .40909 m
1 .40909 L
s
.99625 .45455 m
1 .45455 L
s
.99625 .54545 m
1 .54545 L
s
.99625 .59091 m
1 .59091 L
s
.99625 .63636 m
1 .63636 L
s
.99625 .68182 m
1 .68182 L
s
.99625 .77273 m
1 .77273 L
s
.99625 .81818 m
1 .81818 L
s
.99625 .86364 m
1 .86364 L
s
.99625 .90909 m
1 .90909 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.42981 0 m
.42981 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
newpath
matrix currentmatrix
0.0111643 0.04895 scale
19.9269 10.2145 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0111643 0.04895 scale
19.9269 10.2145 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0111643 0.04895 scale
29.3309 10.2145 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0111643 0.04895 scale
84.9276 10.2145 1 0 365.73 arc
setmatrix s
.02089 .48182 m
.05726 .51818 L
s
.02089 .51818 m
.05726 .48182 L
s
.20429 .48182 m
.24065 .51818 L
s
.20429 .51818 m
.24065 .48182 L
s
.20429 .48182 m
.24065 .51818 L
s
.20429 .51818 m
.24065 .48182 L
s
.20429 .48182 m
.24065 .51818 L
s
.20429 .51818 m
.24065 .48182 L
s
.20429 .48182 m
.24065 .51818 L
s
.20429 .51818 m
.24065 .48182 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@000?l08@000?l08@000?l08@000?l08@000?l08@00028000<10000<@040Bl0
0P4c00@1=0000`40000W00008P000`40000a00030@0002l000@10001<P000`40000e00030@0002L0
000O00D1<`000`40000^00040@000C<000<10000<@050BP0000J00@100D00@000@0]00@110000`40
000]00040@000C@000<10000<0001040004Y000080000`400@0f00030@0002`000@10001=@000`40
000`00030@0102T0000Q0081<`001040004^00040@000C8000@10001<`020BT0000R00030@000380
0P4`0081=0020CD000<100009`000?l08@0001/0o`450@40000K00050@00004030000`40000;0003
0@0000X000<100002`000`40000:00030@0000X000<100002`000`40000:00030@0000/000<10000
2P000`40000;00030@0000X000<100002`000`40000:00030@0000/000<100002P000`40000:0003
0@0000/000<100002P010@40000K00050@000040=@000`40000b00030@0003<000<10000<`000`40
000U00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001<0104400030@0006`000<10000T@010@40000E00030@0000<0
0P5]00030@0009000P4100005@000`40000300030@0006`000<10000T@010@40000=00@110000`40
000300030@0006`000<10000T@010@40000E00030@0000<000<10000K0000`40002A00410@0001<0
0`4500030@0006`000<10000T@010@40000E00030@0000<000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/00P5]00030@0009000P4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`020Fd000<10000T0020@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K0081K@000`40
002@00810@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/00P5]00030@0009000P4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@41000020020@@000<100000P030@D000<10000K0000`40
002A00410@0000L000@100012`000`4000020081K@000`40002@00810@0000L000@100012`000`40
000200030@0006`000<10000T@010@4000000`010@020@8000@1000120030@D000<10000K0000`40
002A00410@0000L000@1000120000`40000500030@0006`000<10000T@010@40000700040@000@P0
00<100001@000`40001/00030@0009400@41000020020@T0104400030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K0081K@000`40002@00810@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/00P5]00030@0009000P4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`020Fd0
00<10000T0020@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0003L0
00<1000060000`40000G00030@0008@000<100002P010@40000K0081=`000`400@0H00030@0101P0
00<10000P`000`400@0:00810@0001/000<10000=P000`400@0H00030@0101P000<10000P`000`40
0@0;00410@0001/000<10000=@001040004G00050@0000405`000`40002200050@0000402P010@40
000K00030@0003D000D100000@0F00050@0000405`000`40002200050@0000402P010@40000K0003
0@0003@000<100000P000`40000C00030@00008000<100005@000`40002200050@0000402P010@40
000K00030@0003@000<100000P000`40000C00030@00008000<100005@000`40002200050@000040
2P010@40000K00030@0003@000<100000P000`40000C00030@00008000<100005@000`4000210003
0@00008000<1000020010@40000K00030@00008000<100001`000`40000S00030@0100@000<10040
4`000`40000300030@0001@000<10000P@000`40000300030@0000L00@4100006`000`4000030003
0@0000D000<100009@020@@00P4D00030@0000<000<1000050000`40002100030@0000<000<10000
1`010@40000K00030@0000@000<100000`000`40000W00030@00008000<100004`000`4000030003
0@0001@000<10000P@000`40000300030@0000L00@4100006`000`40000500050@000040:P020@80
0P4E00030@0000<000<1000050000`40002100030@0000<000<100001`010@40000D00811@000`40
000600030@0102/000H10041004E00030@0000<000<1000050000`40002100030@0000<000<10000
1`010@40000C00040@000@@0o`450@40000C00040@000@@000<100001P000`400@0[00060@010@01
5@000`40000300030@0001@000<10000P@000`40000300030@0000L00@4100004`00104000440003
0@0000D000D100000@0Z00810P020AD000<100000`000`40000D00030@00084000<100000`000`40
000700410@0001<000@1000110000`40000400030@0000<000<100009`000`40000200030@0001<0
00<100000`000`40000D00030@00084000<100000`000`40000700410@0001<000@1000110000`40
000300030@0000D000<100009@020@@00P4D00030@0000<000<1000050000`40002100030@0000<0
00<100001`010@40000D00811@000`40000200030@0000L000<100008`000`400@0400030@0101<0
00<100000P000`40000E00030@00084000<100000`000`40000700410@0001/000<10000=0000`40
000200030@0001<000<100000P000`40000E00030@00084000<100000`000`40000700410@0001/0
00<10000=0000`40000200030@0001<000<100000P000`40000E00030@00084000<100000P000`40
000800410@0001/000<10000=0000`40000200030@0001@000D100000@0G00030@00088000D10000
0@0:00410@0001/000<10000=0000`40000200030@0001@000D100000@0G00030@00088000D10000
0@0:00410@0001/000<10000=0000`40000200030@0001@000D100000@0G00030@00088000D10000
0@0:00410@0001/000<10000=@001040004H00030@0101P000<10000P`000`400@0;00410@0001/0
0P4f00040@010AP000<1004060000`40002300030@0100X00P4100006`000`40000f00030@0001T0
00<100005`000`40002400030@0000X00@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`020Fd000<10000T0020@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K0081K@000`40002@00810@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/00P5]00030@0009000P4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@41000020020@@0
00<100000P030@D000<10000K0000`40002A00410@0000L000@100012`000`4000020081K@000`40
002@00810@0000L000@100012`000`40000200030@0006`000<10000T@010@40000700040@000@P0
0`4500030@0006`000<10000T@010@40000700040@000@P000<100001@000`40001/00030@000940
0@4100001`001040004800030@0000D000<10000K0000`40002A00410@0000P00P4900@110000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`020Fd000<10000T0020@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K0081K@000`40002@00810@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/00P5]00030@0009000P4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40
001/00030@0009400@4100006`000`40001/00030@0009400@4100006`000`40001/00030@000940
0@4100006`000`40001/00030@0009400@4100006`020Fd000<10000T0020@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`0
00<10000T@010@40000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40
000K00030@0006`000<10000T@010@40000K00030@0006`000<10000T@010@40000C00@110000`40
001/00030@0009400@4100005@000`4000030081K@000`40002@00810@0001D000<100000`000`40
001/00030@0009400@4100005@000`40000300030@0006`000<10000T@010@40000E00030@0000<0
00<10000K0000`40002A00410@0001<00`4500030@0006`000<10000T@010@40000E00030@0000<0
00<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40
002A00410@0001/000<10000K0000`40002A00410@0001/000<10000K0000`40002A00410@0001/0
00D100000@0e00030@00038000<10000<`000`40000c00030@0002D00@4100006`001@40000100`0
00<100002`000`40000:00030@0000/000<100002P000`40000:00030@0000/000<100002P000`40
000;00030@0000X000<100002`000`40000:00030@0000/000<100002P000`40000;00030@0000X0
00<100002P000`40000;00030@0000X00@4100006`3o0@D10@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@000?l08@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.15819, -1.26786, 0.0371529, 
  0.0084737}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.5 How good is the answer?", "Section"],

Cell[CellGroupData[{

Cell["Check that Trat satisfies the original requirements", "Subsection"],

Cell[CellGroupData[{

Cell["\<\

perf = Plot[ 1/r0[w] Abs[k0[w]-Trat2[I w]],{w,0,10},
                          PlotRange->{0.,2.},
                          Frame -> True,
                          DisplayFunction->Identity];
\t   Show[perf,
                Graphics[{Dashing[{0.05,0.05}],Line[{{0,1},{10,1}}]}],
                          DisplayFunction->$DisplayFunction]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.309017 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .14388 m
.02499 .14388 L
.02605 .14388 L
.02729 .14387 L
.02846 .14387 L
.03053 .14385 L
.03279 .14383 L
.0379 .14376 L
.04262 .14367 L
.04759 .14358 L
.05002 .14355 L
.05108 .14353 L
.05224 .14351 L
.05344 .10762 L
.05458 .10762 L
.05589 .10761 L
.0571 .1076 L
.0578 .1076 L
.05845 .1076 L
.05969 .1076 L
.06038 .1076 L
.06101 .1076 L
.06171 .10761 L
.06244 .10761 L
.06379 .10762 L
.06507 .10764 L
.06746 .10768 L
.0688 .10771 L
.07003 .10774 L
.07283 .10784 L
.07507 .10793 L
.07754 .10806 L
.08253 .1084 L
.088 .10891 L
.0939 .10964 L
.10458 .11144 L
.11415 .11359 L
.12462 .1165 L
.14572 .12375 L
.16697 .13215 L
.18628 .13994 L
.19592 .14371 L
.20099 .14564 L
.20637 .14764 L
.21106 .14934 L
.21235 .1498 L
.21306 .15005 L
.21373 .15028 L
.21504 .14292 L
.21623 .14267 L
Mistroke
.22533 .14068 L
.26357 .13137 L
.30427 .12091 L
.34345 .1112 L
.36346 .10652 L
.37398 .10415 L
.38508 .10172 L
.39506 .0996 L
.39779 .09903 L
.40072 .09842 L
.40214 .09813 L
.40348 .09785 L
.40468 .09761 L
.40599 .10683 L
.40718 .10697 L
.4083 .10709 L
.41084 .10738 L
.41598 .10796 L
.4252 .10896 L
.46394 .11278 L
.50514 .11624 L
.54481 .11909 L
.58297 .12144 L
.62359 .12361 L
.66268 .12541 L
.70423 .12707 L
.74427 .12846 L
.78279 .12964 L
.82376 .13074 L
.86321 .13167 L
.90115 .13247 L
.94154 .13323 L
.97619 .13382 L
Mfstroke
[ .05 .05 ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@0002000P4_00@1
;`000`40000]0081<0020B/010430081100001l000@10001;P000`40000`00030@0002`000@10001
;P001040004/00050@0000400P000`40000100007`001040004_00030@0002`01@4]00040@000Bh0
00@10001;0001@400001008000<100000@0001l000@10001<0000`40000[00040@000Bh00`4`0081
;@001@400001008000<100000@0001l000@10001<@000`40000[00030@0102h000<10000;`001040
004/00050@0000400P000`40000100007`001040004^00040@000Bh00P4^00030@0002l000@10001
:P030@<000@100010`0002000P4`0081<0000`40000]00<1;`020Bd000<100000P020@@0003o0240
003o0240000K0?l11@4100006`000`40000300030@0000T000<100002P000`40000900030@0000X0
00<100002@000`40000900030@0000X000<100002@000`40000900030@0000X000<100002@000`40
000900030@0000X000<100002@000`40000900030@0000X000<100002@000`40000900030@0000X0
00<100002@000`40000300410@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/0
0P7o00400P4100006`000`40003o00400@4100006`000`40003o00400@4100006`000`40003o0040
0@4100006`020Ol00@020@40000K00030@000?l00@010@40000K00030@000?l00@010@40000K0003
0@000?l00@010@40000K0081o`0100810@0001/000<10000o`0100410@0001/000<10000o`010041
0@0001/000<10000o`0100410@0001/00P7o00400P4100006`000`40003o00400@4100006`000`40
003o00400@4100000P020@@000<100000P040@800`4500030@000?l00@010@4000001@01000100P0
00<100001P000`40000200<1o`020@4000001@01000100T000<100001@000`40000200030@000?l0
0@010@4000001@01000100X000@100000`4500030@000?l00@010@4000001@01000100/000@10001
1`000`40003o00400@41000000D00@000@0800040@000@8000<100001@020Ol00@020@4000020081
2P020@<0104400030@0006@00`6I00410@0001/000<10000H0040@8000<10000U`010@40000K0003
0@0005X01P4600030@0009L00@4100006`020@`0305100813@0:0Hh00P4100006`000`40000;0003
0@0000T01P4g00@16@0:0HD00@4100006`000`40000;00030@0000l00P4`00D19`0;0GX00@410000
6`000`40000;00030@0001400`4Y00@1=`0D0FH00@4100006`020@`000<1000050030B80105?01D1
D0020@40000K00030@0000X000<1000060020A`0105X01l1<P010@40000K00030@0000X000<10000
6P030AD0106;02d11@010@40000K00030@0000X000<100007@020@h01@7100410@0001/00P4;0003
0@0001l00`4700@1a@020@40000K00030@0000<0204T008110000`40003800410@0001/000<10000
<@030@0300400<T00@41000020020@@000<100000P030@D000<10000=0000`40003900410@0000L0
00@100012`000`40000200<1o`020@40000700040@000@/000<100000P000`40003o00400@410000
1`001040004800<11@000`40003o00400@4100001`001040004800030@0000D000<10000o`010041
0@0000L000@1000120000`4000050081o`0100810@0000P00P4900@110000`40003o00400@410000
6`000`40003o00400@4100006`000`40003o00400@4100006`020Ol00@020@40000K00030@000?l0
0@010@40000K00030@000?l00@010@40000K00030@000?l00@010@40000K0081o`0100810@0001/0
00<10000o`0100410@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/00P7o0040
0P4100006`000`40003o00400@4100006`000`40003o00400@4100000P020@@000<100000`000`40
000200<11@000`40003o00400@41000000D00@000@0900030@0000D000<100000P030Ol00P410000
00D00@000@0:00030@0000@000<100000P000`40003o00400@41000000D00@000@0:00040@0000<1
1@000`40003o00400@41000000D00@000@0;00040@000@L000<10000o`0100410@00000500400040
20001040004200030@0000D00P7o00400P4100000P020@T0104200@110000`40003o00400@410000
6`000`40003o00400@4100006`000`40003o00400@4100006`020Ol00@020@40000K00030@000?l0
0@010@40000K00030@000?l00@010@40000K00030@000?l00@010@40000K0081o`0100810@0001/0
00<10000o`0100410@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/00P7o0040
0P4100006`000`40003o00400@4100006`000`40003o00400@4100004`040@@000<10000o`010041
0@0001D000<100000`030@<03P4<00h1300>0@`03P4<00h1300>0@`03P4<00h12`0>0@`03P450081
0@0001D000<100000`000`40003o00400@4100005@000`40000300030@000?l00@010@40000E0003
0@0000<000<10000o`0100410@0001<00`450081o`0100810@0001D000<100000`000`40003o0040
0@4100006`000`40003o00400@4100006`000`40003o00400@4100006`020Ol00@020@40000K0003
0@000?l00@010@40000K00030@000?l00@010@40000K00030@000?l00@010@40000K0081o`010081
0@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/0
0P7o00400P4100006`000`40003o00400@4100006`000`40003o00400@41000000<00@400P430003
0@000080104200<11@000`40003o00400@4100000`000`40000700030@0000H000<100000P030Ol0
0P4100000`000`40000800030@0000D000<100000P000`40003o00400@4100000`000`4000090004
0@0000<11@000`40003o00400@4100000`000`40000:00040@000@L000<10000o`0100410@000004
00410@T000@100010P000`4000050081o`0100810@0000<000<1000020020@<0104400030@000?l0
0@010@40000K00030@000?l00@010@40000K00030@000?l00@010@40000K0081o`0100810@0001/0
00<10000o`0100410@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/00P7o0040
0P4100006`000`40003o00400@4100006`000`40003o00400@4100006`000`40003o00400@410000
6`020Ol00@020@40000K00030@000?l00@010@40000K00030@000?l00@010@40000700@10`000`40
000200<11@000`40003o00400@4100002@000`40000:00030@0000800`7o00810@0000T000<10000
2P000`40000200030@000?l00@010@40000900030@0000L00`4500030@000?l00@010@4000090003
0@0000L000<100001@000`40003o00400@4100001`030@T000<100001@020Ol00@020@4000090003
0@0000L0104400030@000?l00@010@40000K00030@000?l00@010@40000K00030@000?l00@010@40
000K0081o`0100810@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/000<10000
o`0100410@0001/00P7o00400P4100006`000`40003o00400@4100006`000`40003o00400@410000
6`000`40003o00400@4100006`020Ol00@020@40000K00030@000?l00@010@40000K00030@000?l0
0@010@4000000`010@020@<000<100000`000`40000200<11@000`40003o00400@4100000`000`40
000800030@0000D000<100000P030Ol00P4100000`000`40000900030@0000@000<100000P000`40
003o00400@4100000`000`40000900040@0000<11@000`40003o00400@4100000`000`40000:0004
0@000@L000<10000o`0100410@00000400410@T000@100010P000`4000050081o`0100810@0000<0
00<100001`040@80104400030@000?l00@010@40000K00030@000?l00@010@40000K00030@000?l0
0@010@40000K0081o`0100810@0001/000<10000o`0100410@0001/000<10000o`0100410@0001/0
00<10000o`0100410@0001/00P7o00400P4100006`000`40003o00400@4100006`000`40003o0040
0@4100006`000`40003o00400@4100006`020Ol00@020@40000K00030@000?l00@010@40000K0003
0@0000<000<10000;`000`40000^00030@0002h000<10000;`000`40000^00030@0000<00@410000
4`040@@000<100000`000`40000900030@0000X000<100002@000`40000:00030@0000T000<10000
2@000`40000:00030@0000T000<100002@000`40000:00030@0000T000<100002@000`40000:0003
0@0000T000<100002@000`40000:00030@0000T000<100002@000`40000:00030@0000T000<10000
0`010@40000C00030@0000D0o`450@40000D00030@000?l02P0001D000<10000o`0900005P000`40
003o00P0000C00040@000Ol02P000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.36219, -0.152823, 
  0.0405086, 0.0124846}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bode Plots of closed loop transfer function", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
T2disc = Discretize[Trat2[s]];
bm = BodeMagnitude[T2disc,PlotLabel ->\"BodeMagnitudePlot\"];
bp = BodePhase[T2disc,PlotLabel -> \"Phase Bode Plot\"];
\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 1.49012 0.0952624 [
[.25 -0.0125 -11 -15 ]
[.25 -0.0125 11 0 ]
[.5 -0.0125 -5 -15 ]
[.5 -0.0125 5 0 ]
[.75 -0.0125 -8 -15 ]
[.75 -0.0125 8 0 ]
[1 -0.0125 -11 -15 ]
[1 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -29 -30 ]
[.5 -0.0125 29 -15 ]
[-0.0125 .06118 -18 -4.5 ]
[-0.0125 .06118 0 4.5 ]
[-0.0125 .15645 -18 -4.5 ]
[-0.0125 .15645 0 4.5 ]
[-0.0125 .25171 -18 -4.5 ]
[-0.0125 .25171 0 4.5 ]
[-0.0125 .34697 -18 -4.5 ]
[-0.0125 .34697 0 4.5 ]
[-0.0125 .44223 -18 -4.5 ]
[-0.0125 .44223 0 4.5 ]
[-0.0125 .5375 -18 -4.5 ]
[-0.0125 .5375 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34 -7.5 ]
[-0.01875 .30902 -18 7.5 ]
[0 .63053 -14 0 ]
[0 .63053 14 15 ]
[.25 .63053 -11 0 ]
[.25 .63053 11 15 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 15 ]
[.75 .63053 -8 0 ]
[.75 .63053 8 15 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -53 15 ]
[.5 .63053 53 30 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.25 0 m
.25 .61803 L
s
.5 0 m
.5 .61803 L
s
.75 0 m
.75 .61803 L
s
1 0 m
1 .61803 L
s
0 .06118 m
1 .06118 L
s
0 .15645 m
1 .15645 L
s
0 .25171 m
1 .25171 L
s
0 .34697 m
1 .34697 L
s
0 .44223 m
1 .44223 L
s
0 .5375 m
1 .5375 L
s
0 g
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.07526 0 m
.07526 .00375 L
s
.11928 0 m
.11928 .00375 L
s
.15051 0 m
.15051 .00375 L
s
.17474 0 m
.17474 .00375 L
s
.19454 0 m
.19454 .00375 L
s
.21127 0 m
.21127 .00375 L
s
.22577 0 m
.22577 .00375 L
s
.23856 0 m
.23856 .00375 L
s
.32526 0 m
.32526 .00375 L
s
.36928 0 m
.36928 .00375 L
s
.40051 0 m
.40051 .00375 L
s
.42474 0 m
.42474 .00375 L
s
.44454 0 m
.44454 .00375 L
s
.46127 0 m
.46127 .00375 L
s
.47577 0 m
.47577 .00375 L
s
.48856 0 m
.48856 .00375 L
s
.57526 0 m
.57526 .00375 L
s
.61928 0 m
.61928 .00375 L
s
.65051 0 m
.65051 .00375 L
s
.67474 0 m
.67474 .00375 L
s
.69454 0 m
.69454 .00375 L
s
.71127 0 m
.71127 .00375 L
s
.72577 0 m
.72577 .00375 L
s
.73856 0 m
.73856 .00375 L
s
.82526 0 m
.82526 .00375 L
s
.86928 0 m
.86928 .00375 L
s
.90051 0 m
.90051 .00375 L
s
.92474 0 m
.92474 .00375 L
s
.94454 0 m
.94454 .00375 L
s
.96127 0 m
.96127 .00375 L
s
.97577 0 m
.97577 .00375 L
s
.98856 0 m
.98856 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -34 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 15.000000 moveto
(H) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 15.000000 moveto
(\\220) show
105.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
111.000000 15.000000 moveto
(L) show
117.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
0 .06118 m
.00625 .06118 L
s
[(-15)] -0.0125 .06118 1 0 Mshowa
0 .15645 m
.00625 .15645 L
s
[(-14)] -0.0125 .15645 1 0 Mshowa
0 .25171 m
.00625 .25171 L
s
[(-13)] -0.0125 .25171 1 0 Mshowa
0 .34697 m
.00625 .34697 L
s
[(-12)] -0.0125 .34697 1 0 Mshowa
0 .44223 m
.00625 .44223 L
s
[(-11)] -0.0125 .44223 1 0 Mshowa
0 .5375 m
.00625 .5375 L
s
[(-10)] -0.0125 .5375 1 0 Mshowa
.125 Mabswid
0 .08024 m
.00375 .08024 L
s
0 .09929 m
.00375 .09929 L
s
0 .11834 m
.00375 .11834 L
s
0 .13739 m
.00375 .13739 L
s
0 .1755 m
.00375 .1755 L
s
0 .19455 m
.00375 .19455 L
s
0 .2136 m
.00375 .2136 L
s
0 .23266 m
.00375 .23266 L
s
0 .27076 m
.00375 .27076 L
s
0 .28981 m
.00375 .28981 L
s
0 .30887 m
.00375 .30887 L
s
0 .32792 m
.00375 .32792 L
s
0 .36602 m
.00375 .36602 L
s
0 .38508 m
.00375 .38508 L
s
0 .40413 m
.00375 .40413 L
s
0 .42318 m
.00375 .42318 L
s
0 .46129 m
.00375 .46129 L
s
0 .48034 m
.00375 .48034 L
s
0 .49939 m
.00375 .49939 L
s
0 .51844 m
.00375 .51844 L
s
0 .04213 m
.00375 .04213 L
s
0 .02308 m
.00375 .02308 L
s
0 .00403 m
.00375 .00403 L
s
0 .55655 m
.00375 .55655 L
s
0 .5756 m
.00375 .5756 L
s
0 .59465 m
.00375 .59465 L
s
0 .61371 m
.00375 .61371 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -95 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
75.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
gsave
0 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 .61178 m
.25 .61803 L
s
gsave
.25 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.75 .61178 m
.75 .61803 L
s
gsave
.75 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.07526 .61428 m
.07526 .61803 L
s
.11928 .61428 m
.11928 .61803 L
s
.15051 .61428 m
.15051 .61803 L
s
.17474 .61428 m
.17474 .61803 L
s
.19454 .61428 m
.19454 .61803 L
s
.21127 .61428 m
.21127 .61803 L
s
.22577 .61428 m
.22577 .61803 L
s
.23856 .61428 m
.23856 .61803 L
s
.32526 .61428 m
.32526 .61803 L
s
.36928 .61428 m
.36928 .61803 L
s
.40051 .61428 m
.40051 .61803 L
s
.42474 .61428 m
.42474 .61803 L
s
.44454 .61428 m
.44454 .61803 L
s
.46127 .61428 m
.46127 .61803 L
s
.47577 .61428 m
.47577 .61803 L
s
.48856 .61428 m
.48856 .61803 L
s
.57526 .61428 m
.57526 .61803 L
s
.61928 .61428 m
.61928 .61803 L
s
.65051 .61428 m
.65051 .61803 L
s
.67474 .61428 m
.67474 .61803 L
s
.69454 .61428 m
.69454 .61803 L
s
.71127 .61428 m
.71127 .61803 L
s
.72577 .61428 m
.72577 .61803 L
s
.73856 .61428 m
.73856 .61803 L
s
.82526 .61428 m
.82526 .61803 L
s
.86928 .61428 m
.86928 .61803 L
s
.90051 .61428 m
.90051 .61803 L
s
.92474 .61428 m
.92474 .61803 L
s
.94454 .61428 m
.94454 .61803 L
s
.96127 .61428 m
.96127 .61803 L
s
.97577 .61428 m
.97577 .61803 L
s
.98856 .61428 m
.98856 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06118 m
1 .06118 L
s
.99375 .15645 m
1 .15645 L
s
.99375 .25171 m
1 .25171 L
s
.99375 .34697 m
1 .34697 L
s
.99375 .44223 m
1 .44223 L
s
.99375 .5375 m
1 .5375 L
s
.125 Mabswid
.99625 .08024 m
1 .08024 L
s
.99625 .09929 m
1 .09929 L
s
.99625 .11834 m
1 .11834 L
s
.99625 .13739 m
1 .13739 L
s
.99625 .1755 m
1 .1755 L
s
.99625 .19455 m
1 .19455 L
s
.99625 .2136 m
1 .2136 L
s
.99625 .23266 m
1 .23266 L
s
.99625 .27076 m
1 .27076 L
s
.99625 .28981 m
1 .28981 L
s
.99625 .30887 m
1 .30887 L
s
.99625 .32792 m
1 .32792 L
s
.99625 .36602 m
1 .36602 L
s
.99625 .38508 m
1 .38508 L
s
.99625 .40413 m
1 .40413 L
s
.99625 .42318 m
1 .42318 L
s
.99625 .46129 m
1 .46129 L
s
.99625 .48034 m
1 .48034 L
s
.99625 .49939 m
1 .49939 L
s
.99625 .51844 m
1 .51844 L
s
.99625 .04213 m
1 .04213 L
s
.99625 .02308 m
1 .02308 L
s
.99625 .00403 m
1 .00403 L
s
.99625 .55655 m
1 .55655 L
s
.99625 .5756 m
1 .5756 L
s
.99625 .59465 m
1 .59465 L
s
.99625 .61371 m
1 .61371 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -114 11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(BodeMagnitudePlot) show
165.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.09751 .49839 Mdot
.17283 .49876 Mdot
.21696 .49938 Mdot
.24835 .50024 Mdot
.27277 .50134 Mdot
.29281 .50269 Mdot
.30984 .50427 Mdot
.32467 .50609 Mdot
.33783 .50814 Mdot
.3497 .51042 Mdot
.36052 .51291 Mdot
.37048 .51562 Mdot
.37975 .51854 Mdot
.38841 .52166 Mdot
.39657 .52497 Mdot
.40431 .52846 Mdot
.41167 .53213 Mdot
.41871 .53595 Mdot
.42547 .53991 Mdot
.43199 .544 Mdot
.4383 .5482 Mdot
.44443 .55249 Mdot
.45039 .55685 Mdot
.45622 .56126 Mdot
.46194 .56567 Mdot
.46755 .57007 Mdot
.47308 .57442 Mdot
.47854 .57868 Mdot
.48395 .58281 Mdot
.48932 .58674 Mdot
.49467 .59044 Mdot
.5 .59383 Mdot
.50533 .59684 Mdot
.51068 .59939 Mdot
.51605 .6014 Mdot
.52146 .60274 Mdot
.52692 .60332 Mdot
.53245 .60299 Mdot
.53806 .6016 Mdot
.54378 .59898 Mdot
.54961 .59493 Mdot
.55557 .58922 Mdot
.5617 .5816 Mdot
.56801 .57177 Mdot
.57453 .55939 Mdot
.58129 .54408 Mdot
.58833 .52537 Mdot
.59569 .50276 Mdot
.60343 .47562 Mdot
.61159 .44327 Mdot
.62025 .40486 Mdot
.62952 .35942 Mdot
.63948 .30579 Mdot
.6503 .24256 Mdot
.66217 .16801 Mdot
.67533 .07997 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{336, 207.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005@0000c`P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl0D@000?l0D@000?l0D@000:X000<10000
7P000`4000220000Z@000`40000C00030@0000X000<10000P@0009/000<100402`00104000040@<0
0P40100100020@050040004010030@@000<10000P@0009/000<100402`000`40000200030@000080
00@100010P001040004300030@0000D000D100000@230000VP001@400@0100X000<100000P000`40
000300<10P0010400043008110020@@000<10000P@0009X000D100400@0:00030@00008000<10000
1@001040004200030@00008000D100000@0600030@000840002J00040@0100812@001P40000100<1
0P020@@00`4400030@0000800`4300030@000840002Z00030@0000l000<100000`000`4000060003
0@000880002k0081T`000?l0D@000?l0D@000?l0D@000?l0D@000?l0D@000?l0D@000?l0D@000?l0
D@0007D00P4400030@000080104_00@1<P040@<00P4]00@10`020@@00P4R0000M0001040004:0003
0@00030000<10000<`001@400001008000<10000;0001@400001008000@100010P000`40000O0000
M0001040004:00030@00030000<10000<`001@400001008000<10000;0001@400001008000@10001
0P000`40000O0000M0001040004:00030@00030000<10000<`001@400001008000<10000;0001@40
0001008000@100010P000`40000O0000M0001040004:00030@00030000<10000<`001@4000010080
00<10000;0001@400001008000@100010P000`40000O0000M0001040004800<1<0030C<00`430004
0@000B`00`4300040@000@8000@100018@0007D00P4;00030@00030000<10000<`000`4000020081
;`000`400002008110020B80003o0540003o0540003o0540003o0540003o0540003o054000130>D1
:00004<00P4?00030@0000L000<1000010000`40000300050@0000400`001040004200040@000A00
00<100001`000`40000400030@00008000<100000P001@400001008000@100010P000`40000>0003
0@0000L000<1000010000`40000200030@00008000D100000@0200040@000@8000<100003P000`40
000700030@0000@000<100000P000`40000200050@0000400P001@4000400081:00004<000<10000
=P000c80000f0003<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000
=P000c80000f00030@0002H0001300030@0003H000<b0000=P000c80000f0003<P0003H000<10000
9P0004<00P4g0003<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80000f0003
<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f0003
0@0002H0001300030@0003H000<b0000=P000c80000f0003<P0003H000<100009P0004<00P4g0003
<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80000f0003<P0003H000<b0000
=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0000e00@1
0P030@D000<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000=`000`4000040003
0@00008000<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000=`000`4000040003
0@0000800P7P<P<1:00002l0104400040@0000<11@000`40000f0003<P0003H000<b0000=P000c80
000f00030@0002H0000g00050@0000401`000`40000f0003<P0003H000<b0000=P000c80000f0003
0@0002H0000e00<10`000`40000500030@0003H000<b0000=P000c80000f0003<P0003H000<10000
9P0003L000@1000010440081=`000c80000f0003<P0002@00P4@0003<P0003D00P4X0000@`000`40
000f0003<P0003H000<b00009@000`40000>0003<P0003H000<100009P0004<000<10000=P000c80
000f0003<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80
000f00030@0002H000130081=`000c80000f0003<P0003H000<b0000=@020BP0001300030@0003H0
00<b0000=P000c80000f0003<P0003H000<100009P0004<000<10000=P000c80000f0003<P0003H0
00<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0
001300030@0003H000<b0000=P000c80000f0003<P0003H000<100009P0004<00P4g0003<P0003H0
00<b0000=P000c80000e0081:00004<000<10000=P000c80000f0003<P0003H000<b0000=P000`40
000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0001300030@0003H0
00<b0000=P000c80000f0003<P0003H000<100009P0004<00P4g0003<P0003H000<b0000=P000c80
000e0081:00004<000<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000@`000`40
000f0003<P0003H000<b0000=P000c80000f00030@0002H0000e00@110000`40000300030@0003H0
00<b0000=P000c80000f0003<P0003H000<100009P0003L000<100000`000`4000030081h3830BP0
000g00030@0000D110000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0000_00@1
10001040004200030@0000<000<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000
=`001`40000100401@000`40000f0003<P0003H000<b00008@020A<000<b0000=P000`40000V0000
=@030@@00P4500030@0003H000<b0000=P000c80000R00030@00014000<b0000=P000`40000V0000
=`000`40000300030@0000<00P4g0003<P0003H000<b0000=P000c80000e0081:00004<000<10000
=P000c80000f0003<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000
=P000c80000f00030@0002H0001300030@0003H000<b0000=P000c80000f0003<P0003H000<10000
9P0004<00P4g0003<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80000f0003
<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f0003
0@0002H0001300030@0003H000<b0000=P000c80000f0003<P0003H000<100009P0004<000<10000
=P000c80000f0003<P0003H000<b0000=P000`40000V0000@`020CL000<b0000=P000c80000f0003
<P0003D00P4X0000@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H000130003
0@0003H000<b0000=P000c80000f0003<P0003H000<100009P0004<000<10000=P000c80000f0003
<P0003H000<b0000=P000`40000V0000@`020CL000<b0000=P000c80000f0003<P0003D00P4X0000
@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0001300030@0003H000<b0000
=P000c80000N00815P000c80000f00030@0002H0000e00@10`020@D000<10000=P000c80000f0003
<P0001l000<1000050000c80000f00030@0002H0000g00050@0000400P000`4000020081h3830BP0
000g00030@0000@000<100000P000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0
000_00@110000`40000200811@000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0
000g00030@0000@000<100000P000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0
000e00<10`001040004400030@0003H000<b0000=P000c80000f0003<P0003H000<100009P0003L0
00<100000P020@D00P4g0003<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80
000f0003<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80
000f00030@0002H0001300030@0003H000<b0000=P000c80000f0003<P0003H000<100009P0004<0
0P4g0003<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80000f0003<P0003H0
00<b0000=P000`40000V00008@020@03004100<16P000`40000f0003<P0003H000<b0000=P000c80
000f00030@0002H0000P00040@000@8000@100016@000`40000f0003<P0003H000<b000070020AP0
00<b0000=P000`40000V000080001040004200040@000AT00P4g0003<P0003H000<b00007@000`40
000F0003<P0003D00P4X000080001040004200<16P000`40000f0003<P0003H000<b0000=P000c80
000f00030@0002H0000Q00<10P001040004I00030@0003H000<b0000=P000c80000f0003<P0003H0
00<100009P0002<000<100400`4J00030@0003H000<b0000=P000c80000f0003<P0003H000<10000
9P0002800P4O00030@0003H000<b0000=P000c80000f0003<P0003H000<100009P0004<00P4g0003
<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80000f0003<P0003H000<b0000
=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0000e00@1
0P040@@000<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000=`001@40000100L0
0P7P<P<1:00003L000<100000P000`40000400030@0003H000<b0000=P000c80000f0003<P0003H0
00<100009P0002l0104400030@0000<000<100000`000`40000f0003<P0003H000<b00006P020AX0
00<b0000=P000`40000V0000=`000`40000400030@00008000<10000=P000c80000f0003<P0001/0
00<1000060000c80000f00030@0002H0000e00<10`00104000440081=`000c80000f0003<P0003H0
00<b0000=@020BP0000g00030@0000800P4500030@0003H000<b0000=P000c80000f0003<P0003H0
00<100009P0004<000<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000@`000`40
000f0003<P0003H000<b0000=P000c80000f00030@0002H0001300030@0003H000<b0000=P000c80
000f0003<P0003H000<100009P0004<00P4g0003<P0003H000<b0000=P000c80000e0081:00004<0
00<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H0
00<b0000=P000c80000f00030@0002H0001300030@0003H000<b0000=P000c80000f0003<P0003H0
00<100009P0004<00P4g0003<P0003H000<b00005`020Ad000<b0000=@020BP0001300030@0003H0
00<b0000=P000c80000H00030@0001/000<b0000=P000`40000V0000@`000`40000f0003<P0003H0
00<b0000=P000c80000f00030@0002H0001300030@0003H000<b0000=P000c80000f0003<P0003H0
00<100009P0004<00P4g0003<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80
000f0003<P0003H000<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80
000f00030@0002H0000e00@10P040@@000<10000=P000c80000f0003<P0003H000<b0000=P000`40
000V0000=`000`40000300030@0000<000<10000=P000c80000f0003<P0001D00P4O0003<P0003H0
00<100009P0003L000<100000`000`4000030081RC800`4b<P1D<P<1:00002l0104400030@0000<0
00<100000`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0000g00030@0000<0
00<100000`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0000e00<10`030@D0
00<10000=P000c80000f0003<P0003H000<b0000=P000`40000V0000=`000`40000300030@0000<0
0P4g0003<P0003H000<b0000=P000c80000e0081:00004<000<10000=P000c80000f0003<P0003H0
00<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0
001300030@0003H000<b0000=P000c80000D008180000c80000f00030@0002H000130081=`000c80
000f0003<P0001D000<100007P000c80000e0081:00004<000<10000=P000c80000f0003<P0003H0
00<b0000=P000`40000V0000@`000`40000f0003<P0003H000<b0000=P000c80000f00030@0002H0
001300030@0003H000<b0000=P000c80000f0003<P0003H000<100009P0004<000<100004P020@l0
0P4900811@020CP000<b0000=P000c80000f00030@0002H00013008150000`40000>00030@0000P0
00<100001000104000020@<00P420081:P000c80000B00818P000c80000e0081:00004<000<10000
=P000c80000200030@00008000H100000@020@03004102@000<b00004`000`40000P0003<P0003H0
00<100009P0004<000<10000=P000c80000>00050@000@00104O0003<P0003H000<b0000=P000`40
000V0000@`000`40000f0003<P0001@000@100400P4L0003<P0003H000<b0000=P000`40000V0000
@`020CL000<b00006@050AP000<b0000=P000c80000e0081:00004<000<10000=P000c80000K0004
0@010AL000<b000040020B@000<b0000=P000`40000V0000@`000`40000f0003<P0001h00`4E0003
<P00014000<100008P000c80000f00030@0002H0000e00@10`020@D000<10000=P000c80000P00<1
4`000c80000f0003<P0003H000<100009P0003L000D100000@0200030@0000800P5L<P@1P3830BP0
000g00050@0000400P000`40000200030@0003H000<b00008`000`400@020@h000<b00003`020BD0
00<b0000=P000`40000V0000;`040@@000D100000@0200030@00008000<10000=P000c80000W0081
3@000c80000@00030@0002<000<b0000=P000`40000V0000=`001@400001008000<100000P000`40
000f0003<P0002P00P4<0003<P0003H000<b0000=P000`40000V0000=@030@<000@1000110000`40
000f0003<P0002T00`4:0003<P0003H000<b0000=P000`40000V0000=`000`40000200811@020CL0
00<b0000:`020@T000<b00003@020BL000<b0000=@020BP0001300030@0003H000<b0000;0020@P0
00<b00003P000`40000U0003<P0003H000<100009P0004<000<10000=P000c80000]00<11P000c80
000f0003<P0003H000<100009P0004<000<10000=P000c80000_00811@000c80000<0081:0000c80
000f00030@0002H000130081=`000c80000`008110000c80000=00030@0002H000<b0000=@020BP0
001300030@0003H000<b0000<@020@<000<b00002P020BX000<b0000=P000`40000V0000@`000`40
000f0003<P0003800`400`0b000<00030@0002P000<b0000=P000`40000V0000@`000`40000f0003
<P0003@00P400c8000090081:`000c80000f00030@0002H000130081=`000c80000e00<120020@03
004002X000<b0000=@020BP0001300030@0003H000<b0000=P050@@00`4]0003<P0003H000<10000
9P0004<000<10000=P000c80000f0004<P0100L1;P000c80000f00030@0002H0001300030@0003H0
00<b0000=P000c80000200<100<00@00;P000c80000f00030@0002H0001300030@0003H000<10000
=P000`40000f00030@0003H000<100009P0004<00P4?00030@0000L000<1000010000`4000030005
0@0000400`001040004200040@000A0000<100001`000`40000400030@00008000<100000P001@40
0001008000@100010P000`40000>00030@0000L000<1000010000`40000200030@00008000D10000
0@0200040@000@8000<100003P000`40000700030@0000@000<100000P000`40000200050@000040
0P001@4000400081:00004<0i@4X0000o`1A0000o`1A0000o`1A0000o`1A0000o`1A0000o`1A0000
>@020@@000<100000`020@<0104W008110000`40000200@1;`040C8010430081GP0003P000@10001
20001040004400030@0002D000@100012P000`40000`00030@0003<000D100000@0200030@0005/0
000h00040@000@P000@1000110000`40000U00040@000@X000<10000<0000`40000c00050@000040
0P000`40001K0000>0001040004800040@000@@000<100009@001040004:00030@00030000<10000
<`001@400001008000<10000F`0003P000@1000120001040004400030@0002D000@100012P000`40
000`00030@0003<000D100000@0200030@0005/0000h00040@000@P000@100010P030BL000@10001
20030C000`4c00<10`001040005M0000>@020@X00P4500030@0002H00P4;00030@00030000<10000
<`000`4000020081GP000?l0D@000?l0D@000?l0D@000?l0D@000?l0D@000?l0D@000:L00`6V0000
ZP000`40002S0000PP040@@00P44008100@00@000`4010010@020@<00P40100100030@0500410@00
0P400`010@030@<00P43008100@00@000P40100100030@0400410@@01@4200811@020FT000230004
0@000@8000@100010P001040004200030@00008000D100000@0200040@000@8000@100010P001040
004400030@00008000H10001004200040@000@8000@100011@000`40000500050@0000400P001@40
0001008000<10000IP0008<000@100010P001040004200040@000@800`4200050@0100400`030@80
00@100010P001040004400030@00008000<100000P001040004200040@000@800`4300<11@001@40
0001008000D100000@1[0000P`030@<000@100010P0010400042000:0@000@0100400@D000@10001
0P001040004200030@00008000<100000P000`40000200040@000@8000@100010P00104000420004
0@000@@000D100000@0200050@000040J`0008<000@100010`020@@00`4300810P020@03004100<0
0P44008100@00@400P4400810`040@04004100810`030@<00P4300040@000@@000<100000P020@<0
105Y0000PP040@`000<100001@001@40000101/000<100002`000`40000500@11@000`4000080003
0@0006T0002A00818P000`40000200030@0000X00P4?00812P000`40001Y0000o`1A0000o`1A0000
o`1A0000o`1A0000\
\>"],
  ImageRangeCache->{{{0, 335}, {206.5, 0}} -> {-3.18026, -17.1558, 0.0175573, 
  0.0460762}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.603319 0.00232207 [
[.25 -0.0125 -11 -15 ]
[.25 -0.0125 11 0 ]
[.5 -0.0125 -5 -15 ]
[.5 -0.0125 5 0 ]
[.75 -0.0125 -8 -15 ]
[.75 -0.0125 8 0 ]
[1 -0.0125 -11 -15 ]
[1 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -29 -30 ]
[.5 -0.0125 29 -15 ]
[-0.0125 .0228 -24 -4.5 ]
[-0.0125 .0228 0 4.5 ]
[-0.0125 .13891 -24 -4.5 ]
[-0.0125 .13891 0 4.5 ]
[-0.0125 .25501 -24 -4.5 ]
[-0.0125 .25501 0 4.5 ]
[-0.0125 .37111 -24 -4.5 ]
[-0.0125 .37111 0 4.5 ]
[-0.0125 .48722 -18 -4.5 ]
[-0.0125 .48722 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -46 -7.5 ]
[-0.01875 .30902 -24 7.5 ]
[0 .63053 -14 0 ]
[0 .63053 14 15 ]
[.25 .63053 -11 0 ]
[.25 .63053 11 15 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 15 ]
[.75 .63053 -8 0 ]
[.75 .63053 8 15 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -47 15 ]
[.5 .63053 47 30 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.25 0 m
.25 .61803 L
s
.5 0 m
.5 .61803 L
s
.75 0 m
.75 .61803 L
s
1 0 m
1 .61803 L
s
0 .13891 m
1 .13891 L
s
0 .25501 m
1 .25501 L
s
0 .37111 m
1 .37111 L
s
0 .48722 m
1 .48722 L
s
0 g
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.07526 0 m
.07526 .00375 L
s
.11928 0 m
.11928 .00375 L
s
.15051 0 m
.15051 .00375 L
s
.17474 0 m
.17474 .00375 L
s
.19454 0 m
.19454 .00375 L
s
.21127 0 m
.21127 .00375 L
s
.22577 0 m
.22577 .00375 L
s
.23856 0 m
.23856 .00375 L
s
.32526 0 m
.32526 .00375 L
s
.36928 0 m
.36928 .00375 L
s
.40051 0 m
.40051 .00375 L
s
.42474 0 m
.42474 .00375 L
s
.44454 0 m
.44454 .00375 L
s
.46127 0 m
.46127 .00375 L
s
.47577 0 m
.47577 .00375 L
s
.48856 0 m
.48856 .00375 L
s
.57526 0 m
.57526 .00375 L
s
.61928 0 m
.61928 .00375 L
s
.65051 0 m
.65051 .00375 L
s
.67474 0 m
.67474 .00375 L
s
.69454 0 m
.69454 .00375 L
s
.71127 0 m
.71127 .00375 L
s
.72577 0 m
.72577 .00375 L
s
.73856 0 m
.73856 .00375 L
s
.82526 0 m
.82526 .00375 L
s
.86928 0 m
.86928 .00375 L
s
.90051 0 m
.90051 .00375 L
s
.92474 0 m
.92474 .00375 L
s
.94454 0 m
.94454 .00375 L
s
.96127 0 m
.96127 .00375 L
s
.97577 0 m
.97577 .00375 L
s
.98856 0 m
.98856 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -34 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 15.000000 moveto
(H) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 15.000000 moveto
(\\220) show
105.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
111.000000 15.000000 moveto
(L) show
117.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
0 .0228 m
.00625 .0228 L
s
[(-250)] -0.0125 .0228 1 0 Mshowa
0 .13891 m
.00625 .13891 L
s
[(-200)] -0.0125 .13891 1 0 Mshowa
0 .25501 m
.00625 .25501 L
s
[(-150)] -0.0125 .25501 1 0 Mshowa
0 .37111 m
.00625 .37111 L
s
[(-100)] -0.0125 .37111 1 0 Mshowa
0 .48722 m
.00625 .48722 L
s
[(-50)] -0.0125 .48722 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04602 m
.00375 .04602 L
s
0 .06924 m
.00375 .06924 L
s
0 .09246 m
.00375 .09246 L
s
0 .11569 m
.00375 .11569 L
s
0 .16213 m
.00375 .16213 L
s
0 .18535 m
.00375 .18535 L
s
0 .20857 m
.00375 .20857 L
s
0 .23179 m
.00375 .23179 L
s
0 .27823 m
.00375 .27823 L
s
0 .30145 m
.00375 .30145 L
s
0 .32467 m
.00375 .32467 L
s
0 .34789 m
.00375 .34789 L
s
0 .39433 m
.00375 .39433 L
s
0 .41755 m
.00375 .41755 L
s
0 .44077 m
.00375 .44077 L
s
0 .46399 m
.00375 .46399 L
s
0 .51044 m
.00375 .51044 L
s
0 .53366 m
.00375 .53366 L
s
0 .55688 m
.00375 .55688 L
s
0 .5801 m
.00375 .5801 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -107 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
gsave
0 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 .61178 m
.25 .61803 L
s
gsave
.25 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.75 .61178 m
.75 .61803 L
s
gsave
.75 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.07526 .61428 m
.07526 .61803 L
s
.11928 .61428 m
.11928 .61803 L
s
.15051 .61428 m
.15051 .61803 L
s
.17474 .61428 m
.17474 .61803 L
s
.19454 .61428 m
.19454 .61803 L
s
.21127 .61428 m
.21127 .61803 L
s
.22577 .61428 m
.22577 .61803 L
s
.23856 .61428 m
.23856 .61803 L
s
.32526 .61428 m
.32526 .61803 L
s
.36928 .61428 m
.36928 .61803 L
s
.40051 .61428 m
.40051 .61803 L
s
.42474 .61428 m
.42474 .61803 L
s
.44454 .61428 m
.44454 .61803 L
s
.46127 .61428 m
.46127 .61803 L
s
.47577 .61428 m
.47577 .61803 L
s
.48856 .61428 m
.48856 .61803 L
s
.57526 .61428 m
.57526 .61803 L
s
.61928 .61428 m
.61928 .61803 L
s
.65051 .61428 m
.65051 .61803 L
s
.67474 .61428 m
.67474 .61803 L
s
.69454 .61428 m
.69454 .61803 L
s
.71127 .61428 m
.71127 .61803 L
s
.72577 .61428 m
.72577 .61803 L
s
.73856 .61428 m
.73856 .61803 L
s
.82526 .61428 m
.82526 .61803 L
s
.86928 .61428 m
.86928 .61803 L
s
.90051 .61428 m
.90051 .61803 L
s
.92474 .61428 m
.92474 .61803 L
s
.94454 .61428 m
.94454 .61803 L
s
.96127 .61428 m
.96127 .61803 L
s
.97577 .61428 m
.97577 .61803 L
s
.98856 .61428 m
.98856 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0228 m
1 .0228 L
s
.99375 .13891 m
1 .13891 L
s
.99375 .25501 m
1 .25501 L
s
.99375 .37111 m
1 .37111 L
s
.99375 .48722 m
1 .48722 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04602 m
1 .04602 L
s
.99625 .06924 m
1 .06924 L
s
.99625 .09246 m
1 .09246 L
s
.99625 .11569 m
1 .11569 L
s
.99625 .16213 m
1 .16213 L
s
.99625 .18535 m
1 .18535 L
s
.99625 .20857 m
1 .20857 L
s
.99625 .23179 m
1 .23179 L
s
.99625 .27823 m
1 .27823 L
s
.99625 .30145 m
1 .30145 L
s
.99625 .32467 m
1 .32467 L
s
.99625 .34789 m
1 .34789 L
s
.99625 .39433 m
1 .39433 L
s
.99625 .41755 m
1 .41755 L
s
.99625 .44077 m
1 .44077 L
s
.99625 .46399 m
1 .46399 L
s
.99625 .51044 m
1 .51044 L
s
.99625 .53366 m
1 .53366 L
s
.99625 .55688 m
1 .55688 L
s
.99625 .5801 m
1 .5801 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -108 11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
99.000000 15.000000 moveto
(Bode) show
129.000000 15.000000 moveto
(Plot) show
153.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.09751 .60184 Mdot
.17283 .60036 Mdot
.21696 .59887 Mdot
.24835 .59736 Mdot
.27277 .59583 Mdot
.29281 .59428 Mdot
.30984 .5927 Mdot
.32467 .59109 Mdot
.33783 .58943 Mdot
.3497 .58774 Mdot
.36052 .58599 Mdot
.37048 .58418 Mdot
.37975 .58231 Mdot
.38841 .58038 Mdot
.39657 .57836 Mdot
.40431 .57627 Mdot
.41167 .57409 Mdot
.41871 .57181 Mdot
.42547 .56943 Mdot
.43199 .56694 Mdot
.4383 .56432 Mdot
.44443 .56158 Mdot
.45039 .5587 Mdot
.45622 .55567 Mdot
.46194 .55247 Mdot
.46755 .54911 Mdot
.47308 .54556 Mdot
.47854 .54181 Mdot
.48395 .53785 Mdot
.48932 .53366 Mdot
.49467 .52922 Mdot
.5 .52453 Mdot
.50533 .51955 Mdot
.51068 .51427 Mdot
.51605 .50866 Mdot
.52146 .5027 Mdot
.52692 .49637 Mdot
.53245 .48963 Mdot
.53806 .48245 Mdot
.54378 .4748 Mdot
.54961 .46664 Mdot
.55557 .45793 Mdot
.5617 .44861 Mdot
.56801 .43866 Mdot
.57453 .42799 Mdot
.58129 .41657 Mdot
.58833 .4043 Mdot
.59569 .39114 Mdot
.60343 .37697 Mdot
.61159 .36173 Mdot
.62025 .3453 Mdot
.62952 .32756 Mdot
.63948 .30841 Mdot
.6503 .2877 Mdot
.66217 .26528 Mdot
.67533 .24103 Mdot
.69016 .2148 Mdot
.70719 .18648 Mdot
.72723 .15601 Mdot
.75165 .12339 Mdot
.78304 .08875 Mdot
.82717 .05238 Mdot
.90249 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{325, 200.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000550000b0P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl0AP000?l0AP000?l0AP000:X000<10000
7P000`40001g0000Z@000`40000C00030@0000X000<10000MP0009/000<100402`00104000040@<0
0P40100100020@050040004010030@@000<10000MP0009/000<100402`000`40000200030@000080
00@100010P001040004300030@0000D000D100000@1h0000VP001@400@0100X000<100000P000`40
000300<10P0010400043008110020@@000<10000MP0009X000D100400@0:00030@00008000<10000
1@001040004200030@00008000D100000@0600030@0007H0002J00040@0100812@001P40000100<1
0P020@@00`4400030@0000800`4300030@0007H0002Z00030@0000l000<100000`000`4000060003
0@0007L0002k0081R0000?l0AP000?l0AP000?l0AP000?l0AP000?l0AP000?l0AP000?l0AP000?l0
AP0007P00P4400030@000080104/00@1;`040@<00P4[00@10`020@@00P4L0000M`001040004:0003
0@0002d000<10000<0001@400001008000<10000:P001@400001008000@100010P000`40000I0000
M`001040004:00030@0002d000<10000<0001@400001008000<10000:P001@400001008000@10001
0P000`40000I0000M`001040004:00030@0002d000<10000<0001@400001008000<10000:P001@40
0001008000@100010P000`40000I0000M`001040004:00030@0002d000<10000<0001@4000010080
00<10000:P001@400001008000@100010P000`40000I0000M`001040004800<1;@030C000`430004
0@000BX00`4300040@000@8000@100016`0007P00P4;00030@0002d000<10000<0000`4000020081
;@000`400002008110020A`0003o04H0003o04H0003o04H0003o04H0003o04H000180=/18P0004P0
00<100003P000`40000600030@0000@000<100000P000`40000200040@000@8000@100010P000`40
000=00030@0000L000<100000`000`40000300050@0000400`001040004200030@0100l000<10000
1`000`40000400030@00008000D100000@0300040@000@8000<1004040000`40000600030@0000@0
00<100000P000`40000200040@000@8000@100010P000`40000P0000B0000`40000d00030@0003<0
00<10000<`000`40000d00030@000200001800030@0003@000<b0000<`000c80000c0003<P0001h0
0P4D00030@000200000e00@10P030@@00P4400030@0003@000<b0000<`000c80000c0003<P0001l0
00<100004P000`40000P0000=@000`40000600040@000@8000@100000`4d0003<P0003<000<b0000
<`000c80000b00<18P0003H000<100001@001040004200050@000040=P000c80000c0003<P0003<0
00<b0000=0000`40000P0000;`040@@000@100000`4300040@000@<000<10000=0000c80000c0003
<P0003<000<b0000=0000`40000P0000>0001040004500040@000@<000<10000=0000c80000c0003
<P0003<000<b0000=0000`40000P0000=@001040004200030@0000<000@100010`000`40000d0003
<P0003<000<b0000<`000c80000d00030@000200000f00810`040@<00P440081=@000c80000c0003
<P0003<000<b0000<`020B80001800030@0003@000<b0000<`000c80000c0003<P0000h00P4T0003
0@000200001800030@0003@000<b0000<`000c80000c0003<P0000l000<100008P000`40000P0000
B0000`40000d0003<P0003<000<b0000<`000c80000d00030@000200001800030@0003@000<b0000
<`000c80000c0003<P0003@000<10000800004P000<10000=0000c80000c0003<P0003<000<b0000
=0000`40000P0000B0020CD000<b0000<`000c80000c0003<P0003<00P4R0000B0000`40000d0003
<P0003<000<b0000<`000c80000d00030@000200001800030@0003@000<b0000<`000c80000c0003
<P0003@000<10000800004P000<10000=0000c80000c0003<P0003<000<b000010020Bh000<10000
800004P000<10000=0000c80000c0003<P0003<000<b00001@000`40000/00030@00020000180081
=@000c80000c0003<P0003<000<b0000<`020B80001800030@0003@000<b0000<`000c80000c0003
<P0003@000<10000800004P000<10000=0000c80000c0003<P0003<000<b0000=0000`40000P0000
B0000`40000d0003<P0003<000<b0000<`000c80000d00030@000200001800030@0003@000<b0000
<`000c80000c0003<P0003@000<10000800004P00P4e0003<P0003<000<b0000<`000c80000c0081
8P0004P000<10000=0000c80000c0003<P0003<00P4e00030@000200001800030@0003@000<b0000
<`000c80000c0003<P4003@000<10000800003D01043008110020@@000<10000=0000c80000c0003
<P0003<000<b0000=0000`40000P0000=@000`40000300040@000@8000@100010`000`40000d0003
<P0003<000<b0000<`000c80000d00030@000200000f00030@00008000@100010P001040004300<1
eC830B80000_00@110001@400001008000@100010P001@40000103H000<b0000<`000c80000c0003
<P0003@000<10000800003P000@100010P001040004200050@000040=P000c80000c0003<P0003<0
00<b0000=0000`40000P0000=@001040004200040@000@8000@100010`000`40000d0003<P0003<0
00<b0000;P020@<000<b0000=0000`40000P0000=P020@@00P44008110000`40000d0003<P0003<0
00<b0000;`001@40000b03H000<10000800004P00P4e0003<P0003<000<b0000<`000c80000c0081
8P0004P000<10000=0000c80000c0003<P0003<000<b0000=0000`40000P0000B0000`40000d0003
<P0003<000<b0000<`000c80000d00030@000200001800030@0003@000<b0000<`000c80000c0003
<P0003@000<10000800004P000<10000=0000c80000c0003<P0003<000<b0000=0000`40000P0000
B0020CD000<b0000<`000c80000Z00811`000c80000c00818P0004P000<10000=0000c80000c0003
<P0002/000<100001@000c80000d00030@000200001800030@0003@000<b0000<`000c80000c0003
<P0003@000<10000800004P000<10000=0000c80000c0003<P0003<000<b0000=0000`40000P0000
B0000`40000d0003<P0003<000<b0000<`000c80000d00030@00020000180081=@000c80000c0003
<P0003<000<b0000<`020B80001800030@0003@000<b0000<`000c80000V00812`000c80000d0003
0@000200001800030@0003@000<b0000<`000c80000W00030@0000T000<b0000=0000`40000P0000
B0000`40000d0003<P0003<000<b0000<`000c80000d00030@000200001800030@0003@000<b0000
<`000c80000c0003<P0003@000<10000800004P00P4e0003<P0003<000<b0000<`000c80000c0081
8P0004P000<10000=0000c80000c0003<P0002<00P4>0003<P0003@000<10000800004P000<10000
=0000c80000c0003<P0002@000<1000030000c80000d00030@000200001800030@0003@000<b0000
<`000c80000c0003<P0003@000<10000800003D0104200<110020@@000<10000=0000c80000c0003
<P0003<000<b0000=0000`40000P0000=`000`40000400040@000@8000@100000`7E<P<18P0003L0
00<1000010001040004200050@000040=P000c80000c0003<P0003<000<b0000=0000`40000P0000
;`040@@000@100000`4300040@000@<000<10000=0000c80000c0003<P0002000P4A0003<P0003@0
00<10000800003L000D100000@0500040@000@<000<10000=0000c80000c0003<P00024000<10000
3`000c80000d00030@000200000e00<10`000`40000300040@000@<000<10000=0000c80000c0003
<P0003<000<b0000=0000`40000P0000=`00104000040@<00P440081=@000c80000c0003<P0003<0
00<b0000<`020B80001800030@0003@000<b0000<`000c80000c0003<P0003@000<10000800002D0
0`4P00030@0003@000<b0000<`000c80000M008150000c80000d00030@000200000X00030@0001d0
00<10000=0000c80000c0003<P0001h000<100004P000c80000d00030@000200000J008100@00@00
0`4300<17`000`40000d0003<P0003<000<b0000<`000c80000d00030@000200000I00040@000@80
00<100000`001040004O0081=@000c80000c0003<P0003<000<b0000<`020B80000I00040@000@80
0`4300040@000Al000<10000=0000c80000c0003<P0001/00P4F0003<P0003@000<10000800001T0
00@100010P001040004200040@000Al000<10000=0000c80000c0003<P0001`000<1000050000c80
000d00030@000200000J00<10`020@@00P400`01000M00030@0003@000<b0000<`000c80000c0003
<P0003@000<10000800001`000<10000:@000`40000d0003<P0003<000<b0000<`000c80000d0003
0@000200000K0081:`020CD000<b0000<`000c80000I008160000c80000c00818P0004P000<10000
=0000c80000c0003<P0001X000<100005P000c80000d00030@000200001800030@0003@000<b0000
<`000c80000c0003<P0003@000<10000800004P000<10000=0000c80000c0003<P0003<000<b0000
=0000`40000P0000B0000`40000d0003<P0003<000<b00005`020AX000<b0000=0000`40000P0000
B0020CD000<b0000<`000c80000H00030@0001P000<b0000<`020B80001800030@0003@000<b0000
<`000c80000c0003<P0003@000<10000800004P000<10000=0000c80000c0003<P0003<000<b0000
=0000`40000P0000B0000`40000d0003<P0003<000<b00005@020A`000<b0000=0000`40000P0000
=@040@<00P44008110000`40000d0003<P0003<000<b00005P000`40000J0003<P0003@000<10000
800003L000D100000@0200040@000@8000@100000`7E<P<18P0003L000D100000@0200040@000@80
00D100000@0f0003<P0003<000<b00004`020Ah000<b0000=0000`40000P0000;`040@@000D10000
0@0200040@000@8000D100000@0f0003<P0003<000<b000050000`40000L0003<P0003@000<10000
800003L000D100000@0200040@000@8000D100000@0f0003<P0003<000<b0000<`000c80000d0003
0@000200000e00<10`001040004200040@000@<000<10000=0000c80000c0003<P0001400P4P0003
<P0003@000<10000800003L000<100000P020@@00P440081=@000c80000c0003<P00018000<10000
7P000c80000c00818P0004P000<10000=0000c80000c0003<P0003<000<b0000=0000`40000P0000
B0000`40000d0003<P0003<000<b000040020B4000<b0000=0000`40000P0000B0000`40000d0003
<P0003<000<b00004@000`40000O0003<P0003@000<10000800004P000<10000=0000c80000c0003
<P0003<000<b0000=0000`40000P0000B0020CD000<b0000<`000c80000>00818`000c80000c0081
8P0004P000<10000=0000c80000c0003<P0000l000<100008@000c80000d00030@00020000180003
0@0003@000<b0000<`000c80000=008190000c80000d00030@000200001800030@0003@000<b0000
<`000c80000>00030@00028000<b0000=0000`40000P0000B0000`40000d0003<P0003<000<b0000
2`020BH000<b0000=0000`40000P0000B0020CD000<b0000<`000c80000<00030@0002@000<b0000
<`020B80001800030@0003@000<b0000<`000c80000c0003<P0003@000<10000800004P000<10000
=0000c80000c0003<P0000X00P4W0003<P0003@000<10000800004P000<10000=0000c80000c0003
<P0000/000<100009@000c80000d00030@000200001800030@0003@000<b0000<`000c8000090081
:0000c80000d00030@00020000180081=@000c80000c0003<P0000L00P400`01000W0003<P0003<0
0P4R0000B0000`40000d0003<P0003<000<b000020000`40000X0003<P0003@000<10000800004P0
00<10000=0000c80000c0003<P0000H00P4[0003<P0003@000<10000800004P000<10000=0000c80
000c0003<P0000L000<10000:@000c80000d00030@000200000k00<110020@@000<10000=0000c80
000c0003<P0000D00P4/0003<P0003@000<10000800003h000@100010P00104000030G4b0`5Q<P<1
8P0003h000@100010P001@40000103H000<b0000<`000c80000500030@0002/000<b0000=0000`40
000P0000=@040@800`4300040@000@<000<10000=0000c80000c0003<P0000800P4_0003<P0003@0
00<10000800003/000<100000`001040004300030@0003@000<b0000<`00138000030Bl000<b0000
=0000`40000P0000>`000`40000300040@000@<000<10000=0000c80000c0003<P00008000<10000
;P000c80000d00030@000200000k00@10`020@@00P4e0003<P0003<000<b00000P4a0003<P0003<0
0P4R0000B0000`40000d0003<P0003<000<b00400P4a0003<P0003@000<10000800004P000<10000
=0000c80000c0004<P410C8000<b0000=0000`40000P0000B0000`40000d0003<P0003800P400`01
000b0003<P0003@000<10000800004P000<10000=0000c80000a00<1=@000c80000d00030@000200
00180081=@000c80000`00<100<b0000<`000c80000c00818P0004P000<10000=0000c80000_00<1
00<0<P00=0000c80000d00030@000200001800030@0003@000<b0000;P030@8000<b0000<`000c80
000d00030@000200001800030@0003@000<b0000:`050@<000<b0000<`000c80000d00030@000200
001800030@0003@000<b0000:P030@03004000<000<b0000<`000c80000d00030@00020000180081
=@000c80000X00@11`000c80000c0003<P0003<00P4R0000B0000`40000d0003<P0002H00P400`01
0@080003<P0003<000<b0000=0000`40000P0000B0000`40000d0003<P0002@0104;0003<P0003<0
00<b0000=0000`40000P0000B0000`40000d0003<P0002400`400`010@0<0003<P0003<000<b0000
=0000`40000P0000B0000`40000d0003<P0001h00`400`010@0?0003<P0003<000<b0000=0000`40
000P0000B0000`40000d0003<P0001X010400`010@0B0003<P0003<000<b0000=0000`40000P0000
B0020CD000<b000050060@0400400AD000<b0000<`000c80000c00818P0004P000<10000=0000c80
000<008100@00@400P401P0100400AT000<b0000<`000c80000d00030@000200001800030@0003@0
00<b00001@020@800P4200040@000@8000<100007@000c80000c0003<P0003@000<1000080000480
0P4400030@0002`00P4500810`020@<000D100000@0X0003<P0003<000<b0000=0000`40000P0000
@@001040004300030@0001800P4>00812@000`40000400030@00008000<10000;P000c80000c0003
<P0003@000<100008000044000@100010`030A<000<100003@000`40000>0003<P0003<000<b0000
<`000c80000b00<18P00044000@100010`000`40000d00030@0003<000<10000<`000`40000d0003
0@000200001100040@000@<000<100003P000`40000600030@0000@000<100000P000`4000020004
0@000@8000@100010P000`40000=00030@0000L000<100000`000`40000300050@0000400`001040
004200030@0100l000<100001`000`40000400030@00008000D100000@0300040@000@8000<10040
40000`40000600030@0000@000<100000P000`40000200040@000@8000@100010P000`40000P0000
@@00104000430=/18P0004800P7o0080003o04H0003o04H0003o04H0003o04H0003o04H0000n0081
10000`40000300810`040BD00P4400030@000080104/00@1;`040@<00P5F0000?@00104000480004
0@000@@000<100008`001040004:00030@0002d000<10000<0001@400001008000<10000D`0003d0
00@1000120001040004400030@0002<000@100012P000`40000]00030@00030000D100000@020003
0@0005<0000m00040@000@P000@1000110000`40000S00040@000@X000<10000;@000`40000`0005
0@0000400P000`40001C0000?@001040004800040@000@@000<100008`001040004:00030@0002d0
00<10000<0001@400001008000<10000D`0003d000@1000120001040004200<19@001040004800<1
;@030C000`4300040@000ED0000n00812P020@D000<1000090020@/000<10000;@000`40000`0003
0@0000800P5F0000o`160000o`160000o`160000o`160000o`160000o`160000o`160000o`160000
R0030@<00`400`010@02008100<00@000`4400<11`040@@00P44008100@00@000`4700<110050@80
0P450081I00008T000<100000`001040004200040@000@D000@100012`001040004200040@000@80
00@100010P000`40000900030@0000D000D100000@0200050@0000400P000`40001Q0000R@030@<0
00@100010`030@<00P4300<12@001040004200040@000@8000@100010P030@T00`4500050@000040
0P001@40000106H0002900040@000@8000@100011@001040004500040@000@P00`4300040@000@80
00@100010P001040004800040@000@@000D100000@0200050@000040IP0008T000@100010P030@@0
0P4400<10`020@T000@100010`020@@00`4300812@001040004400030@0000800P4300@1I00008P0
104300030@0001X0104<00030@0000/0104500030@0000P000<10000I00008h00P4[00815@020@X0
00<10000I0000?l0AP000?l0AP000?l0AP000?l0AP000001\
\>"],
  ImageRangeCache->{{{0, 324}, {199.75, 0}} -> {-3.34126, -324.651, 0.0184053,
   1.98157}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.6 Optimality diagnostics", "Section"],

Cell[CellGroupData[{

Cell["flat", "Input"],

Cell[BoxData[
    \(0.00356167256509846774`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["grAlign", "Input"],

Cell[BoxData[
    \(4.44089209850062616`*^-16\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ned", "Input"],

Cell[BoxData[
    \(0.0131836236287417518`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["gamma", "Input"],

Cell[BoxData[
    \(gamma\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2 : changing tracking and roll off", "Section"],

Cell[CellGroupData[{

Cell["\<\

     p[s_]= (1 - s/5)/(1+s/2)^2;

      wt  = 0.3;
  alphat  = 0.5;

 alphagpm = 2.0;

       wb = 2.0;
   alphab = 0.7;
              
       wr = 4.0;
   alphar = 30.;
 
    k0[w_]= Which[ Abs[w] < wb, 1.0,
                     True, 0.0];
 
   r0[w_] = Which[Abs[w] < wt,  alphat,
               Abs[w] < wb,  alphagpm,
               Abs[w] < wr,  alphab,
                     True ,  alphar*Abs[p[I w]/w^2]
                ];
                
     wpts = Grid[Ngrid ->128,GridSpread -> 1.0];


EnvelopePlot[Radius ->r0,Center -> k0,
\t\t\tFrequencyBand -> {0,wr+1} 
\t\t \t(* ,GridPoints -> wpts *) ];\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.161866 0.147151 [
[.2 .14937 -3 -9 ]
[.2 .14937 3 0 ]
[.4 .14937 -3 -9 ]
[.4 .14937 3 0 ]
[.6 .14937 -3 -9 ]
[.6 .14937 3 0 ]
[.8 .14937 -3 -9 ]
[.8 .14937 3 0 ]
[1 .14937 -3 -9 ]
[1 .14937 3 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .16187 m
.2 .16812 L
s
[(1)] .2 .14937 0 1 Mshowa
.4 .16187 m
.4 .16812 L
s
[(2)] .4 .14937 0 1 Mshowa
.6 .16187 m
.6 .16812 L
s
[(3)] .6 .14937 0 1 Mshowa
.8 .16187 m
.8 .16812 L
s
[(4)] .8 .14937 0 1 Mshowa
1 .16187 m
1 .16812 L
s
[(5)] 1 .14937 0 1 Mshowa
.125 Mabswid
.04 .16187 m
.04 .16562 L
s
.08 .16187 m
.08 .16562 L
s
.12 .16187 m
.12 .16562 L
s
.16 .16187 m
.16 .16562 L
s
.24 .16187 m
.24 .16562 L
s
.28 .16187 m
.28 .16562 L
s
.32 .16187 m
.32 .16562 L
s
.36 .16187 m
.36 .16562 L
s
.44 .16187 m
.44 .16562 L
s
.48 .16187 m
.48 .16562 L
s
.52 .16187 m
.52 .16562 L
s
.56 .16187 m
.56 .16562 L
s
.64 .16187 m
.64 .16562 L
s
.68 .16187 m
.68 .16562 L
s
.72 .16187 m
.72 .16562 L
s
.76 .16187 m
.76 .16562 L
s
.84 .16187 m
.84 .16562 L
s
.88 .16187 m
.88 .16562 L
s
.92 .16187 m
.92 .16562 L
s
.96 .16187 m
.96 .16562 L
s
.25 Mabswid
0 .16187 m
1 .16187 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1 .12227 m
.89064 .10101 L
.79844 .07715 L
.72271 .06301 L
.65931 .05917 L
.60541 .05886 L
.55896 .05886 L
.51848 .05886 L
.48284 .0586 L
.45119 .05548 L
.42286 .04471 L
.39733 .02887 L
.37417 .01809 L
.35305 .01497 L
.33368 .01472 L
.31583 .01472 L
.29932 .01472 L
.28398 .01472 L
.26967 .01472 L
.25628 .01472 L
.2437 .01472 L
.23186 .01472 L
.22067 .01472 L
.21007 .01472 L
.2 .01472 L
.19042 .01472 L
.18127 .01472 L
.17252 .01472 L
.16414 .01472 L
.15608 .01472 L
.14833 .01472 L
.14086 .01472 L
.13364 .01472 L
.12665 .01472 L
.11988 .01472 L
.1133 .01472 L
.1069 .01472 L
.10067 .01472 L
.09459 .01472 L
.08865 .01472 L
.08284 .01472 L
.07715 .01472 L
.07156 .016 L
.06607 .0316 L
.06067 .08549 L
.05535 .16467 L
.0501 .21856 L
.04491 .23415 L
.03978 .23544 L
.0347 .23544 L
Mistroke
.02967 .23544 L
.02467 .23544 L
.0197 .23544 L
.01475 .23544 L
.00983 .23544 L
.00491 .23544 L
0 .23544 L
Mfstroke
1 .20146 m
.89064 .22272 L
.79844 .24658 L
.72271 .26073 L
.65931 .26456 L
.60541 .26487 L
.55896 .26487 L
.51848 .26487 L
.48284 .26685 L
.45119 .29076 L
.42286 .37339 L
.39733 .4948 L
.37417 .57743 L
.35305 .60134 L
.33368 .60332 L
.31583 .60332 L
.29932 .60332 L
.28398 .60332 L
.26967 .60332 L
.25628 .60332 L
.2437 .60332 L
.23186 .60332 L
.22067 .60332 L
.21007 .60332 L
.2 .60332 L
.19042 .60332 L
.18127 .60332 L
.17252 .60332 L
.16414 .60332 L
.15608 .60332 L
.14833 .60332 L
.14086 .60332 L
.13364 .60332 L
.12665 .60332 L
.11988 .60332 L
.1133 .60332 L
.1069 .60332 L
.10067 .60332 L
.09459 .60332 L
.08865 .60332 L
.08284 .60332 L
.07715 .60332 L
.07156 .60203 L
.06607 .58644 L
.06067 .53255 L
.05535 .45336 L
.0501 .39947 L
.04491 .38388 L
.03978 .38259 L
.0347 .38259 L
Mistroke
.02967 .38259 L
.02467 .38259 L
.0197 .38259 L
.01475 .38259 L
.00983 .38259 L
.00491 .38259 L
0 .38259 L
Mfstroke
.5 g
.01 w
0 .38259 m
.01975 .38259 L
.04057 .38259 L
.04585 .38259 L
.0515 .38259 L
.05424 .38259 L
.05683 .38259 L
.05796 .38259 L
.05916 .38259 L
.06047 .60332 L
.06168 .60332 L
.08481 .60332 L
.12454 .60332 L
.16684 .60332 L
.20755 .60332 L
.25083 .60332 L
.29253 .60332 L
.33263 .60332 L
.35501 .60332 L
.37531 .60332 L
.38547 .60332 L
.39082 .60332 L
.39374 .60332 L
.39646 .60332 L
.39769 .60332 L
.39885 .60332 L
.40019 .26487 L
.40141 .26487 L
.40684 .26487 L
.41639 .26487 L
.45664 .26487 L
.49946 .26487 L
.54069 .26487 L
.58033 .26487 L
.62254 .26487 L
.66316 .26487 L
.70636 .26487 L
.74797 .26487 L
.76893 .26487 L
.78798 .26487 L
.79306 .26487 L
.79574 .26487 L
.7972 .26487 L
.79857 .26487 L
.79977 .26487 L
.80105 .23224 L
.80178 .23203 L
.80247 .23184 L
.80377 .23147 L
.80857 .23016 L
Mistroke
.83057 .22451 L
.87073 .21568 L
.91346 .20798 L
.9546 .20188 L
.99832 .1965 L
1 .19631 L
Mfstroke
0 .23544 m
.01975 .23544 L
.04057 .23544 L
.04585 .23544 L
.0515 .23544 L
.05424 .23544 L
.05683 .23544 L
.05796 .23544 L
.05916 .23544 L
.06047 .01472 L
.06168 .01472 L
.08481 .01472 L
.12454 .01472 L
.16684 .01472 L
.20755 .01472 L
.25083 .01472 L
.29253 .01472 L
.33263 .01472 L
.35501 .01472 L
.37531 .01472 L
.38547 .01472 L
.39082 .01472 L
.39374 .01472 L
.39646 .01472 L
.39769 .01472 L
.39885 .01472 L
.40019 .05886 L
.40141 .05886 L
.40684 .05886 L
.41639 .05886 L
.45664 .05886 L
.49946 .05886 L
.54069 .05886 L
.58033 .05886 L
.62254 .05886 L
.66316 .05886 L
.70636 .05886 L
.74797 .05886 L
.76893 .05886 L
.78798 .05886 L
.79306 .05886 L
.79574 .05886 L
.7972 .05886 L
.79857 .05886 L
.79977 .05886 L
.80105 .0915 L
.80178 .0917 L
.80247 .0919 L
.80377 .09226 L
.80857 .09358 L
Mistroke
.83057 .09922 L
.87073 .10805 L
.91346 .11575 L
.9546 .12185 L
.99832 .12723 L
1 .12742 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@000?l08@000?l0
8@0000l000<10000o`0?00003`000`40003o00l0000?00030@000?l03`0000L0104400030@000?l0
3`0000T000<100000`030@`0GF^U00002@000`40000300030@0000`0GF^U000000<00@400P440003
0@0000<000<100003002J`8000<10000D0020@800V^U00002@000`40000300030@0000`00V/00`01
001D00810V^U00001`030@D000<100003002J`03004005H00V^U00002@000`40000300030@0000`0
0V/00`01001F009[0P6S00003`000`40000<009[00<00@00EP02J`8000<10000X00000l000<10000
3002J`03004005H00V/30081X00000l00P4=009[00<00@00EP02J`D00P6N00003`000`40000<009[
00<10000EP02J`L00`6K00003`000`40000<009[00<10000EP02J`X00P6I00003`000`40000<009[
00<10000EP02J``01P6C00003`000`40000<009[00<10000EP1^JcT0000?00030@0000`00V/00`40
001F06i[>@0000l000<100003002J`030@000;401@4<009[>@0000l000<100003002J`030@000;H0
1@47009[>@0000l00P4=009[_P050@800V/i00003`000`40000<009[``020@9[00<10000=P0000l0
00<100003002JlD00V/00`010@020C@0000?00030@0000`00V_5009[1@040C00000?00030@0000`0
0V_5009[00<0J`001P040B`0000?00030@0000`00V_500M[20040BP0000?00030@0000`00V_500Y[
2@040B@0000?00030@0000`00V_;00U[20050Al0000?00813@02Jlh036/700D16P0000l000<10000
3002Jm@02f/700D15@0000l000<100003002JmT036/600D1400000l000<100003002Jml02f/600D1
2`0000l000<100003002Jn@036/500D11P0000l000<100003002JnX04V/00`40000100003`000`40
000<009[k`0>J`<0000?00030@0000`00V/S00@1<@040C<00P4e00030@0003400f/300003`020@d0
0V/U00030@00030000<10000<`001040004d00030@0003@00@410040000?00030@0000`00V/U0003
0@00034000<10000=@000`40000_00D1=@010@400@0000l000<100003002JbD000<10000<P000`40
000b0081<P001040004c00<10`0000l000<100003002JbD000<10000<`000`40000c00030@000300
00<10040<`000`40000300003`000`40000<009[8`030C8000@10001<P001040004c0081<`000`40
000300003`000`40000<009[9@000`40000a0081=0020CD000<10000<@040@80000?00030@0000`0
0V_o0040000?00l10V_m0@<0000?00030@0000P000@100000V/400030@0000P000<1000020000`40
000800030@0000L000<1000020000`40000800030@0000P000<100001`000`40000800030@0000P0
00<1000020000`40000700030@0000P000<1000020000`40000800030@0000L000<1000020000`40
000800030@0000P000<100001`000`40000800030@0000P000<1000020000`40000100003`000`40
000800040@00009[10000`40000800030@0000P000<1000020000`40000700030@0000P000<10000
20000`40000800030@0000L000<1000020000`40000800030@0000P000<100001`000`4000080003
0@0000P000<1000020000`40000700030@0000P000<1000020000`40000800030@0000L000<10000
20000`40000800030@0000P000<100000@0000l000<100003002Jol00@0000l000<100003002Jol0
0@0000l000<100002`000`5[J`3o0040000?00030@0000/000<1Jf/0o`0100003`000`40000;0003
0F][0?l00@0000l00P4<00030F][0?l00@0000l000<100002`000`5[J`3k0003J`000080000?0003
0@0000/000<1Jf/0k`0>J`<0000?00030@0000/000<1Jf/0jP0CJ`<0000?00030@0000/000<1Jf/0
i00<J`D01@4600003`000`40000:00040@1[Jml02f/600D12`0000l000<100002P001040Jf_I00a[
1P050A00000?00030@0000X000@106][e00;J`L01@4E00003`020@/000@106][cP0<J`L01@4J0000
3`000`40000:00040@1[Jl/02F/800D17`0000l000<100002P001040Jf_800M[2@040B@0000?0003
0@0000T000<100000V_500M[20040BP0000>019[a@04J`L0104/00003P0BJlD00V/500@1<00000l0
00<10000d`02J`0300410081=00000l000<10000d@020@9[00<10000=P0000l00P7=00D10P02JcT0
000?00030@000<L01@47009[>@0000l000<10000`P050@`00V/i00003`000`40002g00/14@02JcT0
000?00030@0006L0KV/i00003`000`40001W06i[>@0000l000<10000I`02Ja@00P6?00003`000`40
001W009[4`000`40002?00003`020FP00V/A0081TP0000l000<10000I`02Ja0000<10000TP0000l0
00<10000I`02J`h00P6E00003`000`40001W009[3@000`40002E00003`000`40001W009[3@000`40
002E00003`000`40001W009[30000`40002F00003`000`40001W009[30000`40002F00001`040@@0
00<10000I`02J``000<10000UP0000T000<100000`030FL00V/;00030@0009L0000900030@0000<0
00<10000I`02J`/000<10000U`0000T000<100000`000`40001W009[2P000`40002H00002@000`40
000300030@0006L00V/:00030@0009P0000700<11@000`40001W009[2P000`40002H00002@000`40
000300030@0006L00V/900030@0009T0000?00030@0006L00V/900030@0009T0000?00030@0006L0
0V/900030@0009T0000?0081J002J`P000<10000VP0000l000<10000I`02J`P000<10000VP0000l0
00<10000I`02J`P000<10000VP0000l000<10000I`02J`L000<10000V`0000l000<10000I`02J`L0
00<10000V`0000l000<10000I`02J`H000<10000W00000l000<10000I`02J`H000<10000W00000l0
00<10000I`02J`H000<10000W00000l00P5X009[1@000`40002M00003`000`40001W009[1@000`40
002M00003`000`40001W009[1@000`40002M00003`000`40001W009[1@000`40002M00003P0BJeT0
0V/400030@0009h0000>019[F@02J`@000<10000WP0000l000<100002P001040Jf]I009[10000`40
002N00003`000`40000:00040@1[JeT00V/400030@0009h0000?00812`001040Jf]I009[10000`40
002N00003`000`40000:00040@1[JeT00V/400030@0009h0000?00030@0000X000@106][F@02J`<0
00<10000W`0000l000<100002P001040Jf]I009[0`000`40002O00003`000`40000;00030F][05T0
0V/300030@0009l0000?00030@0000/000<1Jf/0F@02J`<000<10000W`0000l000<100002`000`5[
J`1I009[0`000`40002O00003`000`40000;00030F][05T00V/200030@000:00000?008130000`5[
J`1I009[0P000`40002P00003`000`40000;00030F][05T00V/200030@000:00000?00030@0000/0
00<1Jf/0F@02J`8000<10000X00000l000<100002`000`5[J`1I009[0P000`40002P00003`000`40
000<009[F@02J`8000<10000X00000l000<100003002JeT00V/00`01002R00001`040@@000<10000
3002JeT00V/00`01002R00001`000`40000500030@0000`00V]I009[00<00@00XP0000P000<10000
10030@`00V]I009[00<00@00XP0000T000<100000`000`40000<009[F@02J`0300400:80000:0003
0@00008000<100003002JeT00V/00`40002R00001`001040004400030@0000`00V]I009[00<10000
XP0000P00P4500030@0000`00V]I009[00<10000XP0000l000<100003002JeT00V/00`40002R0000
3`000`40000<009[F@02J`030@000:80000?00813@02JeT00V/00`40002R00003`000`40000<009[
F@02JjD0000?00030@0000`00V]I009[Y@0000l000<100003002JeT00V^U00003`000`40000<009[
F@02JjD0000?00030@0000`00V]I009[Y@0000l000<100003002JeT00V^U00003`000`40000<009[
F@02JjD0000?00813@02JeP000<1Jf/0Y@0000l000<100003002JeP000<1Jf/0Y@0000l000<10000
3002JeP000<1Jf/0Y@0000l000<100003002JeL000@106][Y@0000l000<100003002JeL000@106][
Y@0000l000<100003002JeL000@106][Y@0000l000<100003002JeL000@106][Y@0000l000<10000
3002JeH000<100000V^U00003`020@d00V]F00030@00009[Y@0000l000<100003002J`030@0005<0
00<100000V^U00003`000`40000<009[00<10000DP0010400002JjD0000?00030@0000`00V/00`40
001B00040@00009[Y@0000l000<100003002J`030@00058000@100000V^U00003`000`40000<009[
00<10000D@000`400002009[Y@0000l000<100003002J`030@00054000<100000P02JjD0000?0003
0@0000`00V/00`40001A00030@0000800V^U00003`020@d00V/00`40001@00030@0000<00V^U0000
3`000`40000<009[00<00@00D0000`400003009[Y@0000l000<100003002J`03004004l000<10000
1002JjD0000?00030@0000`00V/00`01001?00030@0000@00V^U00003`000`40000<009[00<00@00
CP000`400005009[Y@0000l000<100003002J`03004004d000<100001P02JjD0000?00030@0000`0
0V/200030@0004X000<100001`02JjD0000800811@000`40000<009[0P000`40001:00030@0000L0
0V^U00001`001040004400<1301MJjD0000:00030@00008000<10000301MJjD0000800811@000`40
003o00l0000:00030@00008000<10000o`0?00001`001040004400030@000?l03`0000P00P7o01L0
003o0240003o0240003o0240003o02400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.285873, -1.23796, 
  0.0186123, 0.0252969}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\


OPTDesign[p,Radius->r0,Center->k0,Cdecay -> 2];\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[BoxData[
    \("\nParameterization for internal stability:"\)], "Print"],

Cell[BoxData[
    \("  T = A + B * T1, where T1 is RHP stable and"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("A[s]="\[InvisibleSpace]\(\( - 5.`\) + s
            \)\/\((\(2.`\[InvisibleSpace]\) + s)\)\^4\),
      SequenceForm[ "A[s]=", 
        Times[ 
          Plus[ -5.0, s], 
          Power[ 
            Plus[ 2.0, s], -4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("B[s]="\[InvisibleSpace]\(\( - 5.`\) + s
            \)\/\((\(2.`\[InvisibleSpace]\) + s)\)\^4\),
      SequenceForm[ "B[s]=", 
        Times[ 
          Plus[ -5.0, s], 
          Power[ 
            Plus[ 2.0, s], -4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("  "\)], "Print"],

Cell[BoxData[
    \("Processing performance function..."\)], "Print"],

Cell[BoxData[
    \("Sampling Radius and Center ..."\)], "Print"],

Cell[BoxData[
    \("Smoothing Radius and Center ..."\)], "Print"],

Cell[BoxData[
    \("Optimization routine Anopt now number-crunching ..."\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("It :    Current Value    :  Step   : Optimality Tests  :  Error  : Sm. \
: Grid"\)], "Print"],

Cell[BoxData[
    \("   :     gammastar       :         :   flat   grAlign  :   ned   :     \
:"\)], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
------"\)], "Print"],

Cell[BoxData[
    \(" 0 : 6.8717898926677E+00 :   N/A   : 10.E-01 : 1. E+00 :   N/A   : NON \
: 128"\)], "Print"],

Cell[BoxData[
    \(" 1 : 2.6213878066205E-01 : 1.8E+01 : 1.5E-02 : 0  E+00 : 1.4E-02 : NON \
: 128"\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("Summary"\)], "Print"],

Cell[BoxData[
    \("-------"\)], "Print"],

Cell[BoxData[
    \("gammastar = 2.621387806620542E-01"\)], "Print"],

Cell[BoxData[
    \("flat      = 1.5147014939E-02"\)], "Print"],

Cell[BoxData[
    \("grAlign   = 0           E+00"\)], "Print"],

Cell[BoxData[
    \("ned      = 1.43E-02"\)], "Print"],

Cell[BoxData[
    \("Calculating output functions ..."\)], "Print"],

Cell[BoxData[
    \("Resetting options ..."\)], "Print"],

Cell[BoxData[
    \("Done! "\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trat, the rational approximation to T", "Subsection"],

Cell[CellGroupData[{

Cell["Trat = RationalModel[s,DegreeOfDenominator -> 9]", "Input"],

Cell[BoxData[
    InterpretationBox[\("Error = "\[InvisibleSpace]0.805310352957057418`\),
      SequenceForm[ "Error = ", 0.80531035295705744],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\(-5.`\) + s\)\/\((\(2.`\[InvisibleSpace]\) + s)\)\^4 + 
      \((\((\(-5.`\) + s)\)\ 
            \((\(4.50319577736617482`\[InvisibleSpace]\) + 
                34.8332052647553513`\ s + 45.5341346094399046`\ s\^2 + 
                39.9900950725826476`\ s\^3 + 14.4099613488268962`\ s\^4 + 
                1.874021794164587`\ s\^5)\))\)/
        \((\((\(2.`\[InvisibleSpace]\) + s)\)\^4\ 
            \((\(-1.54335440756903219`\) - 7.4885253309155999`\ s - 
                16.5908993000363906`\ s\^2 - 4.83380609779031189`\ s\^3 - 
                1.40600243770370347`\ s\^4 - 0.137412425984960506`\ s\^5)\))
          \)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["How close are T and its rational approximation Trat?", "Subsection"],

Cell["\<\
The Mma. command ListPlot is used for plotting data.  In the plot \
below the horizontal axis represents the gridpoint number (and not \
frequency).\
\>", "Text"],

Cell[CellGroupData[{

Cell["ListPlot[  Abs[T-Sample[Trat]],PlotRange -> All]", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0163105 0.00749906 0.0147151 3.44445 [
[.16629 .00222 -6 -9 ]
[.16629 .00222 6 0 ]
[.31627 .00222 -6 -9 ]
[.31627 .00222 6 0 ]
[.46625 .00222 -6 -9 ]
[.46625 .00222 6 0 ]
[.61624 .00222 -6 -9 ]
[.61624 .00222 6 0 ]
[.76622 .00222 -9 -9 ]
[.76622 .00222 9 0 ]
[.9162 .00222 -9 -9 ]
[.9162 .00222 9 0 ]
[.00381 .10083 -30 -4.5 ]
[.00381 .10083 0 4.5 ]
[.00381 .18694 -24 -4.5 ]
[.00381 .18694 0 4.5 ]
[.00381 .27305 -30 -4.5 ]
[.00381 .27305 0 4.5 ]
[.00381 .35916 -18 -4.5 ]
[.00381 .35916 0 4.5 ]
[.00381 .44527 -30 -4.5 ]
[.00381 .44527 0 4.5 ]
[.00381 .53138 -24 -4.5 ]
[.00381 .53138 0 4.5 ]
[.00381 .61749 -30 -4.5 ]
[.00381 .61749 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16629 .01472 m
.16629 .02097 L
s
[(20)] .16629 .00222 0 1 Mshowa
.31627 .01472 m
.31627 .02097 L
s
[(40)] .31627 .00222 0 1 Mshowa
.46625 .01472 m
.46625 .02097 L
s
[(60)] .46625 .00222 0 1 Mshowa
.61624 .01472 m
.61624 .02097 L
s
[(80)] .61624 .00222 0 1 Mshowa
.76622 .01472 m
.76622 .02097 L
s
[(100)] .76622 .00222 0 1 Mshowa
.9162 .01472 m
.9162 .02097 L
s
[(120)] .9162 .00222 0 1 Mshowa
.125 Mabswid
.05381 .01472 m
.05381 .01847 L
s
.0913 .01472 m
.0913 .01847 L
s
.1288 .01472 m
.1288 .01847 L
s
.20379 .01472 m
.20379 .01847 L
s
.24128 .01472 m
.24128 .01847 L
s
.27878 .01472 m
.27878 .01847 L
s
.35377 .01472 m
.35377 .01847 L
s
.39126 .01472 m
.39126 .01847 L
s
.42876 .01472 m
.42876 .01847 L
s
.50375 .01472 m
.50375 .01847 L
s
.54124 .01472 m
.54124 .01847 L
s
.57874 .01472 m
.57874 .01847 L
s
.65373 .01472 m
.65373 .01847 L
s
.69123 .01472 m
.69123 .01847 L
s
.72872 .01472 m
.72872 .01847 L
s
.80371 .01472 m
.80371 .01847 L
s
.84121 .01472 m
.84121 .01847 L
s
.8787 .01472 m
.8787 .01847 L
s
.95369 .01472 m
.95369 .01847 L
s
.99119 .01472 m
.99119 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.01631 .10083 m
.02256 .10083 L
s
[(0.025)] .00381 .10083 1 0 Mshowa
.01631 .18694 m
.02256 .18694 L
s
[(0.05)] .00381 .18694 1 0 Mshowa
.01631 .27305 m
.02256 .27305 L
s
[(0.075)] .00381 .27305 1 0 Mshowa
.01631 .35916 m
.02256 .35916 L
s
[(0.1)] .00381 .35916 1 0 Mshowa
.01631 .44527 m
.02256 .44527 L
s
[(0.125)] .00381 .44527 1 0 Mshowa
.01631 .53138 m
.02256 .53138 L
s
[(0.15)] .00381 .53138 1 0 Mshowa
.01631 .61749 m
.02256 .61749 L
s
[(0.175)] .00381 .61749 1 0 Mshowa
.125 Mabswid
.01631 .03194 m
.02006 .03194 L
s
.01631 .04916 m
.02006 .04916 L
s
.01631 .06638 m
.02006 .06638 L
s
.01631 .0836 m
.02006 .0836 L
s
.01631 .11805 m
.02006 .11805 L
s
.01631 .13527 m
.02006 .13527 L
s
.01631 .15249 m
.02006 .15249 L
s
.01631 .16972 m
.02006 .16972 L
s
.01631 .20416 m
.02006 .20416 L
s
.01631 .22138 m
.02006 .22138 L
s
.01631 .2386 m
.02006 .2386 L
s
.01631 .25583 m
.02006 .25583 L
s
.01631 .29027 m
.02006 .29027 L
s
.01631 .30749 m
.02006 .30749 L
s
.01631 .32472 m
.02006 .32472 L
s
.01631 .34194 m
.02006 .34194 L
s
.01631 .37638 m
.02006 .37638 L
s
.01631 .3936 m
.02006 .3936 L
s
.01631 .41083 m
.02006 .41083 L
s
.01631 .42805 m
.02006 .42805 L
s
.01631 .46249 m
.02006 .46249 L
s
.01631 .47972 m
.02006 .47972 L
s
.01631 .49694 m
.02006 .49694 L
s
.01631 .51416 m
.02006 .51416 L
s
.01631 .5486 m
.02006 .5486 L
s
.01631 .56583 m
.02006 .56583 L
s
.01631 .58305 m
.02006 .58305 L
s
.01631 .60027 m
.02006 .60027 L
s
.25 Mabswid
.01631 0 m
.01631 .61803 L
s
.008 w
.02381 .01472 Mdot
.03131 .01473 Mdot
.03881 .01489 Mdot
.04631 .01536 Mdot
.05381 .01639 Mdot
.0613 .01815 Mdot
.0688 .02102 Mdot
.0763 .02582 Mdot
.0838 .03439 Mdot
.0913 .04742 Mdot
.0988 .05851 Mdot
.1063 .06001 Mdot
.1138 .05745 Mdot
.1213 .06054 Mdot
.1288 .06724 Mdot
.1363 .0752 Mdot
.14379 .09694 Mdot
.15129 .12831 Mdot
.15879 .16153 Mdot
.16629 .18874 Mdot
.17379 .20061 Mdot
.18129 .20745 Mdot
.18879 .21775 Mdot
.19629 .21522 Mdot
.20379 .23717 Mdot
.21129 .24117 Mdot
.21879 .25924 Mdot
.22628 .27154 Mdot
.23378 .28106 Mdot
.24128 .30048 Mdot
.24878 .3029 Mdot
.25628 .32608 Mdot
.26378 .3248 Mdot
.27128 .34795 Mdot
.27878 .34642 Mdot
.28628 .36634 Mdot
.29378 .3672 Mdot
.30127 .38185 Mdot
.30877 .38648 Mdot
.31627 .39522 Mdot
.32377 .40369 Mdot
.33127 .40738 Mdot
.33877 .41843 Mdot
.34627 .41954 Mdot
.35377 .43092 Mdot
.36127 .43354 Mdot
.36877 .44343 Mdot
.37627 .45354 Mdot
.38376 .46642 Mdot
.39126 .49588 Mdot
.39876 .54193 Mdot
.40626 .58234 Mdot
.41376 .60332 Mdot
.42126 .59187 Mdot
.42876 .53978 Mdot
.43626 .50606 Mdot
.44376 .51118 Mdot
.45126 .48998 Mdot
.45876 .49381 Mdot
.46625 .50218 Mdot
.47375 .49817 Mdot
.48125 .50928 Mdot
.48875 .50773 Mdot
.49625 .51117 Mdot
.50375 .51202 Mdot
.51125 .51117 Mdot
.51875 .50773 Mdot
.52625 .50928 Mdot
.53375 .49817 Mdot
.54124 .50218 Mdot
.54874 .49381 Mdot
.55624 .48998 Mdot
.56374 .51118 Mdot
.57124 .50606 Mdot
.57874 .53978 Mdot
.58624 .59187 Mdot
.59374 .60332 Mdot
.60124 .58234 Mdot
.60874 .54193 Mdot
.61624 .49588 Mdot
.62373 .46642 Mdot
.63123 .45354 Mdot
.63873 .44343 Mdot
.64623 .43354 Mdot
.65373 .43092 Mdot
.66123 .41954 Mdot
.66873 .41843 Mdot
.67623 .40738 Mdot
.68373 .40369 Mdot
.69123 .39522 Mdot
.69873 .38648 Mdot
.70622 .38185 Mdot
.71372 .3672 Mdot
.72122 .36634 Mdot
.72872 .34642 Mdot
.73622 .34795 Mdot
.74372 .3248 Mdot
.75122 .32608 Mdot
.75872 .3029 Mdot
.76622 .30048 Mdot
.77372 .28106 Mdot
.78121 .27154 Mdot
.78871 .25924 Mdot
.79621 .24117 Mdot
.80371 .23717 Mdot
.81121 .21522 Mdot
.81871 .21775 Mdot
.82621 .20745 Mdot
.83371 .20061 Mdot
.84121 .18874 Mdot
.84871 .16153 Mdot
.85621 .12831 Mdot
.8637 .09694 Mdot
.8712 .0752 Mdot
.8787 .06724 Mdot
.8862 .06054 Mdot
.8937 .05745 Mdot
.9012 .06001 Mdot
.9087 .05851 Mdot
.9162 .04742 Mdot
.9237 .03439 Mdot
.9312 .02582 Mdot
.9387 .02102 Mdot
.94619 .01815 Mdot
.95369 .01639 Mdot
.96119 .01536 Mdot
.96869 .01489 Mdot
.97619 .01473 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@000?l08@000?l0
8@000?l08@0004801043008180000`40000200817`020@@00P4N008110020A/01043008110020AP0
104200@10`020A00001200030@0000<000@100017`001@400001008000<100006`00104000420004
0@000A`000@100010P001040004L00050@0000400P001040004200030@0001L000D100000@050004
0@000@l0001300030@00008000@1000170050@8000@100017@001040004200040@000A`000@10001
0P001040004L00050@0000400P001040004200030@0001L000<100000P000`40000200040@000@l0
001400050@0000400P000`40000J00040@000@<000@100017@030@<000@100017@020@<000@10001
70001@400001008000@100010P000`40000G00030@0000<000D100000@0200030@0000d0000Q0003
0@00024000@100010P000`40000K00030@0100<000@100017@000`40000300040@000A`000@10001
0P001040004L00050@0000400P001040004200030@0001L000<1000010001040004200030@0000d0
000Q00030@0001h000@100010P001040004N00810`001040004M00030@0000<000@1000170001040
004200040@000AX00`4300040@000@8000@100015`030@<000@100010P001040004?00008@000`40
000O008110020B0000<100000P020Al00`4300817P020@@00P4M00030@0000800P4400816P000`40
0002008110020A00000Q00030@000?`0000M0?l11040024000P100400@0100L110000`4000070003
0@0000H000<100001`000`40000700030@0000H000<100001`000`40000700030@0000H000<10000
1`000`40000700030@0000H000<100001`000`40000700030@0000H000<100001`000`4000070003
0@0000L000<100001P000`40000700030@0000L000<100001P000`40000700030@00008010402001
00400@010P000`40000100008@000`40000900030@0101L000<1000090000`40000T00030@0002<0
00<1000090000`40000T00030@0000<000<100403P00024000<1000030020MX00P4B00008@000`40
000=00030@000=T000<10000400002400P4?0081eP020A@0000Q00030@0000l000<10000e@000`40
000B00008@000`40003l00008@000`40000@0081dP020AH0000Q00814P000`40003A00030@0001@0
000Q00030@000?`0000Q00030@0001801`7400L16000024000<100004`020@0400400LD000@10040
0P4H00008@020AX00P7000817`00024000<100006P000`40002o00030@0001d0000Q00030@0001/0
0P6l00818@00024000<1000070000`40002k00030@0001l0000Q00030@000?`0000Q0081o@000240
00<10000o000024000<10000o00000800P4400030@0000<00P4300@10P030@D000<100007@020KP0
0P4S000000D00@000@0800040@000@8000<100001P000`40000200817`000`40002g00030@000240
00001@01000100P000@100010`000`40000500030@00008000<10000o00000050040004020001040
004400040@0000<11@000`40003l000000D00@000@0800040@000@D000@100011`000`40003l0000
00D00@000@0800040@000@8000@100010P000`40000500030@000?`0000200812P020@@00P4300@1
10020Od0000Q00030@000?`0000Q00030@0001l00P6d00819@00024000<1000080000`40002c0003
0@0002<0000Q0081o@00024000<10000o000024000<10000o000024000<10000o000024000<10000
o00002400P7m00008@000`40003l00008@000`40000Q0081/0020BL0000Q00030@00028000<10000
[`000`40000U00008@020Od0000Q00030@000?`0000Q00030@000?`00008008110000`4000030081
0`030@D000<10000o00000L000@1000120001040004500030@00008000<10000o00000L000@10001
20001040004500030@0000800P4T0081[0020BT0000700040@000@P000@100010P030@D000<10000
90000`40002[00030@0002L0000700040@000@P000@100010P000`40000500030@000?`000070004
0@000@P000@100010P000`40000500030@0002D00P6X0081:`0000P00P4:00810`040@@00P4W00<1
Y0020@03004002X0000Q00030@0002P000<10000X`000`40000[00008@000`40000[0081W0020C40
000Q00030@0002T00P400`01002L00<1;`0002400P4[00030@0009l000<10000;@00024000<10000
o000024000<10000o000024000<10000o000024000<10000;@020IP00P4c00008@020Bl00`6D0081
00<00@00<P00024000<10000<0000`40002C00030@0003<0000Q00030@000?`0000Q00030@000?`0
000Q0081o@00024000<10000<0020I400P4g00008@000`40000a00030@00090000<10000=@000080
0P4400030@0000<00P4400030@0000800`4500030@000?`000001@01000100P000@100010`000`40
000500030@00008000<10000<P020Hh00P4h000000D00@000@0800040@000@@000<1000010000`40
00020081=0000`40002=00030@0003H000001@01000100P000@100011000104000030@D000<10000
=0020HX00P4j000000D00@000@0800040@000@D000@100011`000`40000e00030@0008T000<10000
>00000050040004020001040004200040@000@8000<100001@000`40003l00000P020@X00P4300@1
0P040@@00P7m00008@000`40003l00008@000`40000f0081QP020C`0000Q00030@0003L00`620081
00<00@00>`00024000<10000>@000`40002100030@0003`0000Q0081o@00024000<10000o0000240
00<10000o000024000<10000o00002400P4k00@1NP040D00000Q00030@0003/000<10040N`000`40
0@1000008@000`40003l00008@000`40003l00008@000`40003l00008@020D400P5b0081AP000240
00<10000?P020@03004007800`5400008@000`40000o00030@0007D000<10000@P0000h00P440003
0@000080104400030@000?`0000=00040@000@X000<100000`020Od0000=00040@000@X000<10000
0`000`4000120081KP020DP0000=00040@000@X000<100000`000`40001300<1JP020@03004004L0
000=00040@000@X000<100000`000`40001500030@0006T000<10000B00000d000@1000120030@D0
0P7m00003P020@/000<100000`000`4000160081IP020D`0000Q00030@0004L000<10000I@000`40
001:00008@000`4000180081HP020Dh0000Q00030@0004T000<10000H@000`40001<00008@020D/0
0P5N0081D000024000<10000B`000`40001M00030@0004h0000Q00030@0004`00P5J0081DP000240
00<10000C@020EL00P400`01001A00008@020Dl000<10000EP000`40001B00008@000`40003l0000
8@000`40001?00@1D0040ED0000Q00030@00050000<10040D@000`400@1E00008@000`40003l0000
8@020E@00P5<0081F@00024000<10000E0030DP00P400`01001H00008@000`40001F00030@0004L0
00<10000F@0000800P4400030@000080104200@10P030@D000<10000E`020D@00P5M000000D00@00
0@0:00050@00004020000`4000020081F@000`40001300030@0005/000001@01000100X000<10000
0P000`40000500030@00008000<10000o0000005004000402P000`40000300040@0000<11@000`40
001I0081@0020El000001@01000100X000<1000010001040004700030@0005X000<10000?`000`40
001M000000D00@000@0800<10`001040004200030@0000D000<10000o00000800P4;00030@000080
0P4300@110020E`00P4l0081H@00024000<10000G0000`40000k00030@0005l0000Q00030@000?`0
000Q00030@000?`0000Q0081o@00024000<10000o000024000<10000K0020AX00P5b00008@000`40
001]00<15P020@0300400740000Q00030@0005d00P4@00030@0000813P020@<000<100003@020F<0
000Q0081G`000`40000?008100<00@003P030A8000<10000H@00024000<10000J@020@H000<10000
4@000`4000030081K`00024000<10000JP000`40000700@11P040@X000<10000K@00024000<10000
J`020@P000<100401P40100100470081L@0002400P5]00030@0000X000D100400@0<00030@0006l0
000Q00030@000?`0000Q00030@000?`00008008110000`40000200@10P030@D000<10000o00000L0
00@100012P000`40000400030@0000800P7m00001`001040004:00030@0000@000<100000P000`40
003l00001`001040004:00040@0000<11@000`40001W008190020Fd0000700040@000@X000D10000
0@0700030@0005l00P4700030@0002<000<1000010020FD0000700040@000@P00`4300030@0000D0
00<10000H0000`40000c00030@0006<0000800812`00104000040@@00P7m00008@000`40003l0000
8@000`40003l00008@000`40003l00008@020Od0000Q00030@000?`0000Q00030@000?`0000Q0003
0@000?`0000Q00030@0006400P4`0081I`0002400P5S00030@0002l000<10000I@00024000<10000
o000024000<10000I@020BP00P5[00008@000`40001V00030@0002L000<10000J@0002400P5T0081
;0020FT0000Q00030@0006@000<10000:`000`40001W00008@000`40003l00000P020@@000<10000
0P040@<000<100000P030@D000<10000o0000005004000402P000`40000200030@0000D000<10000
0P000`40003l000000D00@000@0:00030@0000<000<1000010000`4000020081o@00000500400040
2P000`40000300040@0000<1o`05000000D00@000@0:00030@0000@000@10001o`07000000D00@00
0@0800<10`001040004200030@000?l01@0000800P4;00040@0000@10P040Ol010000?l08@000?l0
8@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-17.1746, -0.0164061, 0.5169,
   0.00112537}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here is a similar plot, only now the horizontal axis represents \
frequency w\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ Transpose[{wpts,Abs[T-Sample[Trat]]}],
          PlotRange -> {{0.,5.},All}]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  FormatType->InputForm],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.0147151 3.44445 [
[.2 .00222 -3 -9 ]
[.2 .00222 3 0 ]
[.4 .00222 -3 -9 ]
[.4 .00222 3 0 ]
[.6 .00222 -3 -9 ]
[.6 .00222 3 0 ]
[.8 .00222 -3 -9 ]
[.8 .00222 3 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .10083 -30 -4.5 ]
[-0.0125 .10083 0 4.5 ]
[-0.0125 .18694 -24 -4.5 ]
[-0.0125 .18694 0 4.5 ]
[-0.0125 .27305 -30 -4.5 ]
[-0.0125 .27305 0 4.5 ]
[-0.0125 .35916 -18 -4.5 ]
[-0.0125 .35916 0 4.5 ]
[-0.0125 .44527 -30 -4.5 ]
[-0.0125 .44527 0 4.5 ]
[-0.0125 .53138 -24 -4.5 ]
[-0.0125 .53138 0 4.5 ]
[-0.0125 .61749 -30 -4.5 ]
[-0.0125 .61749 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(1)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(2)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(3)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(4)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(5)] 1 .00222 0 1 Mshowa
.125 Mabswid
.04 .01472 m
.04 .01847 L
s
.08 .01472 m
.08 .01847 L
s
.12 .01472 m
.12 .01847 L
s
.16 .01472 m
.16 .01847 L
s
.24 .01472 m
.24 .01847 L
s
.28 .01472 m
.28 .01847 L
s
.32 .01472 m
.32 .01847 L
s
.36 .01472 m
.36 .01847 L
s
.44 .01472 m
.44 .01847 L
s
.48 .01472 m
.48 .01847 L
s
.52 .01472 m
.52 .01847 L
s
.56 .01472 m
.56 .01847 L
s
.64 .01472 m
.64 .01847 L
s
.68 .01472 m
.68 .01847 L
s
.72 .01472 m
.72 .01847 L
s
.76 .01472 m
.76 .01847 L
s
.84 .01472 m
.84 .01847 L
s
.88 .01472 m
.88 .01847 L
s
.92 .01472 m
.92 .01847 L
s
.96 .01472 m
.96 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
0 .10083 m
.00625 .10083 L
s
[(0.025)] -0.0125 .10083 1 0 Mshowa
0 .18694 m
.00625 .18694 L
s
[(0.05)] -0.0125 .18694 1 0 Mshowa
0 .27305 m
.00625 .27305 L
s
[(0.075)] -0.0125 .27305 1 0 Mshowa
0 .35916 m
.00625 .35916 L
s
[(0.1)] -0.0125 .35916 1 0 Mshowa
0 .44527 m
.00625 .44527 L
s
[(0.125)] -0.0125 .44527 1 0 Mshowa
0 .53138 m
.00625 .53138 L
s
[(0.15)] -0.0125 .53138 1 0 Mshowa
0 .61749 m
.00625 .61749 L
s
[(0.175)] -0.0125 .61749 1 0 Mshowa
.125 Mabswid
0 .03194 m
.00375 .03194 L
s
0 .04916 m
.00375 .04916 L
s
0 .06638 m
.00375 .06638 L
s
0 .0836 m
.00375 .0836 L
s
0 .11805 m
.00375 .11805 L
s
0 .13527 m
.00375 .13527 L
s
0 .15249 m
.00375 .15249 L
s
0 .16972 m
.00375 .16972 L
s
0 .20416 m
.00375 .20416 L
s
0 .22138 m
.00375 .22138 L
s
0 .2386 m
.00375 .2386 L
s
0 .25583 m
.00375 .25583 L
s
0 .29027 m
.00375 .29027 L
s
0 .30749 m
.00375 .30749 L
s
0 .32472 m
.00375 .32472 L
s
0 .34194 m
.00375 .34194 L
s
0 .37638 m
.00375 .37638 L
s
0 .3936 m
.00375 .3936 L
s
0 .41083 m
.00375 .41083 L
s
0 .42805 m
.00375 .42805 L
s
0 .46249 m
.00375 .46249 L
s
0 .47972 m
.00375 .47972 L
s
0 .49694 m
.00375 .49694 L
s
0 .51416 m
.00375 .51416 L
s
0 .5486 m
.00375 .5486 L
s
0 .56583 m
.00375 .56583 L
s
0 .58305 m
.00375 .58305 L
s
0 .60027 m
.00375 .60027 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.89064 .04742 Mdot
.79844 .05851 Mdot
.72271 .06001 Mdot
.65931 .05745 Mdot
.60541 .06054 Mdot
.55896 .06724 Mdot
.51848 .0752 Mdot
.48284 .09694 Mdot
.45119 .12831 Mdot
.42286 .16153 Mdot
.39733 .18874 Mdot
.37417 .20061 Mdot
.35305 .20745 Mdot
.33368 .21775 Mdot
.31583 .21522 Mdot
.29932 .23717 Mdot
.28398 .24117 Mdot
.26967 .25924 Mdot
.25628 .27154 Mdot
.2437 .28106 Mdot
.23186 .30048 Mdot
.22067 .3029 Mdot
.21007 .32608 Mdot
.2 .3248 Mdot
.19042 .34795 Mdot
.18127 .34642 Mdot
.17252 .36634 Mdot
.16414 .3672 Mdot
.15608 .38185 Mdot
.14833 .38648 Mdot
.14086 .39522 Mdot
.13364 .40369 Mdot
.12665 .40738 Mdot
.11988 .41843 Mdot
.1133 .41954 Mdot
.1069 .43092 Mdot
.10067 .43354 Mdot
.09459 .44343 Mdot
.08865 .45354 Mdot
.08284 .46642 Mdot
.07715 .49588 Mdot
.07156 .54193 Mdot
.06607 .58234 Mdot
.06067 .60332 Mdot
.05535 .59187 Mdot
.0501 .53978 Mdot
.04491 .50606 Mdot
.03978 .51118 Mdot
.0347 .48998 Mdot
.02967 .49381 Mdot
.02467 .50218 Mdot
.0197 .49817 Mdot
.01475 .50928 Mdot
.00983 .50773 Mdot
.00491 .51117 Mdot
0 .51202 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@000?l08@000540104^00@1;`020C4000<10000;P030@<0001C00030@0002d0
00<10000;`001040004`00030@0003400@410040001C00030@0002h000<10000<@000`40000[00D1
<P010@400@0005<000<10000;`000`40000^0081;P001040004`00<10`0005<000<10000<0000`40
000_00030@0002`000<10040<0000`40000300008@000`40000]00<1;`001040004^00040@000Bl0
0P4`00030@0000<0000Q00030@0002l000<10000;P020C000P4a00030@0002h0104200008@000`40
003l00008@3l0@<0000Q00030@0000L000<100001`000`40000700030@0000L000<100001`000`40
000700030@0000L000<100001`000`40000700030@0000L000<100001`000`40000700030@0000L0
00<100001`000`40000700030@0000L000<100001`000`40000700030@0000L000<100001`000`40
000700030@0000L000<100001`000`40000700030@0000P000<100000@00024000<10000;`000`40
000_00030@0002l000<10000;`000`40000`00030@000040000Q00030@000?`0000Q00030@000?`0
000Q0081o@00024000<10000o000024000<10000o000024000<10000g0020Ah0000Q0081gP000`40
000L00008@000`40002R0081F000024000<10000U0020@d000<100002`020A400P4f00008@000`40
002E00030@0001X000<1000040000`40000d00008@020HT00P5b00008@000`40002900030@000700
000Q00030@0007h00P5l00008@000`40001o00030@0007X0000Q00030@000?`0000Q0081o@000240
00<10000o000024000<10000M@020HD00002008110000`40000300810`040@800`4500030@0007H0
00<10000P`0000050040004020001040004200030@0000H000<100000P020Od000001@01000100P0
00@100010`000`40000500030@00008000<10000o00000050040004020001040004400040@0000<1
1@000`40003l000000D00@000@0800040@000@D000@100011`000`40003l000000D00@000@080004
0@000@8000@100010P000`4000050081o@0000800P4:008110020@<0104400030@000?`0000Q0003
0@0006d00P6=00008@000`40001^00030@0008/0000Q0081o@00024000<10000o000024000<10000
o000024000<10000o000024000<10000o00002400P7m00008@000`40003l00008@000`40001V0081
U000024000<10000I`000`40002B00008@020Od0000Q00030@000?`0000Q00030@000?`000080081
10000`40000300810`030@D000<10000o00000L000@1000120001040004500030@0000800P5Q0081
VP0000L000@1000120001040004500030@00008000<10000H@000`40002H00001`00104000480004
0@000@800`4500030@000?`0000700040@000@P000@100010P000`40000500030@0005X00P6P0000
1`001040004800040@000@8000<100001@000`40001K00030@0009h0000800812P020@<010440081
EP020JD0000Q00030@0005H000<10000X`00024000<10000B`020Jl0000Q00030@0004`000@10000
0P6Z00008@020E8000<10000Z000024000<10000o000024000<10000o000024000<10000o0000240
0P580081/`00024000<10000@`020@<000<10000/@00024000<10000A0000`40002e00008@000`40
003l00008@000`40003l00008@020D400P6j00008@000`40001100030@000;P0000Q00030@000?`0
0002008110000`400003008110000`40000200<11@000`40000l0081_P0000050040004020001040
004300030@0000D000<100000P020Ch000<10000_00000050040004020001040004400030@0000@0
00<100000P000`40003l000000D00@000@0800040@000@@000@100000`4500030@0003T00P710000
00D00@000@0800040@000@D000@100011`000`40000j00030@000;l000001@01000100P000@10001
0P001040004200030@0000D00P7m00000P020@X00P4300@10P040@@000<10000o000024000<10000
=P020L@0000Q00030@0003<00P4200030@000<80000Q00030@0003@000<10000a@0002400P7m0000
8@000`40003l00008@000`40003l00008@000`40003l00008@020Bl00P400`010@3900008@000`40
000_00040@000LT0000Q00030@000?`0000Q00030@000?`0000Q0081o@00024000<10000:P040Lh0
000Q00030@0002/000<10040cP0000h00P4400030@000080104400030@000?`0000=00040@000@X0
00<100000`000`40003l00003@001040004:00030@0000<00P7m00003@001040004:00030@0000<0
00<100009@040M<0000=00040@000@X000<100000`000`40000V00030@010=<0000=00040@000@P0
0`4500030@000?`0000>00812`000`4000030081o@00024000<100008`020ML0000Q00030@000240
0P400`01003F00008@000`40000R00030@000=L0000Q008180020M/0000Q00030@00020000<10000
f@00024000<100007P020M`0000Q00030@0001`00P400`01003K00008@000`40000M00030@000=`0
000Q0081o@00024000<100006@030N00000Q00030@0001X00P7P00008@000`40003l00008@020AP0
0P7S00008@000`40000E008100<00@00hP00024000<100005P000`40003S00000P020@@000<10000
0P040@80104200<11@000`40000D0081iP000005004000402P001@40000100P000<100000P020AH0
00<10000i0000005004000402P000`40000200030@0000D000<100000P000`40003l000000D00@00
0@0:00030@0000<000@100000`4500030@0001800P7X000000D00@000@0:00030@0000@000@10001
1`000`40000C00030@000>H000001@01000100P00`4300040@000@8000<100001@000`40003l0000
0P020@/000<100000P020@<0104400814P020NT0000Q00030@00018000<10000i`00024000<10000
o000024000<10000o00002400P7m00008@000`40003l00008@000`4000050081m@00024000<10000
10030@P00P7[00008@020@800P4200030@0000P000<10000j@00024000<100000P020OP0000Q0004
0@010@8000@100000P7c000080030@03004100@00`7c00008@020@8000<100000`000`40003b0000
8@020Od0000Q00030@000?`0000Q00030@000?`00008008110000`40000200@10P030@D000<10000
o00000L000@100012P000`40000400030@0000800P7m00001`001040004:00030@0000@000<10000
0P000`4000090081l@0000L000@100012P00104000030@D000<100002P00104000020N`000070004
0@000@X000D100000@0700030@0000l000<10000jP0000L000@1000120030@<000<100001@020Od0
000800812`00104000040@@000<10000o000024000<10000o000024000<10000o00002400P7m0000
8@000`40003l00008@000`40003l00008@000`40003l00008@000`40000=0081k@0002400P4?0003
0@000>/0000Q00030@000?`0000Q00030@0000X00P7`00008@000`40000;00030@000>h0000Q0081
30020Nl0000Q00030@0000`000<10000k@00024000<10000o00000800P4400030@00008010430003
0@0000800`4500030@000?`000001@01000100X000<100000P000`40000500030@0000800P7m0000
00D00@000@0:00030@0000<000<1000010000`40000200030@000?`000001@01000100X000<10000
0`00104000030Ol01@000005004000402P000`40000400040@000Ol01`0000050040004020030@<0
00@100010P000`40003o00D0000200812`00104000040@80107o00@0003o0240003o0240003o0240
003o02400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.660464, -0.0193031, 
  0.0199313, 0.0011573}}],

Cell[BoxData[
    RowBox[{
    \(Graphics::"gptn"\), \( : \ \), 
      "\<\"Coordinate \\!\\(\\*InterpretationBox[\\\"\\\\[Infinity]\\\", \
DirectedInfinity[1]]\\) in \
\\!\\({\\*InterpretationBox[\\\"\\\\[Infinity]\\\", DirectedInfinity[1]], \
0}\\) is not a floating-point number.\"\>"}]], "Message"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["More on Rational Approximation", "Section"],

Cell["\<\
RationalModel[ ] does rational approximation by calling the \
Caratheodory-Fejer approximation algorithm by N.Threfethen, implemented here \
under the name CFApproximant[].  (this is transparent to the user).  As most \
input is typically the default one, results may be somewhat unusual at times. \
 If RationalModel[ ] does not do a good job, you may try the routine \
NewtonFit[ ].  Rational approximation is a subject unto itself, and there are \
many nontrivial aspects to the problem of rational approximation.\
\>", "Text"],

Cell["\<\
Here we attempt to do a rational approximation with low degree \
rationals\
\>", "Text"],

Cell[CellGroupData[{

Cell["Trat3 = RationalModel[s,DegreeOfDenominator -> 3]", "Input"],

Cell[BoxData[
    InterpretationBox[
      \("Error in input: \n  Internal stability requires that the option \n  \
OrderOfDenominator \n  must specify an integer greater than or equal to "\
\[InvisibleSpace]4\),
      SequenceForm[ 
      "Error in input: \n  Internal stability requires that the option \n  \
OrderOfDenominator \n  must specify an integer greater than or equal to ", 4],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \($Failed\)], "Output"]
}, Open  ]],

Cell["Too low!  Now try a rational with denominator with degree 4", "Text"],

Cell[CellGroupData[{

Cell["Trat3 = RationalModel[s,DegreeOfDenominator -> 4]", "Input"],

Cell[BoxData[
    InterpretationBox[\("Error = "\[InvisibleSpace]15.0700492335091729`\),
      SequenceForm[ "Error = ", 15.070049233509174],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(-\(\(9.37912141739274218`\ 
            \((\(-5.`\) + s)\)\)\/\((\(2.`\[InvisibleSpace]\) + s)\)\^4
            \)\)\)], "Output"]
}, Open  ]],

Cell["\<\
The approximation is not good as the error figure suggests.  A plot \
similar to the one produced before is more informative.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Working",
WindowSize->{585, 654},
WindowMargins->{{177, Automatic}, {5, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"Magnification"->1},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->9],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->9],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 44, 0, 107, "Title"],
Cell[1778, 53, 263, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[2066, 62, 43, 0, 54, "Section"],

Cell[CellGroupData[{
Cell[2134, 66, 29, 0, 27, "Input"],
Cell[2166, 68, 122, 2, 46, "Print"],
Cell[2291, 72, 115, 2, 33, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2455, 80, 45, 0, 54, "Section"],

Cell[CellGroupData[{
Cell[2525, 84, 836, 38, 507, "Input",
  InitializationCell->True],
Cell[3364, 124, 179, 3, 39, "Message"],
Cell[3546, 129, 185, 3, 39, "Message"],

Cell[CellGroupData[{
Cell[3756, 136, 13247, 538, 186, 6195, 446, "GraphicsData", 
"PostScript", "Graphics"],
Cell[17006, 676, 94271, 4140, 233, 72380, 3865, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[111338, 4823, 51, 0, 54, "Section"],

Cell[CellGroupData[{
Cell[111414, 4827, 194, 7, 42, "Input",
  InitializationCell->True],
Cell[111611, 4836, 77, 1, 33, "Print"],
Cell[111691, 4839, 79, 1, 20, "Print"],
Cell[111773, 4842, 301, 9, 37, "Print"],
Cell[112077, 4853, 301, 9, 37, "Print"],
Cell[112381, 4864, 37, 1, 20, "Print"],
Cell[112421, 4867, 69, 1, 20, "Print"],
Cell[112493, 4870, 65, 1, 20, "Print"],
Cell[112561, 4873, 66, 1, 20, "Print"],
Cell[112630, 4876, 86, 1, 20, "Print"],
Cell[112719, 4879, 36, 1, 20, "Print"],
Cell[112758, 4882, 114, 2, 20, "Print"],
Cell[112875, 4886, 109, 2, 20, "Print"],
Cell[112987, 4890, 114, 2, 20, "Print"],
Cell[113104, 4894, 113, 2, 20, "Print"],
Cell[113220, 4898, 113, 2, 20, "Print"],
Cell[113336, 4902, 36, 1, 20, "Print"],
Cell[113375, 4905, 36, 1, 20, "Print"],
Cell[113414, 4908, 42, 1, 20, "Print"],
Cell[113459, 4911, 42, 1, 20, "Print"],
Cell[113504, 4914, 68, 1, 20, "Print"],
Cell[113575, 4917, 63, 1, 20, "Print"],
Cell[113641, 4920, 63, 1, 20, "Print"],
Cell[113707, 4923, 54, 1, 20, "Print"],
Cell[113764, 4926, 67, 1, 20, "Print"],
Cell[113834, 4929, 56, 1, 20, "Print"],
Cell[113893, 4932, 41, 1, 20, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[113983, 4939, 55, 0, 54, "Section"],

Cell[CellGroupData[{
Cell[114063, 4943, 69, 0, 27, "Input"],
Cell[114135, 4945, 177, 3, 20, "Print"],
Cell[114315, 4950, 349, 6, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114701, 4961, 49, 0, 45, "Subsection"],

Cell[CellGroupData[{
Cell[114775, 4965, 211, 7, 42, "Input",
  InitializationCell->True],
Cell[114989, 4974, 18448, 592, 296, 4994, 421, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[133452, 5569, 89, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[133566, 5576, 223, 8, 57, "Input",
  InitializationCell->True],
Cell[133792, 5586, 297, 5, 45, "Output"],
Cell[134092, 5593, 16492, 512, 296, 4214, 356, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[150599, 6108, 67, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[150691, 6112, 115, 4, 57, "Input"],
Cell[150809, 6118, 422, 7, 45, "Output"],
Cell[151234, 6127, 17215, 548, 296, 4636, 388, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[168510, 6682, 46, 0, 54, "Section"],

Cell[CellGroupData[{
Cell[168581, 6686, 73, 0, 45, "Subsection"],

Cell[CellGroupData[{
Cell[168679, 6690, 475, 13, 132, "Input",
  InitializationCell->True],
Cell[169157, 6705, 14518, 657, 186, 6952, 559, "GraphicsData", 
"PostScript", "Graphics"],
Cell[183678, 7364, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[183857, 7373, 65, 0, 45, "Subsection"],

Cell[CellGroupData[{
Cell[183947, 7377, 283, 9, 72, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[184255, 7390, 32374, 1184, 216, 18430, 1007, "GraphicsData", 
"PostScript", "Graphics"],
Cell[216632, 8576, 31922, 1144, 209, 18189, 970, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[248627, 9728, 45, 0, 54, "Section"],

Cell[CellGroupData[{
Cell[248697, 9732, 21, 0, 27, "Input"],
Cell[248721, 9734, 57, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[248815, 9740, 24, 0, 27, "Input"],
Cell[248842, 9742, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[248938, 9748, 20, 0, 27, "Input"],
Cell[248961, 9750, 56, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[249054, 9756, 22, 0, 27, "Input"],
Cell[249079, 9758, 39, 1, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[249167, 9765, 61, 0, 54, "Section"],

Cell[CellGroupData[{
Cell[249253, 9769, 740, 34, 447, "Input",
  InitializationCell->True],
Cell[249996, 9805, 14168, 549, 186, 6193, 446, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264201, 10359, 182, 8, 57, "Input",
  InitializationCell->True],
Cell[264386, 10369, 77, 1, 33, "Print"],
Cell[264466, 10372, 79, 1, 20, "Print"],
Cell[264548, 10375, 301, 9, 37, "Print"],
Cell[264852, 10386, 301, 9, 37, "Print"],
Cell[265156, 10397, 37, 1, 20, "Print"],
Cell[265196, 10400, 69, 1, 20, "Print"],
Cell[265268, 10403, 65, 1, 20, "Print"],
Cell[265336, 10406, 66, 1, 20, "Print"],
Cell[265405, 10409, 86, 1, 20, "Print"],
Cell[265494, 10412, 36, 1, 20, "Print"],
Cell[265533, 10415, 114, 2, 20, "Print"],
Cell[265650, 10419, 109, 2, 20, "Print"],
Cell[265762, 10423, 114, 2, 20, "Print"],
Cell[265879, 10427, 113, 2, 20, "Print"],
Cell[265995, 10431, 113, 2, 20, "Print"],
Cell[266111, 10435, 36, 1, 20, "Print"],
Cell[266150, 10438, 36, 1, 20, "Print"],
Cell[266189, 10441, 42, 1, 20, "Print"],
Cell[266234, 10444, 42, 1, 20, "Print"],
Cell[266279, 10447, 68, 1, 20, "Print"],
Cell[266350, 10450, 63, 1, 20, "Print"],
Cell[266416, 10453, 63, 1, 20, "Print"],
Cell[266482, 10456, 54, 1, 20, "Print"],
Cell[266539, 10459, 67, 1, 20, "Print"],
Cell[266609, 10462, 56, 1, 20, "Print"],
Cell[266668, 10465, 41, 1, 20, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[266746, 10471, 59, 0, 45, "Subsection"],

Cell[CellGroupData[{
Cell[266830, 10475, 65, 0, 27, "Input"],
Cell[266898, 10477, 177, 3, 20, "Print"],
Cell[267078, 10482, 662, 11, 104, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[267789, 10499, 74, 0, 45, "Subsection"],
Cell[267866, 10501, 172, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[268063, 10509, 173, 4, 27, "Input",
  InitializationCell->True],
Cell[268239, 10515, 14372, 504, 186, 6183, 398, "GraphicsData", 
"PostScript", "Graphics"],
Cell[282614, 11021, 130, 3, 27, "Output"]
}, Open  ]],
Cell[282759, 11027, 101, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[282885, 11034, 219, 7, 42, "Input",
  InitializationCell->True],
Cell[283107, 11043, 11054, 408, 186, 4316, 320, "GraphicsData", 
"PostScript", "Graphics"],
Cell[294164, 11453, 302, 6, 39, "Message"],
Cell[294469, 11461, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[294660, 11471, 49, 0, 54, "Section"],
Cell[294712, 11473, 540, 8, 104, "Text"],
Cell[295255, 11483, 98, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[295378, 11490, 66, 0, 27, "Input"],
Cell[295447, 11492, 430, 9, 59, "Print"],
Cell[295880, 11503, 41, 1, 27, "Output"]
}, Open  ]],
Cell[295936, 11507, 75, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[296036, 11511, 66, 0, 27, "Input"],
Cell[296105, 11513, 175, 3, 20, "Print"],
Cell[296283, 11518, 152, 3, 46, "Output"]
}, Open  ]],
Cell[296450, 11524, 149, 3, 50, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

