(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     68465,       2140]*)
(*NotebookOutlinePosition[     69358,       2171]*)
(*  CellTagsIndexPosition[     69314,       2167]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["NewtonFit"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook is the documentation for the package NewtonFit, for treating \
nonlinear L2 data fitting  problems.  The main function is ",
  StyleBox["NewtonFit[ ] ",
    FontWeight->"Bold"],
  ",   which is an  implementation of the Newton algorithm .  "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["An L2 Approximation problem"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The L2 optimization or approximation problem  considered here is

\t\t\tGiven a function  F ( x  , a1 , a2 , . . . , am ) and two sets of n \
numbers each,
\t
\t\t\t(data points) \t \tP   =  { x1 , x2 , x3 , . . . , xn }
 (Prob)\t\t\t(data values)  \t\tV  =  { y1 , y2 , y3 , . . . , yn }
\t
\t\t\tFind ( if it exists ) an m-tuple ( a1 , a2 , a3 , . . . , am ) that \
minimizes
\t
\t\t\t\tchi2( a1 , a2 ,  .  .  .  , am ) =    Sum      (  yk - F ( xk  , a1 , \
a2 , . . . , am ) )^2 
\t\t\t\t\t\t\t\tk=1,n\
\>", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fit[ ]  can be used to treat Prob when the function F( x , a1 , \
. . . ) is linear in the a's.  For the general problem Prob a more powerful \
algorithm is necessary.  One example of this is the  classical Newton method, \
implemented here as the function ",
  StyleBox["NewtonFit",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  ".  Another is the well known Gauss-Newton algorithm.  These are iterative \
procedures that when converge produce a local solution to Prob.  This is the \
best one can hope for such a general optimization problem.  In practice, one \
way to go about finding global solutions is to run the algorithm repeatedly \
with different initial guesses, with the hope that the global solution will \
be found by one of these runs.\n\nThe emphasis in these notes is on models F( \
x , a1 , . . . , am ) which are rational functions in x, with coefficients \
given by a1 , a2, a3, . . . am.  The algorithm implemented  here is very \
general in that  in principle it solves Prob for F rational and for many \
other functions not necessarily rational.  The wide range of problems that \
can be treated with this implementation is due to the fact that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do both simbolic and numerical calculations.  "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["What does NewtonFit[ ]  do for you?",
    FontWeight->"Bold"],
  "\nThe package NewtonFit.m contains the function  ",
  StyleBox["NewtonFit[]",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  ".  You can\n     ",
  StyleBox["a.",
    FontWeight->"Bold"],
  " Find local solutions to  standard nonlinear L2 data fitting  problems for \
a wide range of models, \n          in particular models  which are rational \
functions of given order.\n     ",
  StyleBox["b.",
    FontWeight->"Bold"],
  " Solve weigthed nonlinear L2 data fitting  problems.\n     ",
  StyleBox["c.",
    FontWeight->"Bold"],
  " Find rational approximations to the data, where  the degree and the  ",
  StyleBox["minimum number of stable zeros \n         and poles",
    FontSlant->"Italic"],
  " is specified a priori."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Problems you may encounter when using NewtonFit  when treating rational \
models",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["1",
    FontWeight->"Bold"],
  ".  ",
  StyleBox["NewtonFit",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "  will fail frequently in arriving at  a local solution.  The nature of \
the problem of approximation with rational models is such that for many cases \
there are many narrow, skinny and curved  valleys in parameter space.  This \
produces a high degree of instability in local algorithms, such as Newton and \
Gauss-Newton.  A good initial guess is very important.\n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Even if a local solution is produced  you can never be sure if it is a \
global solution (unless the model is linear in the parameters, i.e., the \
classical linear fit).\n\nIn practice a partial cure for both problems 1. and \
2. is to produce lots of runs, initializing each time at a different location \
in parameter space.  More satisfactory would be to complement the local \
algorithms  with different algorithms having better global behavior.  This is \
not done here though. for lack of time."
}], "SmallText",
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["References.",
    FontWeight->"Bold"],
  "\n\nZ. Shafiei and A. T. Shenton, Theory and application of H-intinity \
disk method.  Report No.     \n       MES/ATS/BAE/002/90, Department of \
Mechanical Engineering, University of Liverpool, U. K.\n\t\nLuus, R. (1980) \
Optimization in model reduction\", International Journal of Control, \n       \
Vol. 32, N0. 5, pp. 741-747.\n\t\nP. Gill,  Murray and M. Wright, Practical \
Optimization, Academic Press, 1986.\n\t\n\t"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["1.First Example"], "Section",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[TextData[
"In this example we sample a high order rationalfunction of \"s\" on the \
imaginary axis \" I w \" , and fit a low order rational to the data that we \
obtained.  \nConsider the function \n\n( 1 )\t\tF[ s ] = 1 / ( s^3 + 6 s^2 + \
11 s + 6 ).\n\t\t\nA grid of points  j*w i  on the imaginary axis is given by \
\n\n( 2 ) \t\tw [[ i+1 ]]  = 0.01  ( 1.1 )^i ,      where i = 0, . . . , 99.\n\
\t\t\nand corresponding values v[[ i ]] are generated as \n\n( 3 ) \t\tv[[ i \
]] = F[  I * w[[ i ]]  ].\n\t\t\nFollowing Luus and Shenton-Shafiei, a \
\"reduced\" second order order model \n\n\t\t\t\t\t     a [ 1 ] s  +  1.\n( 4 \
)\t   g[ s , a ]       = \t  -----------------------------------\n\t    \t\t\t\
  a[ 2 ] + a [ 3 ] s + a [ 4 ]  s^2\n\nis sought.  More precisely,"], 
  "SmallText",
  Evaluatable->False,
  PageBreakBelow->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Problem",
    FontWeight->"Bold"],
  ".\n\nGiven  datapoints ( 2 ),  datavalues (  3  ) , and the model (  4  ) \
find parameters a[1], a[2], a[3] , a[4]\nthat minimize\n( 5 )\t\tSum[      \
Abs[  v[[ i ]]  -  g[  I * w[[ i ]]  , a ]  ]^2  ,      { i , 1 , n } ] \n"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Load the package"], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(<< "\<NewtonFit.m\>"; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"First we produce  the grid points and grid values"], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(w = Table[0.01\ \ 1.1\^i, {i, 0, 99}]; \n
    \(F[s_] := 1\/\(s\^3 + 6.\ s\^2 + 11.\ s + 6.\); \)\), 
    \(\(values = F[I\ w]; \)\), 
    \(\(points = I\ w; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The gridpoints s and gridvalues v are combined as a list of pairs pairs ( \
s , v ) called data below.   This is one of the input for ",
  StyleBox["NewtonFit",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "[]."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(data = Transpose[{points, values}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The model is set below in terms of parameters a[1], a[2],   ... and the \
variable s.  "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(model = \(a[1]\ s + 1.\)\/\(a[2]\ s\^2 + a[3]\ s + a[4]\); \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We now choose an initial set of parameters to start the iteration.  If \
these are not specified the function ",
  StyleBox["NewtonFit",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "[] defaults all of them as 0.  "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(initial1 = {\(-1.\), 5., 9., 4.}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The output of Newton is assigned to the variable output1 below.  This will \
be helpful when manipulating the results of the call to ",
  StyleBox["NewtonFit",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "[]."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(output1 = NewtonFit[data, model, s, a, Parameters \[Rule] initial1]\)], 
  "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]0.754419163461352493`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.581506845340728517`\),
      SequenceForm[ 
      0, "                   ", 0.75441916346135252, "         ", 
        0.5815068453407285],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]4.05838403543786796`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.482129412645315458`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.313686041121274516`\),
      SequenceForm[ 
      1, "   ", 4.058384035437868, "         ", 0.48212941264531545, 
        "         ", 0.31368604112127452],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(2\[InvisibleSpace]"   "\[InvisibleSpace]3.07859708775156626`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.0714609019078544793`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.012388866120528339`\),
      SequenceForm[ 
      2, "   ", 3.0785970877515663, "         ", 0.071460901907854479, 
        "         ", 0.012388866120528339],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(3\[InvisibleSpace]"   "\[InvisibleSpace]2.09594405152194918`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.00824722435888535088`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000601043198262159883`
        \),
      SequenceForm[ 
      3, "   ", 2.0959440515219492, "         ", 0.0082472243588853512, 
        "         ", 0.00060104319826215994],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(4\[InvisibleSpace]"   "\[InvisibleSpace]0.389809259163742041`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000208885044555724164`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000327769154408939478`
        \),
      SequenceForm[ 
      4, "   ", 0.38980925916374204, "         ", 0.00020888504455572417, 
        "         ", 0.00032776915440893946],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"   "\[InvisibleSpace]0.0285536182108089509`
        \[InvisibleSpace]"         "\[InvisibleSpace]1.6621903088022103`*^-6
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000327117421150067499`
        \),
      SequenceForm[ 
      5, "   ", 0.02855361821080895, "         ", 1.6621903088022102*^-06, 
        "         ", 0.00032711742115006749],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(6\[InvisibleSpace]"   "\[InvisibleSpace]0.0000899071574969450182`
        \[InvisibleSpace]"         "\[InvisibleSpace]3.82928898347017323`*^-11
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000327117408386177155`
        \),
      SequenceForm[ 
      6, "   ", 8.9907157496945029*^-05, "         ", 3.8292889834701731*^-11,
         "         ", 0.00032711740838617712],
      Editable->False]], "Print"],

Cell[BoxData[
    \({Parameters 
        \[Rule] {\(-0.134521167400646035`\), 4.86549099652770156`, 
          10.0684113995232893`, 6.01588312172409978`}, 
      SingValHessian 
        \[Rule] {0.401004689233975852`, 0.058370721056915471`, 
          0.00385516699559252895`, 0.00126541511206969703`}, 
      Cost \[Rule] 0.000327117408386177155`, 
      NormGradient \[Rule] 3.82928898347017323`*^-11, NIterations \[Rule] 6}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For an explanation of what the diagnostics mean, for example \
SingValHessian, type ?SingValHessian at the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " prompt to get a description.  \n\nThe results of the run above say that a \
local minimum has been found, since the gradient of the objective function  \
is close enough to 0, and the hessian has the correct signature.  This is how \
you form a function with the optimal parameters out of the model:"
}], "SmallText",
  Evaluatable->False,
  PageBreakWithin->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par = Parameters /. output1; \)\), 
    \(r[s_] = 
      model /. {
          a[j_] \[RuleDelayed] par\[LeftDoubleBracket]j\[RightDoubleBracket]}
          \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    FractionBox[
      RowBox[{
        RowBox[{
          StyleBox["1.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1], "\[InvisibleSpace]"}], "-", 
        \(0.134521167400646035`\ s\)}], 
      \(\(6.01588312172409978`\[InvisibleSpace]\) + 10.0684113995232893`\ s + 
        4.86549099652770156`\ s\^2\)]], "Output"]
}, Open  ]],

Cell[TextData[
"A plot is now produced which contains the (discrete) data being \
approximated, and the optimal function r[s]."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListPlot[Transpose[{Re[values], Im[values]}], 
        DisplayFunction \[Rule] Identity], 
      ParametricPlot[{Re[r[I\ t]], Im[r[I\ t]]}, {t, 0, 10.}, 
        DisplayFunction \[Rule] Identity], 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.191734 4.70785 0.589865 4.88171 [
[.42713 .57737 -12 -9 ]
[.42713 .57737 12 0 ]
[.66252 .57737 -9 -9 ]
[.66252 .57737 9 0 ]
[.89791 .57737 -12 -9 ]
[.89791 .57737 12 0 ]
[.17923 .00406 -30 -4.5 ]
[.17923 .00406 0 4.5 ]
[.17923 .10169 -24 -4.5 ]
[.17923 .10169 0 4.5 ]
[.17923 .19933 -30 -4.5 ]
[.17923 .19933 0 4.5 ]
[.17923 .29696 -30 -4.5 ]
[.17923 .29696 0 4.5 ]
[.17923 .3946 -30 -4.5 ]
[.17923 .3946 0 4.5 ]
[.17923 .49223 -30 -4.5 ]
[.17923 .49223 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.42713 .58987 m
.42713 .59612 L
s
[(0.05)] .42713 .57737 0 1 Mshowa
.66252 .58987 m
.66252 .59612 L
s
[(0.1)] .66252 .57737 0 1 Mshowa
.89791 .58987 m
.89791 .59612 L
s
[(0.15)] .89791 .57737 0 1 Mshowa
.125 Mabswid
.23881 .58987 m
.23881 .59362 L
s
.28589 .58987 m
.28589 .59362 L
s
.33297 .58987 m
.33297 .59362 L
s
.38005 .58987 m
.38005 .59362 L
s
.4742 .58987 m
.4742 .59362 L
s
.52128 .58987 m
.52128 .59362 L
s
.56836 .58987 m
.56836 .59362 L
s
.61544 .58987 m
.61544 .59362 L
s
.7096 .58987 m
.7096 .59362 L
s
.75668 .58987 m
.75668 .59362 L
s
.80375 .58987 m
.80375 .59362 L
s
.85083 .58987 m
.85083 .59362 L
s
.14466 .58987 m
.14466 .59362 L
s
.09758 .58987 m
.09758 .59362 L
s
.0505 .58987 m
.0505 .59362 L
s
.00342 .58987 m
.00342 .59362 L
s
.94499 .58987 m
.94499 .59362 L
s
.99207 .58987 m
.99207 .59362 L
s
.25 Mabswid
0 .58987 m
1 .58987 L
s
.19173 .00406 m
.19798 .00406 L
s
[(-0.12)] .17923 .00406 1 0 Mshowa
.19173 .10169 m
.19798 .10169 L
s
[(-0.1)] .17923 .10169 1 0 Mshowa
.19173 .19933 m
.19798 .19933 L
s
[(-0.08)] .17923 .19933 1 0 Mshowa
.19173 .29696 m
.19798 .29696 L
s
[(-0.06)] .17923 .29696 1 0 Mshowa
.19173 .3946 m
.19798 .3946 L
s
[(-0.04)] .17923 .3946 1 0 Mshowa
.19173 .49223 m
.19798 .49223 L
s
[(-0.02)] .17923 .49223 1 0 Mshowa
.125 Mabswid
.19173 .02847 m
.19548 .02847 L
s
.19173 .05288 m
.19548 .05288 L
s
.19173 .07729 m
.19548 .07729 L
s
.19173 .1261 m
.19548 .1261 L
s
.19173 .15051 m
.19548 .15051 L
s
.19173 .17492 m
.19548 .17492 L
s
.19173 .22374 m
.19548 .22374 L
s
.19173 .24815 m
.19548 .24815 L
s
.19173 .27255 m
.19548 .27255 L
s
.19173 .32137 m
.19548 .32137 L
s
.19173 .34578 m
.19548 .34578 L
s
.19173 .37019 m
.19548 .37019 L
s
.19173 .41901 m
.19548 .41901 L
s
.19173 .44341 m
.19548 .44341 L
s
.19173 .46782 m
.19548 .46782 L
s
.19173 .51664 m
.19548 .51664 L
s
.19173 .54105 m
.19548 .54105 L
s
.19173 .56546 m
.19548 .56546 L
s
.19173 .61427 m
.19548 .61427 L
s
.25 Mabswid
.19173 0 m
.19173 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .57495 Mdot
.97615 .57346 Mdot
.9761 .57182 Mdot
.97605 .57002 Mdot
.97598 .56803 Mdot
.9759 .56585 Mdot
.97579 .56345 Mdot
.97567 .56081 Mdot
.97552 .55791 Mdot
.97535 .55472 Mdot
.97513 .55121 Mdot
.97487 .54736 Mdot
.97455 .54312 Mdot
.97417 .53846 Mdot
.97371 .53334 Mdot
.97315 .52771 Mdot
.97247 .52153 Mdot
.97166 .51475 Mdot
.97067 .5073 Mdot
.96948 .49913 Mdot
.96804 .49017 Mdot
.9663 .48035 Mdot
.9642 .4696 Mdot
.96166 .45784 Mdot
.95861 .44499 Mdot
.95493 .43097 Mdot
.9505 .4157 Mdot
.94518 .3991 Mdot
.93879 .38111 Mdot
.93112 .36166 Mdot
.92196 .34072 Mdot
.91102 .31828 Mdot
.898 .29436 Mdot
.88255 .26905 Mdot
.8643 .24249 Mdot
.84283 .21491 Mdot
.81774 .18665 Mdot
.78859 .15818 Mdot
.755 .13011 Mdot
.71667 .10321 Mdot
.67339 .0784 Mdot
.62514 .05679 Mdot
.57217 .03956 Mdot
.51499 .02799 Mdot
.45449 .02332 Mdot
.39192 .02662 Mdot
.32888 .03871 Mdot
.26727 .05997 Mdot
.20914 .09028 Mdot
.15653 .12888 Mdot
.11128 .17443 Mdot
.07482 .22507 Mdot
.04806 .27855 Mdot
.0312 .33246 Mdot
.02381 .38448 Mdot
.02482 .43256 Mdot
.03273 .47514 Mdot
.04576 .51125 Mdot
.06206 .5405 Mdot
.07993 .56307 Mdot
.09792 .57955 Mdot
.11495 .59081 Mdot
.1303 .59787 Mdot
.14358 .60173 Mdot
.15468 .60329 Mdot
.16369 .60332 Mdot
.17082 .60242 Mdot
.17634 .60104 Mdot
.18053 .59947 Mdot
.18365 .59791 Mdot
.18596 .59646 Mdot
.18764 .59519 Mdot
.18884 .59411 Mdot
.18971 .59321 Mdot
.19032 .59248 Mdot
.19075 .5919 Mdot
.19105 .59143 Mdot
.19126 .59107 Mdot
.19141 .59079 Mdot
.19151 .59057 Mdot
.19158 .5904 Mdot
.19163 .59027 Mdot
.19166 .59017 Mdot
.19168 .5901 Mdot
.1917 .59004 Mdot
.19171 .59 Mdot
.19172 .58997 Mdot
.19172 .58994 Mdot
.19173 .58992 Mdot
.19173 .58991 Mdot
.19173 .5899 Mdot
.19173 .58989 Mdot
.19173 .58988 Mdot
.19173 .58988 Mdot
.19173 .58988 Mdot
.19173 .58987 Mdot
.19173 .58987 Mdot
.19173 .58987 Mdot
.19173 .58987 Mdot
.19173 .58987 Mdot
.5 Mabswid
.9743 .58986 m
.97404 .57176 L
.97334 .5553 L
.97199 .53634 L
.97018 .51848 L
.9657 .48693 L
.95901 .4531 L
.94951 .41649 L
.93706 .37864 L
.90893 .3138 L
.87276 .25198 L
.83315 .19964 L
.78443 .14922 L
.72734 .10381 L
.66697 .06789 L
.63202 .05182 L
.59939 .03961 L
.56867 .03043 L
.53993 .02379 L
.52415 .02092 L
.50722 .01845 L
.49199 .01676 L
.47811 .01566 L
.46542 .01502 L
.45197 .01472 L
.43942 .01479 L
.42813 .01515 L
.41506 .01591 L
.40777 .01651 L
.40107 .01716 L
.37629 .02045 L
.35341 .02476 L
.32915 .03072 L
.28335 .04616 L
.2452 .06368 L
.20933 .08468 L
.15582 .12639 L
.11215 .17381 L
.07837 .22502 L
.06636 .24883 L
.05725 .27045 L
.04506 .30833 L
.04054 .328 L
.03759 .34511 L
.03645 .35367 L
.03549 .36279 L
.03511 .36726 L
.03478 .37198 L
.03453 .37636 L
.03436 .38027 L
Mistroke
.03424 .38418 L
.03418 .3878 L
.03415 .39156 L
.03415 .39364 L
.03417 .39554 L
.03422 .39869 L
.03432 .40209 L
.03445 .40558 L
.03461 .40878 L
.03509 .41598 L
.03565 .4223 L
.03731 .43571 L
.03911 .4465 L
.04137 .45741 L
.04608 .47523 L
.05696 .50459 L
.06898 .52797 L
.0891 .55626 L
.10695 .57428 L
.12071 .58482 L
.1323 .59176 L
.14115 .59592 L
.14802 .59846 L
.15396 .60016 L
.15864 .60116 L
.16085 .60152 L
.16275 .60177 L
.16447 .60195 L
.16592 .60206 L
.16664 .6021 L
.16729 .60213 L
.16765 .60214 L
.16797 .60215 L
.16815 .60215 L
.16835 .60216 L
.16851 .60216 L
.16868 .60216 L
.16884 .60216 L
.16891 .60216 L
.16898 .60216 L
.16905 .60216 L
.16912 .60216 L
.1692 .60217 L
.16927 .60217 L
.16931 .60217 L
.16935 .60217 L
.16939 .60217 L
.16944 .60217 L
.16952 .60216 L
.16956 .60216 L
Mistroke
.1696 .60216 L
.16974 .60216 L
.16982 .60216 L
.1699 .60216 L
.1702 .60216 L
.17037 .60215 L
.17052 .60215 L
.17109 .60213 L
.17166 .60211 L
.17217 .60208 L
.17307 .60202 L
.17399 .60194 L
.17477 .60185 L
.17627 .60164 L
.17754 .60142 L
.17873 .60116 L
.1797 .60092 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[PP10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`<C4a000<`00IP00V@00c000o`0c000c<`0cIP0cV@0cc00co`1V001V<`1VIP1VV@1Vc01V
o`2I002I<`2IIP2IV@2Ic02Io`3<003<<`3<IP3<V@3<c03<o`3o003o<`3oIP3oV@3oc03ooc<003<0
<c<0IS<0VC<0c3<0oc<c03<c<c<cIS<cVC<cc3<coc=V03=V<c=VIS=VVC=Vc3=Voc>I03>I<c>IIS>I
VC>Ic3>Ioc?<03?<<c?<IS?<VC?<c3?<oc?o03?o<c?oIS?oVC?oc3?oofH006H0<fH0IVH0VFH0c6H0
ofHc06Hc<fHcIVHcVFHcc6HcofIV06IV<fIVVFIVc6IVofJI06JI<fJIIVJIVFJIc6JIofK<06K<<fK<
IVK<VFK<c6K<ofKo06Ko<fKoIVKoVFKoc6KooiT009T0<iT0IYT0VIT0c9T0oiTc09Tc<iTcIYTcVITc
c9TcoiUV09UV<iUVIYUVVIUVc9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo
09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laV
I/aVVLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<olco0<co<lcoI/coVLcoc<co
ool00?l0<ol0I_l0VOl0c?l0oolc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI
<onII_nIVOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo0?oo<oooI_ooVOooc>[ZjWAdM:NWYj0Pl=WI
fJj^[WMgMkVi^@000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?l06`000?l06`000?l06`000?l06`0001h0
0P4400030@000080104200@110000`40003P00007@001040004:00050@0000401`030N00000M0004
0@000@X000<100000P000`40000400030@000>00000G00@10P001040004:00030@0000<000<10000
0`000`40003P00007@001040004:00030@0000@000<100000P000`40000h01/1S@0001d000@10001
20030@<000@1000110000`40000_00T16`040HT0000N00812`000`40000200811@000`40000/00<1
5P020A002@600000=`000`40000W00D120020A0000<100003@020@P0105l0000=`020B<01@4>0003
0@0001l000<100002P030GT0000g00030@0002000P5500<1MP0003L000<100007@030@800P510081
0`020G@0000g00030@0001/00P4600030@00040000<100000`030G40000g00030@0001T00P5D00<1
KP0003L000<100005P030ET00`5[0000=`020A@00`5O00<1J00003L000<100004@020F400P420081
IP0003L000<100003P030@030041064000<100000P020F@0000g00030@0000`00P4500030@0006H0
0P5R0000=`000`40000:0081LP020F00000g00030@0000P00P5f00030@0005d0000g00030@0000L0
00<10000M`020Ed0000g00811P020GX0105K0000=`000`4000030081O@000`4000020ET0000g0003
0@00008000<10000PP020EL0000g00040@0000<1Q@000`40001D0000=`001040004200030@0008@0
0P5D000090020@@000<100000P040@@00`6<0081DP0002<000@100012P000`40000300030@0008h0
0P5@00008`001040004:00030@000080106=008100<00@00CP0001d0104200040@000@X000L10000
0@01090000@10001CP0002<000@100012P001040004200030@0009800P5<00008`001040004800<1
00<00@000P000`40002D00030@0004T0000T00812`020@@000<10000U@000`4000180000<0000`40
000400030@0009H000<10000A`0002l000<100001@020IP00P570000;@020@P000<10000U`030DH0
000]008120000`40002H00030@0104D0000/00030@0000P000<10000V`000`4000120000:`000`40
000900030@0009`000<10000@@0002X000<100002P000`40002M0081@@0002T000<100002`000`40
002O00030@0003h0000X00030@0000`00P6Q00030@0003d0000X00030@0000`000<10000X@000`40
000l00009`000`40000=00030@000:400P4m00009P000`40000>00030@000:800P4l00009@000`40
000?00030@000:@000<10000>@0002@000<1000040000`40002U00030@0003P0000Q00<14`000`40
002V00030@0003L0000R00030@0001800P6X00030@0003H0000Q00030@0001<000<10000Y`000`40
000f00008@000`40000C00030@000:P000<10000=@00020000<1000050000`40002Y0081=@0001l0
00<100005@000`40002Z00030@0003<0000N008110000`400003008110020@D000<10000Z`000`40
000b00007@020@03004000L000@100010P001040004400030@000:`000<10000<@0001d000@10001
20001040004200040@000@@00`6]00030@000300000G00@100<00@400P000`40000600040@000@<0
0P4500030@000:h000<10000;`0001`00P4200030@0000H000@100010P001040004400030@000:l0
00<10000;P0001/000<100400P000`40000600040@000@8000@1000110000`40002_00<1;P0001X0
00@100000P4:008110020@D000<10000/0020Bh0000I00030@0001/000<10000/@000`40000/0000
5`030Ad00P6c00030@0002/0000H00030@0001`000<10000/`000`40000Z000060000`40000L0003
0@000;<000<10000:P0001L000<100007@000`40002d00030@0002T0000G00030@0001d000<10000
]@000`40000X00005P000`40000N00030@000;D00P4Y00005P000`40000N00030@000;H000<10000
9`0001D000<100007`020KP000<100009P0001D000<100007`000`40002h00030@0002D0000D0003
0@00020000<10000^@000`40000T000050000`40000P00030@000;T000<10000900001<000<10000
8@000`40002j00030@0002<0000C00030@00024000<10000^P020B@0000B00030@00028000<10000
^`000`40000R00004P000`40000R0081_@000`40000Q00003`030BD000<10000_0000`40000Q0000
40020BD000<10000_@000`40000P00004@000`40000S00030@000;d000<100008000014000<10000
8`000`40002n00030@0001l0000@00030@0000/00P4400030@0000<00P4400811@000`40002n00<1
7`00010000<100002P001040004800040@000@8000@1000110030Kl00P4O000040000`40000:0004
0@000@P000@100010P001040004400030@000<0000<100007@00010000<1000010040@8000@10001
20001040004200<11@000`40003000030@0001d0000?00030@0000/000@100012000104000420003
0@0000D000<10000`@000`40000L00003`000`40000;00040@000@P000@100010P000`4000050003
0@000<4000<10000700000l000<1000030020@X00P4400<110000`40003200030@0001/0000?0003
0@0002D000<10000`P020A`0000>00030@0002H00P7400030@0001X0000>00030@0002H000<10000
``000`40000J00003P000`40000V00030@000<@000<100006@0000/00P400`01000W00030@000<@0
00<100006@0000`000<10040:0000`40003500030@0001P0000=00030@0002L000<10000a@020AT0
000=00030@0002L000<10000aP000`40000G00003@000`40000W0081a`000`40000G00003@000`40
000W00030@000<H000<100005`0000d000<100009`000`40003700030@0001H0000=00030@0002L0
00<10000a`000`40000F00003@000`40000W00030@000<P00P4F00003@000`40000W00030@000<P0
0P4F000030000`40000X0081bP000`40000D000030000`40000X00030@000<T000<10000500000`0
00<10000:0000`40003:00030@0001<0000<00030@0002P000<10000bP020A@00009008100<00@00
:@000`40003:0081500000X000<10040:P000`40003;00030@000180000<00030@0000l00P440003
0@0000<00P4500030@0000<000<10000b`000`40000B000030000`40000>00040@000@P000@10001
10000`40000300<1b`000`40000B000030000`40000>00040@000@P000D1000100050@@000<10000
c0020A80000<00030@0000P0104200040@000@P000H10001004200030@0000<000<10000c0020A80
000<00030@0000h000@1000120001040004200030@0100D000<10000c0000`40000A000030000`40
000>00040@000@P000@100010`020@D000<10000c0000`40000A000030000`40000?00812P020@D0
00<100000`000`40003=00030@000100000<00030@0002P000<10000c@020A40000=00030@0002L0
0P7>00814@0000d000<100009`000`40003>00030@0000l0000=00030@0002L000<10000cP000`40
000?00002@020@8000<100009`000`40003>0081400000X000@10001:@000`40003?00030@0000h0
000=00030@0002L000<10000c`000`40000>00003P000`40000V00030@000<l000<100003P0000h0
00<100009P020M000P4?00003P000`40000V00030@000=0000<100003@0000h000<100009P000`40
003@00030@0000d0000>00030@0002H000<10000d0020@h0000>00030@0002H000<10000d0020@h0
000>00030@0002H000<10000d@000`40000<00003`000`40000U0081dP020@d0000?00030@0002D0
00<10000d@020@d0000;00810P000`40000U00030@000=4000<10000300000`000@100019`000`40
003A00813@00010000<1000090000`40003B00030@0000/0000@00030@0002@000<10000dP000`40
000;00004@000`40000:008110000`40000300810`040@@000<10000dP020@`0000A00030@0000T0
00@1000120001040004200030@0000D00`7B00813000014000<100002@001040004800040@000@<0
00<1000010000`40003B00813000018000<100000P040@8000@1000120001040004400030@0000<0
00<10000dP020@`0000B00030@0000P000@1000120001040004500030@00008000<10000d`000`40
000:00004`000`40000700040@000@P000@100010P001040004400030@000=<00P4;00003`020@80
00<1000020020@X00P4400811@000`40003C00812`00010000D100000@0R00030@000=<00P4;0000
50000`40000P0081e0020@/0000E00030@0001l000<10000d`020@/0000E00030@0001l000<10000
d`020@/0000F00030@0001h000<10000e0000`40000900005`000`40000M00030@000=<00P4;0000
5`000`40000M00030@000=@00P4:00004`020@<000<1000070020MD00P4:000050000`4000020003
0@0001/000<10000e0020@X0000I00030@0001/000<10000e0020@X0000J00030@0001X000<10000
e0020@X0000J00030@0001X000<10000e0020@X0000K00030@0001T000<10000=0020@@000<10000
0`020@<00`4`008110000`40000200@1;P020@@000<100000P040@800`4;00812P0001P00P420003
0@0001P000<10000<`001040004800040@000@D000<10000;0001040004:00030@0002`000@10001
2P000`40000400030@0000P00P4:00006@00104000020AP00P4d00040@000@P000@100011@000`40
000/00040@000@X000<10000;0001040004:00030@0000@000<1000020020@X0000O00030@0001D0
00<10000<`001040004800040@000@800`4_00040@000@X000<10000;0001040004:00040@0000<1
2`020@X0000P00030@0001@000<10000<`001040004800040@000@8000<10000;`001040004:0003
0@0002`000@100012P001@40000100d00P4:00007@020@800P4D00030@0003<000@1000120001040
004200030@0002l000@1000120030Bh000@1000120030@<000<100002`020@X0000N00030@000080
00<100004@000`40000d00812P020@<0104_00812`000`40000]00812`00104000040@X000<10000
2@0002@000<1000040000`40003D00030@0000T0000U008140020MD000<100002@0000<0o`4D0@@0
000400030@0000X000<100002P000`40000200030@0000<00P4:00@12`000`40000:00030@0000X0
00<100002P000`40000:00030@0000X000<100002P000`40000:00030@0000X000<100002P000`40
000:00030@0000T000<100002P000`40000:00030@0000X000<100002P000`40000:00030@0000@0
000V00810`020@H01@7R00009`000`4000020@03004100T1hP0002/000P1000100400@@000<10000
h00003L000<10000h00003L00P7Q0000=`000`40003P0000\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-0.0432649, -0.123359, 
  0.000773979, 0.000746414}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["2. Template for many runs"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The example above is not typical in that the run produced satisfactory \
results in the first trial.  Approximation by rational functions is tricky \
business:  usually there are lots of local minima, and problems due to \
indefinite hessians are not uncommon.  Below you will find an example of a \
set of commands for running the program many times starting the iteration at \
different random locations in the  space of parameters.  \n\nThe example \
treated is the same as above.  Initial sets of parameters are generated \
randomly with values a[i] in the interval ( - 5 , 5 ) .  The output of \
individual runs is stored for later inspection in a file named \"output1\"."],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< "\<NewtonFit.m\>"; \)\), 
    \(\(w = Table[0.01\ 1.1\^i, {i, 0, 99}]; \)\), 
    \(\(F[s_] = 1\/\(s\^3 + 6.\ s\^2 + 11.\ s + 6.\); \)\), 
    \(\(values = F[I\ w]; \)\), 
    \(\(points = I\ w; \)\), 
    \(\(data = Transpose[{points, values}]; \)\), 
    \(\(model = \(a[1]\ s + 1.\)\/\(a[2]\ s\^2 + a[3]\ s + a[4]\); \)\), 
    \(Do[initial = 10.\ {Random[], Random[], Random[], Random[]} - 5.; 
      output = NewtonFit[data, model, s, a, Parameters \[Rule] initial]; 
      \(Save["\<output1\>", initial, output];\), {i, 1, 20}]; \nExit\)}], 
  "Input",
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]782.125696932055358`
        \[InvisibleSpace]"         "\[InvisibleSpace]373.827323235416253`\),
      SequenceForm[ 
      0, "                   ", 782.12569693205535, "         ", 
        373.82732323541626],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]0.`
        \[InvisibleSpace]"         "\[InvisibleSpace]782.125696932055358`
        \[InvisibleSpace]"         "\[InvisibleSpace]373.827323235416253`\),
      SequenceForm[ 
      1, "   ", 0.0, "         ", 782.12569693205535, "         ", 
        373.82732323541626],
      Editable->False]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]9.34744227795542492`
        \[InvisibleSpace]"         "\[InvisibleSpace]11.2056392876001065`\),
      SequenceForm[ 
      0, "                   ", 9.3474422779554249, "         ", 
        11.205639287600107],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]0.`
        \[InvisibleSpace]"         "\[InvisibleSpace]9.34744227795542492`
        \[InvisibleSpace]"         "\[InvisibleSpace]11.2056392876001065`\),
      SequenceForm[ 
      1, "   ", 0.0, "         ", 9.3474422779554249, "         ", 
        11.205639287600107],
      Editable->False]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]419.139735175319039`
        \[InvisibleSpace]"         "\[InvisibleSpace]111.235424715217146`\),
      SequenceForm[ 
      0, "                   ", 419.139735175319, "         ", 
        111.23542471521715],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]21.6546257036088762`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.80067715501053609`
        \[InvisibleSpace]"         "\[InvisibleSpace]2.66023775614429069`\),
      SequenceForm[ 
      1, "   ", 21.654625703608875, "         ", 0.80067715501053616, 
        "         ", 2.6602377561442907],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(2\[InvisibleSpace]"   "\[InvisibleSpace]10.5935745251882496`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.655465658803819728`
        \[InvisibleSpace]"         "\[InvisibleSpace]2.34376904834298116`\),
      SequenceForm[ 
      2, "   ", 10.593574525188249, "         ", 0.65546565880381968, 
        "         ", 2.3437690483429812],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(3\[InvisibleSpace]"   "\[InvisibleSpace]97.4034923514014749`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.16903048897816884`
        \[InvisibleSpace]"         "\[InvisibleSpace]2.28543859499640111`\),
      SequenceForm[ 
      3, "   ", 97.403492351401482, "         ", 0.16903048897816883, 
        "         ", 2.2854385949964011],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(4\[InvisibleSpace]"   "\[InvisibleSpace]0.`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.16903048897816884`
        \[InvisibleSpace]"         "\[InvisibleSpace]2.28543859499640111`\),
      SequenceForm[ 
      4, "   ", 0.0, "         ", 0.16903048897816883, "         ", 
        2.2854385949964011],
      Editable->False]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]3.45223841159841171`
        \[InvisibleSpace]"         "\[InvisibleSpace]3.61726805871105971`\),
      SequenceForm[ 
      0, "                   ", 3.4522384115984117, "         ", 
        3.6172680587110597],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]0.`
        \[InvisibleSpace]"         "\[InvisibleSpace]3.45223841159841171`
        \[InvisibleSpace]"         "\[InvisibleSpace]3.61726805871105971`\),
      SequenceForm[ 
      1, "   ", 0.0, "         ", 3.4522384115984117, "         ", 
        3.6172680587110597],
      Editable->False]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]106.298966164789376`
        \[InvisibleSpace]"         "\[InvisibleSpace]68.6403514501360234`\),
      SequenceForm[ 
      0, "                   ", 106.29896616478938, "         ", 
        68.640351450136023],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]3.8698040832923235`
        \[InvisibleSpace]"         "\[InvisibleSpace]61.6314976662632751`
        \[InvisibleSpace]"         "\[InvisibleSpace]47.5986776477015816`\),
      SequenceForm[ 
      1, "   ", 3.8698040832923235, "         ", 61.631497666263272, 
        "         ", 47.598677647701585],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(2\[InvisibleSpace]"   "\[InvisibleSpace]645476.849679163766`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000308469463805225529`
        \[InvisibleSpace]"         "\[InvisibleSpace]20.3427129388466365`\),
      SequenceForm[ 
      2, "   ", 645476.84967916377, "         ", 0.00030846946380522558, 
        "         ", 20.342712938846638],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(3\[InvisibleSpace]"   "\[InvisibleSpace]1010.74419439466645`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000472430433186144416`
        \[InvisibleSpace]"         "\[InvisibleSpace]19.9484481750484796`\),
      SequenceForm[ 
      3, "   ", 1010.7441943946666, "         ", 0.00047243043318614437, 
        "         ", 19.94844817504848],
      Editable->False]], "Print"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(.\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["3. Using a weight."], "Section",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[TextData[{
  "It is possible to emphasize some data points over other by means of a \
weight function as in\n\n\t\tSum[  weight[[i]]*( Abs[ v[[i]]  -  g[  I * w[[ \
i ]]  , a ]  ]^2  )  ,  { i , 1 , n } ] \n\nA weight can be specified as \
input for the function ",
  StyleBox["NewtonFit",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "[ ] .\nSuppose that the example considered in section 1. gives an answer \
that we reject as producing too large deviation from the model to the data \
for values of w[[i]]  i = 25 , . . . , 45.  To reduce the error at these 21 \
points a weight function is defined as "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(wt = Join[Table[1., {24}], Table[10., {21}], Table[1., {55}]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We can use the parameter values found in the previous run to initialize the \
current one."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(initial2 = Parameters /. output1; \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(output2 = 
      NewtonFit[data, model, s, a, Parameters \[Rule] initial2, 
        Weight \[Rule] wt]\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]0.00372872677728560963`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000526309321218798054`
        \),
      SequenceForm[ 
      0, "                   ", 0.0037287267772856099, "         ", 
        0.00052630932121879807],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]0.165521753017843646`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.0000226568023759128678`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000401831434579619717`
        \),
      SequenceForm[ 
      1, "   ", 0.16552175301784364, "         ", 2.2656802375912868*^-05, 
        "         ", 0.0004018314345796197],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(2\[InvisibleSpace]"   "\[InvisibleSpace]0.00417434053524022008`
        \[InvisibleSpace]"         "\[InvisibleSpace]2.57386147644860585`*^-8
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000401816523290127758`
        \),
      SequenceForm[ 
      2, "   ", 0.0041743405352402205, "         ", 2.5738614764486055*^-08, 
        "         ", 0.00040181652329012774],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(3\[InvisibleSpace]"   "\[InvisibleSpace]3.43865925472445432`*^-7
        \[InvisibleSpace]"         "\[InvisibleSpace]3.06372892247651362`*^-10
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000401816523288686067`
        \),
      SequenceForm[ 
      3, "   ", 3.4386592547244539*^-07, "         ", 3.0637289224765135*^-10,
         "         ", 0.00040181652328868603],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(4\[InvisibleSpace]"   "\[InvisibleSpace]0.`
        \[InvisibleSpace]"         "\[InvisibleSpace]3.06372892247651362`*^-10
        \[InvisibleSpace]"         "\[InvisibleSpace]0.000401816523288686067`
        \),
      SequenceForm[ 
      4, "   ", 0.0, "         ", 3.0637289224765135*^-10, "         ", 
        0.00040181652328868603],
      Editable->False]], "Print"],

Cell[BoxData[
    \({Parameters 
        \[Rule] {\(-0.135427820545090726`\), 4.71744820426683819`, 
          10.1359981048913083`, 6.01399215928739927`}, 
      SingValHessian 
        \[Rule] {1.39787380055665488`, 0.231320130811744029`, 
          0.0153349387091865185`, 0.00155874725556147897`}, 
      Cost \[Rule] 0.000401816523288686067`, 
      NormGradient \[Rule] 3.06372892247651362`*^-10, NIterations \[Rule] 4}
      \)], "Output"]
}, Open  ]],

Cell[TextData[
"To plot the resulting function set just proceed as in the first example."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["4. Stable Zeros and Poles."], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A zero z of a rational function R[x] is stable if Re[z] < 0.  A pole z of \
R[x] is stable if Re[z]<0.   We now consider the problem of finding the set \
of optimal parameters in (Prob) with rational model, with the additional \
constraint that the resulting rational function has either (a) stable poles, \
(b) stable zeros, and (c) stable poles and zeros.  Key in solving this \
problem with the tools we have is the following result.\n\nProposition.\nLet \
P[ x ] be a monic polynomial with real coefficients.  Then P[ x ] has all its \
zeros in the left open (closed) left half plane if and only if  when P is \
factored over the reals as a product of degree 1 and degree 2 monic \
polynomials the coefficients of each  factor are positive (nonnegative).\n\n\
We can take advantage of this result because the function ",
  StyleBox["NewtonFit",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "[ ] calculates derivatives by symbolic differentiation.  As an example, \
consider the problem from section 1. with the additional constraint that all \
zeros and poles of the resulting rational function are located in the left \
half plane.  Note that the answer obtained in section 1. is not satisfactory, \
because it has a zero in the RHP.   Define as model"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(model3 = 
      \(a[4]\ \((a[1]\^2\ s + 1.)\)\)\/\(a[2]\^2\ s\^2 + a[3]\^2\ s + 1\); 
    \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that any choice of parameters in model3 produces a rational functions \
with zeros and poles off the Right Hand Plane.  \n     The set of initial \
parameters given below has been determined with a multiple run of ",
  StyleBox["NewtonFit[] ",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "with several initial sets of parameters.  This set in particular produces \
a local solution as shown below."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(initial3 = {0., .9, 1.3, .17}; \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(output3 = NewtonFit[data, model3, s, a, Parameters \[Rule] initial3]\)],
   "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Iter    step          grad           cost"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(0\[InvisibleSpace]"                   \
"\[InvisibleSpace]0.32370331744577192`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.00430163209508041877`
        \),
      SequenceForm[ 
      0, "                   ", 0.32370331744577191, "         ", 
        0.0043016320950804189],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"   "\[InvisibleSpace]0.112942896597330455`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.0220049670632181904`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.0015677740461229499`\),
      
      SequenceForm[ 
      1, "   ", 0.11294289659733045, "         ", 0.022004967063218188, 
        "         ", 0.0015677740461229502],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(2\[InvisibleSpace]"   "\[InvisibleSpace]0.00762117850806652175`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.0000177770530825137846`
        \[InvisibleSpace]"         "\[InvisibleSpace]0.00154468882754794156`
        \),
      SequenceForm[ 
      2, "   ", 0.0076211785080665213, "         ", 1.7777053082513787*^-05, 
        "         ", 0.0015446888275479414],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(3\[InvisibleSpace]"   "\[InvisibleSpace]0.0000305235121581233848`
        \[InvisibleSpace]"         "\[InvisibleSpace]1.18668481917843005`*^-9
        \[InvisibleSpace]"         "\[InvisibleSpace]0.0015446886541138463`\),
      
      SequenceForm[ 
      3, "   ", 3.0523512158123378*^-05, "         ", 1.1866848191784302*^-09,
         "         ", 0.0015446886541138464],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(4\[InvisibleSpace]"   "\[InvisibleSpace]4.53644917316265416`*^-11
        \[InvisibleSpace]"         "\[InvisibleSpace]1.08998216895482947`*^-9
        \[InvisibleSpace]"         "\[InvisibleSpace]0.00154468865411384559`
        \),
      SequenceForm[ 
      4, "   ", 4.5364491731626537*^-11, "         ", 1.0899821689548295*^-09,
         "         ", 0.0015446886541138453],
      Editable->False]], "Print"],

Cell[BoxData[
    \({Parameters 
        \[Rule] {0.`, 1.00935969011286696`, 1.31713509982247423`, 
          0.166462800628930196`}, 
      SingValHessian 
        \[Rule] {91.4902997084746871`, 0.775119586193552123`, 
          0.350922023253075865`, 0.0313337397597327482`}, 
      Cost \[Rule] 0.00154468865411384559`, 
      NormGradient \[Rule] 1.08998216895482947`*^-9, NIterations \[Rule] 4}
      \)], "Output"]
}, Open  ]],

Cell[TextData[
"Now the rational function obtained above is produced, and a plot ais \
generated.."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par3 = Parameters /. output3; \)\), 
    \(r3[s_] = 
      model3 /. {
          a[j_] \[RuleDelayed] par3\[LeftDoubleBracket]j\[RightDoubleBracket]}
          \)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    FractionBox[
      RowBox[{"0.166462800628930196`", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["1.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], "\[InvisibleSpace]"}], "+", \(0.`\ s\)}], 
          ")"}]}], 
      \(1 + 1.73484487118435914`\ s + 1.0188069840247429`\ s\^2\)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListPlot[Transpose[{Re[values], Im[values]}], 
        DisplayFunction \[Rule] Identity], 
      ParametricPlot[{Re[r3[I\ t]], Im[r3[I\ t]]}, {t, 0, 10.}, 
        DisplayFunction \[Rule] Identity], 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.191734 4.70785 0.589843 4.88963 [
[.42713 .57734 -12 -9 ]
[.42713 .57734 12 0 ]
[.66252 .57734 -9 -9 ]
[.66252 .57734 9 0 ]
[.89791 .57734 -12 -9 ]
[.89791 .57734 12 0 ]
[.17923 .00309 -30 -4.5 ]
[.17923 .00309 0 4.5 ]
[.17923 .10088 -24 -4.5 ]
[.17923 .10088 0 4.5 ]
[.17923 .19867 -30 -4.5 ]
[.17923 .19867 0 4.5 ]
[.17923 .29647 -30 -4.5 ]
[.17923 .29647 0 4.5 ]
[.17923 .39426 -30 -4.5 ]
[.17923 .39426 0 4.5 ]
[.17923 .49205 -30 -4.5 ]
[.17923 .49205 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.42713 .58984 m
.42713 .59609 L
s
[(0.05)] .42713 .57734 0 1 Mshowa
.66252 .58984 m
.66252 .59609 L
s
[(0.1)] .66252 .57734 0 1 Mshowa
.89791 .58984 m
.89791 .59609 L
s
[(0.15)] .89791 .57734 0 1 Mshowa
.125 Mabswid
.23881 .58984 m
.23881 .59359 L
s
.28589 .58984 m
.28589 .59359 L
s
.33297 .58984 m
.33297 .59359 L
s
.38005 .58984 m
.38005 .59359 L
s
.4742 .58984 m
.4742 .59359 L
s
.52128 .58984 m
.52128 .59359 L
s
.56836 .58984 m
.56836 .59359 L
s
.61544 .58984 m
.61544 .59359 L
s
.7096 .58984 m
.7096 .59359 L
s
.75668 .58984 m
.75668 .59359 L
s
.80375 .58984 m
.80375 .59359 L
s
.85083 .58984 m
.85083 .59359 L
s
.14466 .58984 m
.14466 .59359 L
s
.09758 .58984 m
.09758 .59359 L
s
.0505 .58984 m
.0505 .59359 L
s
.00342 .58984 m
.00342 .59359 L
s
.94499 .58984 m
.94499 .59359 L
s
.99207 .58984 m
.99207 .59359 L
s
.25 Mabswid
0 .58984 m
1 .58984 L
s
.19173 .00309 m
.19798 .00309 L
s
[(-0.12)] .17923 .00309 1 0 Mshowa
.19173 .10088 m
.19798 .10088 L
s
[(-0.1)] .17923 .10088 1 0 Mshowa
.19173 .19867 m
.19798 .19867 L
s
[(-0.08)] .17923 .19867 1 0 Mshowa
.19173 .29647 m
.19798 .29647 L
s
[(-0.06)] .17923 .29647 1 0 Mshowa
.19173 .39426 m
.19798 .39426 L
s
[(-0.04)] .17923 .39426 1 0 Mshowa
.19173 .49205 m
.19798 .49205 L
s
[(-0.02)] .17923 .49205 1 0 Mshowa
.125 Mabswid
.19173 .02754 m
.19548 .02754 L
s
.19173 .05198 m
.19548 .05198 L
s
.19173 .07643 m
.19548 .07643 L
s
.19173 .12533 m
.19548 .12533 L
s
.19173 .14978 m
.19548 .14978 L
s
.19173 .17423 m
.19548 .17423 L
s
.19173 .22312 m
.19548 .22312 L
s
.19173 .24757 m
.19548 .24757 L
s
.19173 .27202 m
.19548 .27202 L
s
.19173 .32091 m
.19548 .32091 L
s
.19173 .34536 m
.19548 .34536 L
s
.19173 .36981 m
.19548 .36981 L
s
.19173 .41871 m
.19548 .41871 L
s
.19173 .44315 m
.19548 .44315 L
s
.19173 .4676 m
.19548 .4676 L
s
.19173 .5165 m
.19548 .5165 L
s
.19173 .54095 m
.19548 .54095 L
s
.19173 .5654 m
.19548 .5654 L
s
.19173 .61429 m
.19548 .61429 L
s
.25 Mabswid
.19173 0 m
.19173 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .57491 Mdot
.97615 .57341 Mdot
.9761 .57177 Mdot
.97605 .56996 Mdot
.97598 .56798 Mdot
.9759 .56579 Mdot
.97579 .56339 Mdot
.97567 .56074 Mdot
.97552 .55784 Mdot
.97535 .55464 Mdot
.97513 .55113 Mdot
.97487 .54727 Mdot
.97455 .54302 Mdot
.97417 .53835 Mdot
.97371 .53323 Mdot
.97315 .52759 Mdot
.97247 .5214 Mdot
.97166 .51461 Mdot
.97067 .50715 Mdot
.96948 .49896 Mdot
.96804 .48999 Mdot
.9663 .48015 Mdot
.9642 .46939 Mdot
.96166 .45761 Mdot
.95861 .44473 Mdot
.95493 .43069 Mdot
.9505 .4154 Mdot
.94518 .39877 Mdot
.93879 .38075 Mdot
.93112 .36127 Mdot
.92196 .34029 Mdot
.91102 .31782 Mdot
.898 .29386 Mdot
.88255 .26851 Mdot
.8643 .2419 Mdot
.84283 .21428 Mdot
.81774 .18598 Mdot
.78859 .15746 Mdot
.755 .12934 Mdot
.71667 .1024 Mdot
.67339 .07755 Mdot
.62514 .0559 Mdot
.57217 .03865 Mdot
.51499 .02706 Mdot
.45449 .02237 Mdot
.39192 .02568 Mdot
.32888 .03779 Mdot
.26727 .05909 Mdot
.20914 .08945 Mdot
.15653 .12811 Mdot
.11128 .17373 Mdot
.07482 .22445 Mdot
.04806 .27802 Mdot
.0312 .33202 Mdot
.02381 .38412 Mdot
.02482 .43228 Mdot
.03273 .47493 Mdot
.04576 .5111 Mdot
.06206 .5404 Mdot
.07993 .563 Mdot
.09792 .57951 Mdot
.11495 .59079 Mdot
.1303 .59786 Mdot
.14358 .60172 Mdot
.15468 .60329 Mdot
.16369 .60332 Mdot
.17082 .60242 Mdot
.17634 .60103 Mdot
.18053 .59946 Mdot
.18365 .5979 Mdot
.18596 .59645 Mdot
.18764 .59518 Mdot
.18884 .59409 Mdot
.18971 .5932 Mdot
.19032 .59246 Mdot
.19075 .59188 Mdot
.19105 .59141 Mdot
.19126 .59105 Mdot
.19141 .59077 Mdot
.19151 .59055 Mdot
.19158 .59038 Mdot
.19163 .59025 Mdot
.19166 .59015 Mdot
.19168 .59008 Mdot
.1917 .59002 Mdot
.19171 .58998 Mdot
.19172 .58994 Mdot
.19172 .58992 Mdot
.19173 .5899 Mdot
.19173 .58989 Mdot
.19173 .58988 Mdot
.19173 .58987 Mdot
.19173 .58986 Mdot
.19173 .58986 Mdot
.19173 .58985 Mdot
.19173 .58985 Mdot
.19173 .58985 Mdot
.19173 .58985 Mdot
.19173 .58985 Mdot
.19173 .58985 Mdot
.5 Mabswid
.97542 .58984 m
.97518 .57242 L
.97455 .55657 L
.97333 .53832 L
.97171 .5211 L
.96766 .49065 L
.96161 .45791 L
.95298 .42236 L
.94162 .38541 L
.91569 .32158 L
.88185 .2599 L
.84419 .20691 L
.79705 .15508 L
.74076 .1077 L
.68015 .06976 L
.64463 .05269 L
.61122 .03974 L
.57901 .02991 L
.54989 .02316 L
.53383 .02029 L
.51659 .01787 L
.50872 .01699 L
.50044 .01622 L
.48573 .01523 L
.47155 .01475 L
.45877 .01472 L
.4442 .01513 L
.4306 .01597 L
.41823 .01711 L
.40696 .01847 L
.38209 .02256 L
.35804 .02802 L
.33267 .03544 L
.28538 .0543 L
.24742 .07487 L
.21247 .09903 L
.16222 .14565 L
.14038 .17222 L
.12357 .19667 L
.10867 .22259 L
.09601 .24953 L
.0867 .27417 L
.08028 .29557 L
.07577 .3148 L
.074 .32416 L
.07246 .33386 L
.07135 .34231 L
.07055 .34979 L
.06995 .35707 L
.06954 .36376 L
Mistroke
.06937 .36744 L
.06924 .37127 L
.06916 .37483 L
.06913 .378 L
.06913 .38167 L
.06915 .38371 L
.06918 .38556 L
.06926 .38892 L
.06938 .3924 L
.06953 .39571 L
.06973 .39924 L
.07019 .40546 L
.07132 .41649 L
.07301 .42842 L
.07487 .4386 L
.07874 .45524 L
.0833 .47054 L
.09322 .4959 L
.10232 .51382 L
.11929 .53946 L
.13344 .5557 L
.14386 .56544 L
.15162 .57163 L
.15807 .57614 L
.16297 .57918 L
.16712 .58151 L
.17034 .58316 L
.17289 .58436 L
.17514 .58534 L
.17695 .58607 L
.17843 .58664 L
.17978 .58712 L
.18089 .5875 L
.18192 .58783 L
.18277 .58809 L
.18349 .5883 L
.18417 .58849 L
.18419 .5885 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[PP10`4000010?ooo`0007=cLjjb`k9=
NYM1Imb]`ULU>oooojjb`i>GYMcNiEePJ@00076;YF1fS;o;ecQ5D_ooooogjMSAa/c5^YVDR`0009BD
U:f][B4Q8Kfm_MkNgV=SHol0003o0000oooo003oool0od92@^7QhLS8b:n_[iJFUWemOFATI4];Bc8b
<_ogjIfP[eMIHM7Ej@00?`00O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2o
O`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmo
ocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_glo
ogmo07mo?gmoOgmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0
oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_koo
ool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?ooo
Oooo_mgNiUiPJIBGYZ0Pl9UVoiVI09VI<iVIIYVIVIVIc9VIoiW<09W<<iW<IYW<VIW<c9W<oiWo09Wo
<iWoIYWoVIWoc9Wool`00<`0<l`0I/`0VL`0c<`0ol`c0<`c<l`cI/`cVL`cc<`colaV0<aV<laVI/aV
VLaVc<aVolbI0<bI<lbII/bIVLbIc<bIolc<0<c<<lc<I/c<VLc<c<c<olco0<co<lcoI/coVLcoc<co
ool0<ol0I_l0VOl0c?lc0?lc<olcI_lcVOlcc?lcoomV0?mV<omVI_mVVOmVc?mVoonI0?nI<onII_nI
VOnIc?nIooo<0?o<<oo<I_o<VOo<c?o<oooo<oooI_ooVOl06`000?l06`000?l06`000?l06`0001h0
0P4400030@000080104200@11@000`40003O00007@001040004:00050@00004020020N00000M0004
0@000@X000<100000P000`40000500030@000=l0000G00@10P001040004:00030@0000<000<10000
10000`40003O00007@001040004:00030@0000@000<100000`000`4000100101S`0001d000@10001
20030@<000@100011@000`40000e00/140090HH0000N00812`000`40000200811P000`40000`00D1
3`020A<02@5m0000>0000`40000/00@10`020A0000<100003@020@/0105i0000>0020BX00`480003
0@0001l000<100003@030GH0000h00030@0002D0105000<1L`0003P000<100008P030Cl00P460081
L@0003P000<1000080020@030040040000<100001P030Fh0000h00030@0001d00`5A0081K00003P0
00<100006P030EH00`5Y0000>0020AT00P5L0081I`0003P000<100005P020E/00P4300<1I00003P0
00<100004@020@03004105h000<1000010020F80000h00030@0001800P5Y0081H00003P000<10000
4@000`40001[0081GP0003P000<100003`020G000P5L0000>0000`40000=0081M0020EX0000h0081
3@000`40001a00810`000`40001G0000>0000`40000:0081M@000`4000020081E`0003P000<10000
20020Gh000<10000E00003P000@100000P4400030@0007l00P5D0000>0000`40000200030@000081
Q0020E80000T008110000`40000200@11@000`4000030081R0000`40001?00008`001040004:0003
0@0000@000<100000P000`4000290081C`0002<000@100012P000`40000400810P000`4000280081
0P000`40001<00007@040@8000@100012P000`40000400040@000H`000@100000P5<00008`001040
004:00030@0000@000<10040T`000`40001900008`001040004800<11P020ID000<10000B00002@0
0P4;00030@0000@000<10000U@000`4000170000=P030IP00P570000=@000`4000020IT000<10000
A00002d00P4500050@000040V0020@03004004@0000^00030@00008000<100000P000`40002G0004
0@000D@0000b00030@0000<000<10000V`000`4000110000<@000`40000400030@0009`000<10000
@000030000<100001@000`40002M00030@0003l0000_00030@0000H000<10000WP020Cl0000^0003
0@0000L00P6Q00030@0003`0000]00030@0000P000<10000X@000`40000k0000;0000`4000090003
0@000:000`4l0000;0000`40000900030@000:4000<10040>`0002/000<100002P000`40002T0003
0@0003P0000Z00030@0000/000<10000Y@000`40000g00008@020@H000<1000030000`40002V0003
0@0003H0000R00030@0000<000<100003@020JP000<10000=@0002P000<100003@000`40002X0003
0@0003@0000W00030@0000h000<10000Z@000`40000c00009`000`40000>00030@000:P00P4e0000
9P000`40000?00030@000:T00P4d00007P020@@000<100400`020@@00P4600030@000:/000<10000
<@0001d000@1000110001@400001008000@100010P000`40000300030@000:`000<10000<00001d0
00@100010`000`40000200040@000@8000@100011@020Jh000<10000;`0001L0104200040@000@<0
00<100000P001040004300811P000`40002^00030@0002h0000M00040@000@8000<100000`001040
004200040@000@D000<10000[`000`40000]00007@001040004200030@0000<000@100010P001040
004500030@000:h00`4^00007P020@8000<100001@020@@00P4600030@000:l000<10040;@000280
00<100004`000`40002a00030@0002/0000G008120000`40000D0081/`000`40000Z000060000`40
000600030@0001@000<10000/`000`40000Y000080000`40000E00030@000;@000<10000:0000200
00<100005@000`40002e00030@0002L0000O00030@0001H000<10000]@000`40000W00007`000`40
000F00030@000;@00`4X00007P000`40000G00030@000;D000<100409`0001h000<100005`020KT0
00<10000900001d000<1000060000`40002h00030@0002@0000M00030@0001P000<10000^@000`40
000S000070000`40000I00030@000;X000<100008P0001`000<100006@000`40002k00030@000240
000L00030@0001T000<10000^@030B<0000K00030@0001X000<10000^P000`400@0R00006`000`40
000J0081_@000`40000P000040020@T000<100006P000`40002m00030@0001l0000A00030@0000H0
00<100006`000`40002m00030@0001l0000J00030@0001/000<10000_P000`40000N00006P000`40
000K00030@000;h000<100007P0001T000<100000P020@@000<100000`020@@00P4600030@000;d0
0`4O00006@001@400001008000<100001P001040004200040@000@D00P6o00817`0001T000D10000
0@0200030@0000H000@100010P001040004500030@000<0000<10000700001L0104200040@000@P0
00@100010P030@H000<10000`0000`40000L000060000`40000200040@000@P000@100010P000`40
000600030@000<4000<100006`0001P000<100000P001040004800040@000@8000<100001P000`40
003100030@0001/0000H00030@0000<00P4:008110030@D000<10000`P000`40000J000060000`40
000M00030@000<400P4L00005`000`40000N0081``020A/0000G00030@0001h000<10000``000`40
000I00005`000`40000N00030@000<@000<10000600000/00P4:00030@0001h000<10000a0000`40
000H000030000`40000800030@0001h000<10000a@000`40000G00005`000`40000N00030@000<@0
0P4I00005`000`40000N00030@000<D000<100005`0001L000<100007P020LL000<100005P0001H0
00<100007`000`40003600030@0001H0000F00030@0001l000<10000a`000`40000E00005P000`40
000O00030@000<L000<100005@0001H000<100007`000`40003700815P0001H000<100007`000`40
003800030@0001@0000F00030@0001l00P7900030@0001@0000F00030@0001l000<10000b0000`40
000D00005P000`40000O00030@000<T000<100004`0001H000<100007`000`4000390081500000T0
0P4;00030@0001l000<10000bP000`40000B00002P000`40000900030@0001l000<10000bP000`40
000B00005P000`400005008110000`40000300811@000`40000400030@000<X000<100004P0001H0
00<1000010001040004800040@000@@000<1000010020L`000<100004@0001H000<1000010001040
004800050@000@001@4500030@000<X00P4C00005P050@8000@1000120001P4000400@8000<10000
10000`40003;00030@000140000F00030@0000@000@1000120001040004200030@0100H000<10000
c0000`40000@00005P000`40000400040@000@P000@100010`020@H000<10000c0000`40000@0000
5`000`40000400812P020@D000<1000010000`40003<00030@000100000G00030@0001h000<10000
c0020A40000G00030@0001h00P7>00030@0000l0000G00030@0001h000<10000c@000`40000?0000
5`000`40000N00030@000<d000<100003`0000T00P4<00030@0001h000<10000c@020A00000:0003
0@0000/000<100007@000`40003>00030@0000h0000H00030@0001d000<10000cP000`40000>0000
60000`40000M00030@000<h000<100003P0001P000<100007@020Ll00P4?00006@000`40000L0003
0@000<h00P4?00006@000`40000L00030@000<l000<100003@0001T000<1000070000`40003?0081
3P0001T000<1000070000`40003?00813P0001X000<100006`000`40003?00030@0000d0000J0003
0@0001/00P7@00<13@0001X000<100006`000`40003@00813@0000/00P4=00030@0001/000<10000
d0000`40000<000030000`40000<00030@0001X000<10000d0020@d0000K00030@0001X000<10000
d0020@d0000L00030@0001T000<10000d@000`40000;0000700010400@4400030@0000<00P4300@1
1@000`40003A0081300001d000@1000120001040004200030@0000H00P7B0081300001d000@10001
20001040004300030@0000D000<10000d@020@`0000G00@10P001040004800040@000@@000<10000
10000`40003A0081300001d00P400`01000700040@000@D000<100000`000`40003A00030@0000/0
000M008100<00@001`001040004200040@000@D000<10000d@020@`0000?00813@020@X00P440081
1P000`40003B00030@0000X0000@00030@0000`000<100005P000`40003B00812`00020000<10000
5@020M<00P4;000080000`40000E00030@000=800P4;00008@000`40000D00030@000=800P4;0000
8P000`40000C00030@000=800P4;00008`000`40000B00030@000=800P4;00008`000`40000B0003
0@000=800P4;00004`020@l000<100004@020M@000<100002@0001@000<100003P000`40000@0003
0@000=800P4;00009P000`40000?00030@000=<00P4:00009`000`40000>00030@000=<00P4:0000
:0000`40000=00030@000=<00P4:0000:@000`40000<00030@0003<00P4400030@0000<00P4300<1
<0020@@000<100000P040Bh00P4400030@000080104200<12`020@X0000H00813`000`40000<0003
0@00038000@1000120001040004500030@0002`000@100012P000`40000/00040@000@X000<10000
10000`40000800812P0001T000<100003P000`40000;0081<`001040004800040@000@D000<10000
;0001040004:00030@0002`000@100012P000`40000400030@0000P00P4:0000:`020@/000<10000
<P001040004800040@000@800`4_00040@000@X000<10000;0001040004:00040@0000<12`020@X0
000]00030@0000P000<10000<P001040004800040@000@8000<10000;`001040004:00030@0002`0
00@100012P001@40000100d00P4:0000;P020@P000<10000<P001040004800040@000@8000<10000
;`001040004800<1;P001040004800<10`000`40000;00812P0001d00P4A00811P000`40000c0081
2P020@<0104_00812`000`40000]00812`00104000040@X000<100002@0001h000<100004@000`40
000300030@000=<000<100002@0003<00`400`010@3E00030@0000T000030?l15044000010000`40
000:00030@0000X000<100000P000`40000500030@0000L0104;00030@0000X000<100002P000`40
000:00030@0000X000<100002P000`40000:00030@0000X000<100002P000`40000:00030@0000T0
00<100002P000`40000:00030@0000X000<100002P000`40000:00030@0000X000<10000100002H0
0P4;00H1h@0002L000<100000P400`010@040@0600410@01h@0002/000P1000100400@D000<10000
g`0003P000<10000g`0003P00P7P0000>0000`40003O0000\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-0.0434367, -0.123359, 
  0.000775201, 0.000746382}}]
}, Open  ]],

Cell["", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["6.  Non Rational Models."], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The functions that were  fit to the data in the examples above were \
rational, but the function ",
  StyleBox["NewtonFit[]",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  "   can solve problems with more general models."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1152}, {0, 900}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{640, 708},
WindowMargins->{{177, Automatic}, {2, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 84, 2, 107, "Title"],

Cell[CellGroupData[{
Cell[1840, 57, 89, 2, 54, "Section"],
Cell[1932, 61, 398, 11, 46, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2367, 77, 104, 2, 54, "Section"],
Cell[2474, 81, 582, 17, 177, "SmallText"],
Cell[3059, 100, 1461, 28, 187, "SmallText"],
Cell[4523, 130, 910, 25, 128, "SmallText"],
Cell[5436, 157, 1309, 30, 196, "SmallText",
  PageBreakWithin->False],
Cell[6748, 189, 562, 11, 178, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7347, 205, 151, 4, 54, "Section",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[7501, 211, 876, 14, 327, "SmallText",
  PageBreakBelow->True],
Cell[8380, 227, 359, 8, 103, "SmallText"],
Cell[8742, 237, 95, 2, 27, "SmallText"],
Cell[8840, 241, 85, 2, 27, "Input"],
Cell[8928, 245, 129, 3, 27, "SmallText"],
Cell[9060, 250, 221, 5, 100, "Input"],
Cell[9284, 257, 322, 10, 44, "SmallText"],
Cell[9609, 269, 99, 2, 27, "Input"],
Cell[9711, 273, 167, 4, 27, "SmallText"],
Cell[9881, 279, 125, 3, 46, "Input"],
Cell[10009, 284, 326, 10, 44, "SmallText"],
Cell[10338, 296, 97, 2, 27, "Input"],
Cell[10438, 300, 321, 10, 46, "SmallText"],

Cell[CellGroupData[{
Cell[10784, 314, 188, 5, 27, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[10975, 321, 85, 1, 23, "Print"],
Cell[11063, 324, 76, 1, 23, "Print"],
Cell[11142, 327, 85, 1, 23, "Print"],
Cell[11230, 330, 353, 8, 23, "Print"],
Cell[11586, 340, 426, 8, 23, "Print"],
Cell[12015, 350, 430, 8, 23, "Print"],
Cell[12448, 360, 446, 9, 23, "Print"],
Cell[12897, 371, 450, 9, 23, "Print"],
Cell[13350, 382, 451, 9, 25, "Print"],
Cell[13804, 393, 460, 9, 25, "Print"],
Cell[14267, 404, 448, 9, 61, "Output"]
}, Open  ]],
Cell[14730, 416, 576, 12, 90, "SmallText",
  PageBreakWithin->False],

Cell[CellGroupData[{
Cell[15331, 432, 219, 6, 43, "Input"],
Cell[15553, 440, 357, 9, 44, "Output"]
}, Open  ]],
Cell[15925, 452, 190, 4, 27, "SmallText"],

Cell[CellGroupData[{
Cell[16140, 460, 381, 9, 75, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[16524, 471, 15688, 551, 182, 6735, 434, "GraphicsData", 
"PostScript", "Graphics",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32261, 1028, 102, 2, 54, "Section"],
Cell[32366, 1032, 759, 12, 102, "SmallText"],

Cell[CellGroupData[{
Cell[33150, 1048, 639, 13, 235, "Input",
  PageBreakBelow->Automatic],
Cell[33792, 1063, 85, 1, 23, "Print"],
Cell[33880, 1066, 76, 1, 23, "Print"],
Cell[33959, 1069, 85, 1, 23, "Print"],
Cell[34047, 1072, 350, 8, 23, "Print"],
Cell[34400, 1082, 391, 8, 23, "Print"],
Cell[34794, 1092, 85, 1, 23, "Print"],
Cell[34882, 1095, 76, 1, 23, "Print"],
Cell[34961, 1098, 85, 1, 23, "Print"],
Cell[35049, 1101, 350, 8, 23, "Print"],
Cell[35402, 1111, 391, 8, 23, "Print"],
Cell[35796, 1121, 85, 1, 23, "Print"],
Cell[35884, 1124, 76, 1, 23, "Print"],
Cell[35963, 1127, 85, 1, 23, "Print"],
Cell[36051, 1130, 348, 8, 23, "Print"],
Cell[36402, 1140, 424, 8, 23, "Print"],
Cell[36829, 1150, 425, 8, 23, "Print"],
Cell[37257, 1160, 424, 8, 23, "Print"],
Cell[37684, 1170, 392, 8, 23, "Print"],
Cell[38079, 1180, 85, 1, 23, "Print"],
Cell[38167, 1183, 76, 1, 23, "Print"],
Cell[38246, 1186, 85, 1, 23, "Print"],
Cell[38334, 1189, 350, 8, 23, "Print"],
Cell[38687, 1199, 391, 8, 23, "Print"],
Cell[39081, 1209, 85, 1, 23, "Print"],
Cell[39169, 1212, 76, 1, 23, "Print"],
Cell[39248, 1215, 85, 1, 23, "Print"],
Cell[39336, 1218, 350, 8, 23, "Print"],
Cell[39689, 1228, 422, 8, 23, "Print"],
Cell[40114, 1238, 431, 8, 23, "Print"],
Cell[40548, 1248, 430, 8, 23, "Print"],
Cell[40981, 1258, 42, 1, 27, "Output"]
}, Open  ]],
Cell[41038, 1262, 34, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41109, 1268, 154, 4, 54, "Section",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[41266, 1274, 703, 15, 119, "SmallText"],
Cell[41972, 1291, 129, 3, 27, "Input"],
Cell[42104, 1296, 170, 4, 27, "SmallText"],
Cell[42277, 1302, 156, 4, 27, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[42458, 1310, 220, 6, 27, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[42681, 1318, 85, 1, 23, "Print"],
Cell[42769, 1321, 76, 1, 23, "Print"],
Cell[42848, 1324, 85, 1, 23, "Print"],
Cell[42936, 1327, 373, 9, 23, "Print"],
Cell[43312, 1338, 451, 9, 23, "Print"],
Cell[43766, 1349, 455, 9, 25, "Print"],
Cell[44224, 1360, 459, 9, 25, "Print"],
Cell[44686, 1371, 418, 9, 25, "Print"],
Cell[45107, 1382, 446, 9, 61, "Output"]
}, Open  ]],
Cell[45568, 1394, 155, 4, 27, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45760, 1403, 103, 2, 54, "Section"],
Cell[45866, 1407, 1368, 23, 209, "SmallText"],
Cell[47237, 1432, 212, 6, 48, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[47452, 1440, 515, 12, 59, "SmallText"],
Cell[47970, 1454, 153, 4, 27, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[48148, 1462, 189, 5, 27, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[48340, 1469, 85, 1, 23, "Print"],
Cell[48428, 1472, 76, 1, 23, "Print"],
Cell[48507, 1475, 85, 1, 23, "Print"],
Cell[48595, 1478, 366, 9, 23, "Print"],
Cell[48964, 1489, 441, 9, 23, "Print"],
Cell[49408, 1500, 454, 9, 23, "Print"],
Cell[49865, 1511, 454, 9, 25, "Print"],
Cell[50322, 1522, 457, 9, 25, "Print"],
Cell[50782, 1533, 420, 9, 61, "Output"]
}, Open  ]],
Cell[51217, 1545, 162, 4, 27, "SmallText"],

Cell[CellGroupData[{
Cell[51404, 1553, 282, 8, 43, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[51689, 1563, 387, 10, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52113, 1578, 383, 9, 75, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[52499, 1589, 15408, 524, 182, 6263, 404, "GraphicsData", 
"PostScript", "Graphics",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[67922, 2116, 43, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68002, 2122, 101, 2, 54, "Section"],
Cell[68106, 2126, 331, 10, 44, "SmallText"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

